requirejs.config({
    // https://github.com/vega/vega-embed/issues/8
    //
    // Also we name datatables "datatables.net" because the Bootstrap
    // DataTables code necessitates it -- see
    // https://stackoverflow.com/a/33748812/10730311
    //
    // Lastly, use of the Bootstrap Bundle based on this blessed comment:
    // https://stackoverflow.com/a/49839899/10730311 which saved time
    // debugging require.js and popper.js
    paths: {
        vega: "vendor/vega.min",
        "vega-lite": "vendor/vega-lite.min",
        "vega-embed": "vendor/vega-embed.min",
        jquery: "vendor/jquery-3.4.1.min",
        bootstrap: "vendor/bootstrap.bundle.min",
        "datatables.net": "vendor/jquery.dataTables.min",
        datatablesbs: "vendor/dataTables.bootstrap4.min",
    },
    shim: {
        "vega-lite": { deps: ["vega"] },
        "vega-embed": { deps: ["vega-lite"] },
        bootstrap: { deps: ["jquery"] },
        "datatables.net": { deps: ["jquery"] },
        datatablesbs: { deps: ["datatables.net", "bootstrap"] },
    },
});
requirejs(
    [
        "js/display",
        "js/feature_computation",
        "vega",
        "vega-lite",
        "vega-embed",
        "jquery",
        "bootstrap",
        "datatables.net",
        "datatablesbs",
    ],
    function (display, feature_computation, vega, vegaLite, vegaEmbed) {
        // DON'T CHANGE THESE LINES unless you know what you're doing -- the
        // "var *JSON = {};" lines are expected to contain that text by Qurro's
        // python code, which replaces the empty {}s with JSON objects that
        // contain all of the data needed for the Qurro visualization.
        var rankPlotJSON = {"$schema": "https://vega.github.io/schema/vega-lite/v3.3.0.json", "autosize": {"resize": true}, "background": "#FFFFFF", "config": {"axis": {"gridColor": "#f2f2f2", "labelBound": true}, "mark": {"tooltip": null}, "view": {"height": 300, "width": 400}}, "data": {"name": "data-2928d03f313f6a2334743c6395897a54"}, "datasets": {"data-2928d03f313f6a2334743c6395897a54": [{"Axis 1": -0.07656628126254535, "Axis 2": 0.021454931533858128, "Axis 3": 0.27293792335243716, "Axis 4": 0.3570557415869906, "Axis 5": -0.25633122007078846, "Confidence": "0.9972511412166732", "Feature ID": "4b5eeb300368260019c1fbc7a3c718fc", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides; s__", "qurro_classification": "None", "qurro_spc": 13.0}, {"Axis 1": 0.10805989085103826, "Axis 2": -0.2405422073411352, "Axis 3": -0.1708979267324281, "Axis 4": -0.05330127270981942, "Axis 5": -0.2217689569827807, "Confidence": "0.9799426564411075", "Feature ID": "fe30ff0f71a38a39cf1717ec2be3a2fc", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Neisseriales; f__Neisseriaceae; g__Neisseria", "qurro_classification": "None", "qurro_spc": 16.0}, {"Axis 1": 0.1693976733516469, "Axis 2": -0.07053640212750548, "Axis 3": -0.26445904154084005, "Axis 4": 0.07650073635262021, "Axis 5": -0.2631901755626461, "Confidence": "0.9999999999716238", "Feature ID": "d29fe3c70564fc0f69f2c03e0d1e5561", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus", "qurro_classification": "None", "qurro_spc": 25.0}, {"Axis 1": -0.11291565220526853, "Axis 2": 0.20313055813596156, "Axis 3": -0.10604121194111753, "Axis 4": -0.3599545026546503, "Axis 5": -0.13358595296722264, "Confidence": "0.995585946749247", "Feature ID": "868528ca947bc57b69ffdf83e6b73bae", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides; s__", "qurro_classification": "None", "qurro_spc": 10.0}, {"Axis 1": -0.12968594644949796, "Axis 2": 0.17420349991808984, "Axis 3": 0.15544628548802367, "Axis 4": 0.032277791612310015, "Axis 5": -0.2801570305640862, "Confidence": "0.999999973545473", "Feature ID": "154709e160e8cada6bfb21115acc80f5", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides", "qurro_classification": "None", "qurro_spc": 13.0}, {"Axis 1": 0.07435316464216078, "Axis 2": -0.29873477983376723, "Axis 3": -0.11267376231336822, "Axis 4": -0.042195065820123924, "Axis 5": -0.18640465771725792, "Confidence": "0.9455365481961946", "Feature ID": "1d2e5f3444ca750c85302ceee2473331", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae; g__Haemophilus; s__parainfluenzae", "qurro_classification": "None", "qurro_spc": 23.0}, {"Axis 1": -0.08330675594931562, "Axis 2": 0.12361036103529294, "Axis 3": 0.15882592068742724, "Axis 4": -0.14124028464298144, "Axis 5": -0.2672359484400899, "Confidence": "0.9909718328940056", "Feature ID": "0305a4993ecf2d8ef4149fdfc7592603", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides; s__uniformis", "qurro_classification": "None", "qurro_spc": 11.0}, {"Axis 1": 0.1791786996495833, "Axis 2": 0.1465516067454795, "Axis 3": -0.18391504429737188, "Axis 4": 0.12540798059224528, "Axis 5": -0.11819322504685396, "Confidence": "0.9999999078928576", "Feature ID": "cb2fe0146e2fbcb101050edb996a0ee2", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli", "qurro_classification": "None", "qurro_spc": 15.0}, {"Axis 1": 0.023374641599027246, "Axis 2": -0.27875661279210756, "Axis 3": 0.03414079191124872, "Axis 4": -0.15757360531759246, "Axis 5": -0.10024335335759338, "Confidence": "0.999999749796092", "Feature ID": "997056ba80681bbbdd5d09aa591eadc0", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Fusobacteriaceae; g__Fusobacterium; s__", "qurro_classification": "None", "qurro_spc": 16.0}, {"Axis 1": 0.21292386047833178, "Axis 2": 0.10560316633407521, "Axis 3": 0.012959548856113614, "Axis 4": 0.03164487933271772, "Axis 5": -0.06823347778693055, "Confidence": "0.8746483867160153", "Feature ID": "9079bfebcce01d4b5c758067b1208c31", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Pseudomonadaceae; g__Pseudomonas; s__veronii", "qurro_classification": "None", "qurro_spc": 11.0}, {"Axis 1": -0.010022091835007125, "Axis 2": -0.23511518892993058, "Axis 3": 0.03205748640378355, "Axis 4": -0.07114542589154811, "Axis 5": -0.10730997745155786, "Confidence": "0.9999992094865033", "Feature ID": "3c9c437f27aca05f8db167cd080ff1ec", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__melaninogenica", "qurro_classification": "None", "qurro_spc": 14.0}, {"Axis 1": -0.10596039317924098, "Axis 2": 0.07043004022262178, "Axis 3": 0.0661518237005731, "Axis 4": -0.06623550501122111, "Axis 5": -0.17622951528467717, "Confidence": "0.9936028877616412", "Feature ID": "bfbed36e63b69fec4627424163d20118", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Faecalibacterium; s__prausnitzii", "qurro_classification": "None", "qurro_spc": 14.0}, {"Axis 1": -0.05564270206194526, "Axis 2": 0.020738764622334437, "Axis 3": 0.1390445231864249, "Axis 4": 0.13844147586220432, "Axis 5": -0.17178493378125656, "Confidence": "0.9999875721629126", "Feature ID": "90d32ffe026535b392c0bad850f213c4", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Faecalibacterium; s__prausnitzii", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": 0.04941147666515717, "Axis 2": -0.1892632740508454, "Axis 3": 0.03443819464664957, "Axis 4": -0.06145753560545123, "Axis 5": -0.09236200534595881, "Confidence": "0.7617822104920616", "Feature ID": "ab4ef4399912b0507d8d1187e874684d", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Neisseriales; f__Neisseriaceae; g__Neisseria; s__subflava", "qurro_classification": "None", "qurro_spc": 8.0}, {"Axis 1": -0.09264862990196025, "Axis 2": 0.03690505599860465, "Axis 3": 0.11883488386788417, "Axis 4": 0.04631667136749343, "Axis 5": -0.142788513877503, "Confidence": "0.9999999028719817", "Feature ID": "d86ef5d6394f5dbeb945f39aa25e7426", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Phascolarctobacterium; s__", "qurro_classification": "None", "qurro_spc": 12.0}, {"Axis 1": 0.1545375022823322, "Axis 2": 0.093479186240337, "Axis 3": -0.06066829696351047, "Axis 4": 0.008337542535452916, "Axis 5": -0.04578946434396073, "Confidence": "0.9933097503115736", "Feature ID": "a049763053c277b16c2a318f41eb23b4", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 13.0}, {"Axis 1": 0.03680661662021009, "Axis 2": -0.1347009923895792, "Axis 3": -0.043061493426737686, "Axis 4": -0.02521793215114691, "Axis 5": -0.11393292810272776, "Confidence": "0.9629197506822288", "Feature ID": "699071a4a7ce68918e4cd93a61275ecd", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus; s__", "qurro_classification": "None", "qurro_spc": 14.0}, {"Axis 1": -0.06959583868762922, "Axis 2": 0.14992763840949555, "Axis 3": -0.05960614302316806, "Axis 4": -0.2046531504835514, "Axis 5": -0.05841030421147763, "Confidence": "0.9999977852978703", "Feature ID": "cdd14cce4ec44b3235923652b71e947e", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": 0.16056221295096468, "Axis 2": 0.10851145965113657, "Axis 3": -0.09336208781544532, "Axis 4": 0.03445349252885053, "Axis 5": -0.0738504974481777, "Confidence": "0.9999815189653608", "Feature ID": "7e598ad34909a3fb8ff1623f1ede11a6", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium", "qurro_classification": "None", "qurro_spc": 12.0}, {"Axis 1": 0.11094199301130267, "Axis 2": -0.057274452471449945, "Axis 3": -0.09294948904038909, "Axis 4": 0.07140735981871853, "Axis 5": 0.02369511952623011, "Confidence": "0.9999648589717923", "Feature ID": "b44621e5c80607cdfacbf7a81e1cbe41", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus; s__", "qurro_classification": "None", "qurro_spc": 26.0}, {"Axis 1": 0.03981867247433085, "Axis 2": -0.08692542348624736, "Axis 3": -0.017219588057579668, "Axis 4": -0.0309244376863859, "Axis 5": -0.07617501319927476, "Confidence": "0.9143736167026185", "Feature ID": "e8e6b7fc969005938de8ac7ffb94f17c", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Micrococcaceae; g__Rothia; s__mucilaginosa", "qurro_classification": "None", "qurro_spc": 19.0}, {"Axis 1": -0.04980763212613192, "Axis 2": 0.0503897258093367, "Axis 3": 0.04505133837131586, "Axis 4": -0.03297418440028242, "Axis 5": -0.12796589136727093, "Confidence": "0.8963953418265547", "Feature ID": "535696cecf56f03d3401d7d6dbe66d7b", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Roseburia; s__faecis", "qurro_classification": "None", "qurro_spc": 9.0}, {"Axis 1": -0.05182692690858768, "Axis 2": -0.10373162757046193, "Axis 3": -0.06719095849730028, "Axis 4": 0.00928742282984742, "Axis 5": -0.07981056329403032, "Confidence": "0.9518738795596863", "Feature ID": "9f718b8f66b79c3de80546ca9a54539c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Veillonella; s__parvula", "qurro_classification": "None", "qurro_spc": 15.0}, {"Axis 1": -0.11223509406532138, "Axis 2": 0.002635828238467248, "Axis 3": -0.16043417743966923, "Axis 4": 0.08337103781460331, "Axis 5": -0.02996101406531356, "Confidence": "0.9889967379322608", "Feature ID": "f352c1f1efecf483511c2270aabd0ae6", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.12645495220255645, "Axis 2": 0.06447669812287178, "Axis 3": 0.013582295378955486, "Axis 4": -0.03767996980520382, "Axis 5": -0.024681860731048985, "Confidence": "0.8321950771599298", "Feature ID": "909755d7142ea53c7f61c97c3586f26c", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Acinetobacter; s__guillouiae", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.008711308617571785, "Axis 2": 0.00818407799977234, "Axis 3": -0.13662274177376885, "Axis 4": 0.07596390287065445, "Axis 5": -0.07601291349445351, "Confidence": "0.9977578029345229", "Feature ID": "fd86856409fe6433d719558a30910515", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae; g__Haemophilus", "qurro_classification": "None", "qurro_spc": 16.0}, {"Axis 1": -0.04511417418632579, "Axis 2": 0.057208044614420306, "Axis 3": 0.011594751233910062, "Axis 4": -0.07675133561725031, "Axis 5": -0.09952921665756809, "Confidence": "0.8444956427969824", "Feature ID": "44ff26d8105cf822417b4b0c4eb27c02", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides; s__", "qurro_classification": "None", "qurro_spc": 10.0}, {"Axis 1": 0.09156358371906186, "Axis 2": 0.06308678331017332, "Axis 3": -0.050962994879690277, "Axis 4": 0.014322353362415241, "Axis 5": -0.04921069398896198, "Confidence": "0.9999999998498055", "Feature ID": "ad41fe8f8be5b01c96549309937e3b14", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Peptoniphilus; s__", "qurro_classification": "None", "qurro_spc": 13.0}, {"Axis 1": -0.026865055050296134, "Axis 2": 0.05702290763270183, "Axis 3": -0.09282320087896312, "Axis 4": -0.23125816288305673, "Axis 5": -0.028489193149864107, "Confidence": "0.9817165373591636", "Feature ID": "ab6b063ed43d8cb3008e157a0a305c47", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Rikenellaceae; g__Alistipes; s__putredinis", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.06774648641789663, "Axis 2": 0.07220707071704978, "Axis 3": -0.07051035339990692, "Axis 4": 0.05843668862946946, "Axis 5": -0.030313586006014595, "Confidence": "0.9999999999834444", "Feature ID": "fcd4f95c05b868060121ff709085bf21", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Finegoldia; s__", "qurro_classification": "None", "qurro_spc": 14.0}, {"Axis 1": -0.02817140588083015, "Axis 2": 0.004643891821481969, "Axis 3": 0.105204191021461, "Axis 4": 0.12396495734073619, "Axis 5": -0.1010547995067362, "Confidence": "0.9999938297439364", "Feature ID": "57b34afdff2e84fb9b0befd219edcb38", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Lachnospira; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.04369321153370274, "Axis 2": -0.09847161110405869, "Axis 3": 0.045465844264417764, "Axis 4": 0.014014304635680935, "Axis 5": -0.020190999819796412, "Confidence": "0.9992159962491128", "Feature ID": "047b7fb62a5e9d2711e639ae1cb1519a", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Veillonella; s__dispar", "qurro_classification": "None", "qurro_spc": 10.0}, {"Axis 1": 0.04343889250929341, "Axis 2": -0.028137155653928173, "Axis 3": 0.06584096279170819, "Axis 4": 0.18695606849012278, "Axis 5": 0.02239089438517454, "Confidence": "0.9999999999923688", "Feature ID": "0160e14a78b18b903618f11bc732746e", "Taxon": "k__Bacteria; p__Verrucomicrobia; c__Verrucomicrobiae; o__Verrucomicrobiales; f__Verrucomicrobiaceae; g__Akkermansia; s__muciniphila", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.051507176784311076, "Axis 2": 0.03216638801827683, "Axis 3": 0.023681104731746956, "Axis 4": -0.053882778250952855, "Axis 5": -0.1011917050398177, "Confidence": "0.9999596696884526", "Feature ID": "d2613a43f4ed1dda8a673e7fb251ebef", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Lachnospira; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.09029040959559485, "Axis 2": -0.012555229896754692, "Axis 3": -0.1679303817179119, "Axis 4": 0.07290816193602682, "Axis 5": -0.051420365219727864, "Confidence": "0.9999999455213683", "Feature ID": "e7c8b8c8fced8eead4b767bffe6dd544", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Fusobacteriaceae; g__Fusobacterium; s__", "qurro_classification": "None", "qurro_spc": 8.0}, {"Axis 1": 0.12507234711267398, "Axis 2": 0.09426292133377524, "Axis 3": -0.007746676750059904, "Axis 4": 0.0169745865953963, "Axis 5": -0.031122624531161425, "Confidence": "0.9999999979871887", "Feature ID": "e31b5affbe5e23b79a8619589f3b6620", "Taxon": "k__Bacteria; p__Cyanobacteria; c__Chloroplast; o__Streptophyta; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 11.0}, {"Axis 1": 0.10183733779832041, "Axis 2": 0.06003676775824085, "Axis 3": -0.02767137075457487, "Axis 4": 0.007063100804969979, "Axis 5": -0.038030025394080916, "Confidence": "0.9999999996511519", "Feature ID": "67e23140639733766b7e127f50221289", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Anaerococcus; s__", "qurro_classification": "None", "qurro_spc": 14.0}, {"Axis 1": 0.10224270055949472, "Axis 2": 0.07431802453649904, "Axis 3": -0.07364717971875742, "Axis 4": 0.012253304666394729, "Axis 5": -0.0484746352042699, "Confidence": "0.999920002164234", "Feature ID": "db793caa585e078770021a7979ae8ea2", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.047228213890894946, "Axis 2": 0.05599612561433943, "Axis 3": -0.04101239538781687, "Axis 4": -0.1544376762799874, "Axis 5": -0.05970970250134549, "Confidence": "0.9778528599812335", "Feature ID": "7dd9c9124ec3f118a6cef1f0d422c011", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.04858924016858945, "Axis 2": 0.04449067382800285, "Axis 3": 0.02347857663535342, "Axis 4": -0.04185175024498487, "Axis 5": -0.09188284024764501, "Confidence": "0.9999962602942257", "Feature ID": "01e0b7ac306895be84179f2715af269b", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Lachnospira; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.13708249463170674, "Axis 2": 0.03415738879237271, "Axis 3": 0.12000477165804377, "Axis 4": -0.06540291267526029, "Axis 5": -0.00047746645102320285, "Confidence": "0.8287793003810794", "Feature ID": "1685b25b43eb070cd7655de8c2d8c0a4", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Streptobacillus", "qurro_classification": "None", "qurro_spc": 13.0}, {"Axis 1": 0.01845041998563555, "Axis 2": 0.05172787226301724, "Axis 3": -0.12899173965230917, "Axis 4": 0.06297616407971166, "Axis 5": -0.06818330617510987, "Confidence": "0.8520539825257543", "Feature ID": "500d6b485cef4c52aad211d6d6e6dbc7", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__stationis", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.008552178827665909, "Axis 2": -0.03370053996816494, "Axis 3": 0.08816456000929065, "Axis 4": 0.13133887561881344, "Axis 5": -0.06035510648155983, "Confidence": "0.9979641355813899", "Feature ID": "ee0fb26fca3afb05e0b288d6fcab899e", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides; s__fragilis", "qurro_classification": "None", "qurro_spc": 8.0}, {"Axis 1": -0.01178078012754995, "Axis 2": 0.05611063581069537, "Axis 3": -0.09159944714634898, "Axis 4": 0.04789123848988188, "Axis 5": -0.015044761735642629, "Confidence": "0.9992413684454771", "Feature ID": "d1d750ce3b00503c204516d27ca0d3b0", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Gemellales; f__Gemellaceae", "qurro_classification": "None", "qurro_spc": 19.0}, {"Axis 1": 0.0085748093073018, "Axis 2": -0.02569469777892577, "Axis 3": -0.0009550632406402945, "Axis 4": -0.003890290714565134, "Axis 5": -0.028525626690150054, "Confidence": "0.7129684166926287", "Feature ID": "ebe0e9790089ad4f40151cb4a3231a8f", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Carnobacteriaceae", "qurro_classification": "None", "qurro_spc": 17.0}, {"Axis 1": 0.07962360718221731, "Axis 2": 0.029474678792260903, "Axis 3": 0.035641874755591246, "Axis 4": -0.0087086184848802, "Axis 5": -0.017857756751995, "Confidence": "0.9602964881409842", "Feature ID": "54d098d009b89779530eaf43a1bb136a", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.029485857958187447, "Axis 2": 0.03592057949717995, "Axis 3": -0.010472755371284885, "Axis 4": -0.0827456444191965, "Axis 5": -0.06359562869241712, "Confidence": "0.812432018536005", "Feature ID": "0a69950e803a5d9e7166c450e44f43cf", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Roseburia; s__inulinivorans", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": 0.05835970919789739, "Axis 2": 0.04377336775998309, "Axis 3": -0.020120204545109682, "Axis 4": -0.009187987339042978, "Axis 5": -0.02153748511970793, "Confidence": "0.9966789982986243", "Feature ID": "b685f8246fb6fad0fd91574c444b8f51", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.1705646357822163, "Axis 2": 0.05194944160133849, "Axis 3": 0.08027643071494801, "Axis 4": -0.04197671229880762, "Axis 5": -0.02204990565589401, "Confidence": "0.999999957829858", "Feature ID": "636c27859c1ac0a7994ca8ed145d03fe", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Lactococcus; s__", "qurro_classification": "None", "qurro_spc": 9.0}, {"Axis 1": 0.019760420408031196, "Axis 2": -0.02753815806146921, "Axis 3": 0.08164830474394649, "Axis 4": 0.1728260412500444, "Axis 5": -0.018843842546352386, "Confidence": "0.9999316145657076", "Feature ID": "79e9e337b10e2d298bb1b3bde946782d", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Enterobacteriales; f__Enterobacteriaceae", "qurro_classification": "None", "qurro_spc": 9.0}, {"Axis 1": -0.015234277341452395, "Axis 2": -0.05675057276600511, "Axis 3": 0.041780580943334276, "Axis 4": -0.01721638640971657, "Axis 5": 0.007289633026543998, "Confidence": "0.9999774348684217", "Feature ID": "f35ce9c514e1398308f5f84ed50b260f", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__[Prevotella]; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": -0.08499191581670934, "Axis 2": -0.0014437411634035844, "Axis 3": -0.11033713856034799, "Axis 4": 0.05719055387258655, "Axis 5": -0.015962405718137253, "Confidence": "0.9999950533255195", "Feature ID": "e5c80b4a23b96b2fa35b6da6cac2bf73", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Cytophagia; o__Cytophagales; f__Cytophagaceae; g__Flectobacillus; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.025783448551570807, "Axis 2": 0.042964251521733235, "Axis 3": -0.032593216249416, "Axis 4": -0.11887854954760897, "Axis 5": -0.04552024024377886, "Confidence": "0.9998248672290805", "Feature ID": "9118606a87ac19f8d041da20f16f3236", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Parabacteroides; s__distasonis", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.03628606461384927, "Axis 2": 0.12608586211503262, "Axis 3": -0.08309781199146835, "Axis 4": 0.08060843915871764, "Axis 5": 0.039127213053287827, "Confidence": "0.9999977637029781", "Feature ID": "d8e8459398f3f096775f4298666880a7", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__[Prevotella]; s__", "qurro_classification": "None", "qurro_spc": 19.0}, {"Axis 1": 0.020570711339910862, "Axis 2": -0.09548696210727149, "Axis 3": 0.011677537939961447, "Axis 4": -0.029078973298781043, "Axis 5": -0.053024723113953065, "Confidence": "0.9695893017530326", "Feature ID": "fba3d9b3872ff9021d66434323fb9565", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Veillonella; s__parvula", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.12349587687362447, "Axis 2": 0.11100868116463036, "Axis 3": -0.1564491581830574, "Axis 4": 0.09230912158329266, "Axis 5": 0.024337374236576437, "Confidence": "0.9970077966498331", "Feature ID": "4fdf8dcd9451f5742982d716fa9f0536", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Burkholderiaceae; g__Lautropia; s__", "qurro_classification": "None", "qurro_spc": 12.0}, {"Axis 1": -0.020661544659595566, "Axis 2": -0.024121013062532996, "Axis 3": 0.02544664797401942, "Axis 4": -0.01164225343011011, "Axis 5": -0.005933278344495215, "Confidence": "0.9999999999362217", "Feature ID": "ae27459b7f5465815b1f565d792083ce", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__nanceiensis", "qurro_classification": "None", "qurro_spc": 10.0}, {"Axis 1": -0.020087995755464702, "Axis 2": 0.03224966437202977, "Axis 3": -0.12501338311866375, "Axis 4": 0.06488488145430693, "Axis 5": -0.05415534935576035, "Confidence": "0.8682914463557063", "Feature ID": "4ea5683e2c2a183c11c45dc8fbd0c67c", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__variabile", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.023009184764360285, "Axis 2": -0.06895279952859514, "Axis 3": 0.017764095473712528, "Axis 4": -0.01593942302957039, "Axis 5": -0.040031485622548185, "Confidence": "0.9999877166156739", "Feature ID": "6edca9464612efff71d8f97299f01663", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__melaninogenica", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.011002659254123432, "Axis 2": -0.03150034408232352, "Axis 3": 0.06502252258693675, "Axis 4": 0.10224718882931377, "Axis 5": -0.026767758628624343, "Confidence": "0.9999400765888229", "Feature ID": "41fedaa9200e2933821f84ecdc0b0772", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Blautia; s__", "qurro_classification": "None", "qurro_spc": 10.0}, {"Axis 1": 0.1131152088335819, "Axis 2": 0.05468159439420575, "Axis 3": -0.02094210282865103, "Axis 4": 0.007315962753452316, "Axis 5": -0.05014696207907024, "Confidence": "0.9080840655320389", "Feature ID": "469e4ff2129066178b74b112829fc03c", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.04235781798203833, "Axis 2": 0.026320159488509076, "Axis 3": -0.13274973798124334, "Axis 4": 0.062228401022576006, "Axis 5": -0.04133841186942573, "Confidence": "0.7333023426339906", "Feature ID": "41735c13fb7f63db49b10fba5d959ce3", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Neisseriales; f__Neisseriaceae; g__Neisseria; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": 0.0745948065833279, "Axis 2": 0.027319722821881217, "Axis 3": 0.03458640698946372, "Axis 4": -0.020765793501390267, "Axis 5": -0.012668294627088175, "Confidence": "0.9985918997592399", "Feature ID": "76174505aef45f134d8068d5ad2c42aa", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Fusobacteriaceae", "qurro_classification": "None", "qurro_spc": 9.0}, {"Axis 1": -0.03262687719218785, "Axis 2": 0.037948347196154184, "Axis 3": -0.028905196436988245, "Axis 4": -0.1087213457428234, "Axis 5": -0.04318891720950638, "Confidence": "0.9847405174447873", "Feature ID": "b8afb7bb30b7a9170b7c6dcd40251d54", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.011572761767150922, "Axis 2": -0.007525784457744257, "Axis 3": -0.013918817167568338, "Axis 4": 0.005855967384852593, "Axis 5": -0.015663036713083164, "Confidence": "0.9539946497860148", "Feature ID": "4c4606a3dbb4f5b8bb1ad1db6dfc5617", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Propionibacteriaceae; g__Propionibacterium; s__acnes", "qurro_classification": "None", "qurro_spc": 13.0}, {"Axis 1": -0.026088580612861186, "Axis 2": 0.010101581725731267, "Axis 3": 0.024247462068534384, "Axis 4": -0.001499800853312205, "Axis 5": -0.051988276045467116, "Confidence": "0.9698501238536241", "Feature ID": "3ef461f213bfc675ddf0b1bfeef2dc52", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.014425496644834947, "Axis 2": 0.011217163123347943, "Axis 3": 0.04305955422622284, "Axis 4": -0.0049918157212447845, "Axis 5": 0.005729582658679654, "Confidence": "0.9993876665928056", "Feature ID": "1f50ac250618ced095a2a5c34bae7651", "Taxon": "k__Bacteria; p__Proteobacteria; c__Epsilonproteobacteria; o__Campylobacterales; f__Campylobacteraceae; g__Campylobacter; s__", "qurro_classification": "None", "qurro_spc": 11.0}, {"Axis 1": -0.011049402376433134, "Axis 2": -0.004815887808098517, "Axis 3": 0.03888449316428871, "Axis 4": 0.04387124626323173, "Axis 5": -0.04329564103125391, "Confidence": "0.9999821943478229", "Feature ID": "b3d4d129c955517b446df657236ba5a2", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__Paraprevotella; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.008029755333886923, "Axis 2": -0.009623493979111395, "Axis 3": 0.019241203295540823, "Axis 4": 0.05339308986519126, "Axis 5": -0.0016881242117518904, "Confidence": "0.938309916093354", "Feature ID": "fc15824cd9e9c29e1319d32843452b54", "Taxon": "k__Bacteria; p__Proteobacteria; c__Deltaproteobacteria; o__Desulfovibrionales; f__Desulfovibrionaceae; g__Desulfovibrio; s__", "qurro_classification": "None", "qurro_spc": 10.0}, {"Axis 1": 0.022251194100872645, "Axis 2": 0.027176113482657947, "Axis 3": -0.027555920093577088, "Axis 4": 0.014849697061782909, "Axis 5": -0.025063552259405316, "Confidence": "0.9993756326104638", "Feature ID": "b2866fdca13681232057e3e85a1978cf", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 11.0}, {"Axis 1": -0.03645237514953886, "Axis 2": 0.02971072952940725, "Axis 3": -0.023199842569988208, "Axis 4": -0.09229178311303411, "Axis 5": -0.041964124343158354, "Confidence": "0.9998925710641527", "Feature ID": "f8f937eeee7762f446a0e87292f98eb6", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Parabacteroides; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.004555070657350783, "Axis 2": -0.018341050289088227, "Axis 3": 0.035661811859301486, "Axis 4": 0.049663622455012324, "Axis 5": -0.029692777521301107, "Confidence": "0.9990873627443428", "Feature ID": "052128d7d424728578efe7852b0afd0d", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Coprococcus; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.017424060343054822, "Axis 2": 0.01333629964474338, "Axis 3": 0.03843434177094828, "Axis 4": -0.017386003914513167, "Axis 5": 0.010706034552447785, "Confidence": "0.999828606131178", "Feature ID": "2514cdaab96a1a42cf15506f2ecf6439", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Oribacterium; s__", "qurro_classification": "None", "qurro_spc": 11.0}, {"Axis 1": 0.06359821925190248, "Axis 2": 0.023308208554377347, "Axis 3": 0.025205727844939373, "Axis 4": -0.013985253578312965, "Axis 5": -0.02177294851423487, "Confidence": "0.9999999971811206", "Feature ID": "fc5b641a0b0408d99ddfb2a5ba64da59", "Taxon": "k__Bacteria; p__Cyanobacteria; c__Chloroplast; o__Streptophyta; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.05343749278299079, "Axis 2": 0.016464097854902077, "Axis 3": 0.01873007710797461, "Axis 4": -0.013794419455079105, "Axis 5": -0.006462835849442312, "Confidence": "0.9999999999147633", "Feature ID": "958bc15b660bce0b894665d13f910f5b", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Anaerococcus; s__", "qurro_classification": "None", "qurro_spc": 11.0}, {"Axis 1": -0.02074509943063196, "Axis 2": 0.0022052262646870243, "Axis 3": 0.04941394385321324, "Axis 4": 0.05168298859388819, "Axis 5": -0.05509347698278969, "Confidence": "0.9999969518858179", "Feature ID": "e063d1c3c9daf7390e5475e48d9b01c5", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Lachnospira; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.06792882221248776, "Axis 2": 0.03985110188420002, "Axis 3": -0.016607787373062018, "Axis 4": 0.0020013443585277586, "Axis 5": -0.030395829769006785, "Confidence": "0.9999999987537365", "Feature ID": "e0472171de6fa02a1f58e392ad3d000e", "Taxon": "k__Bacteria; p__Cyanobacteria; c__Chloroplast; o__Streptophyta; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.03170227373422399, "Axis 2": 0.017312985749237883, "Axis 3": 0.0012952422284306046, "Axis 4": -0.03331225142743911, "Axis 5": -0.04401811213231702, "Confidence": "0.9176244963319936", "Feature ID": "2e55763e77234a7bfc3a311067a0c7e1", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.025151797578706496, "Axis 2": 0.012787468258567919, "Axis 3": 0.005092611614383034, "Axis 4": 0.014407522670518837, "Axis 5": 0.01598626410711788, "Confidence": "0.9999999943076432", "Feature ID": "5ada68b9a081358e1a7d5f1d351e656a", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Leptotrichia; s__", "qurro_classification": "None", "qurro_spc": 10.0}, {"Axis 1": 0.03108100162056358, "Axis 2": 0.02535599182693794, "Axis 3": -0.02446321875088411, "Axis 4": 0.02100478794453386, "Axis 5": -0.032125636513240886, "Confidence": "0.9999913628441673", "Feature ID": "162ed46308ef9dd1600fb0fe7c90b186", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Lactobacillaceae; g__Lactobacillus; s__delbrueckii", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.06867128597684978, "Axis 2": 0.027769943431803792, "Axis 3": 0.01217885900149775, "Axis 4": -0.005384979500652143, "Axis 5": -0.02153056032342762, "Confidence": "0.7211112847085853", "Feature ID": "1b448e00c078f81e49a61933072345d2", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Pseudomonadaceae; g__Pseudomonas; s__fragi", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": -0.07723661771862723, "Axis 2": 0.0008399947778696439, "Axis 3": -0.10693891129909269, "Axis 4": 0.0549670045746071, "Axis 5": -0.023638863393254925, "Confidence": "0.9749739574729861", "Feature ID": "9af77e369d2ba4b3bb6e0e808ed84d91", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.044800397477623564, "Axis 2": -0.01961590419214275, "Axis 3": 0.05276512340908506, "Axis 4": -0.03147668671723632, "Axis 5": -0.004066394518756994, "Confidence": "0.9710147374588216", "Feature ID": "e77bac543df42865af751a32a2942fdb", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.030138860125396377, "Axis 2": 0.024574938736901777, "Axis 3": -0.018997470595168934, "Axis 4": -0.07514002642434178, "Axis 5": -0.03616309195198004, "Confidence": "0.996734337995663", "Feature ID": "3ae3e825c5e3862af6c17798e2b40a37", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Ruminococcus", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.04919911485228202, "Axis 2": 0.027956606539153803, "Axis 3": -0.021510658389958023, "Axis 4": 0.00036791476334089126, "Axis 5": -0.02650754568256624, "Confidence": "0.9999999999999768", "Feature ID": "f8a71161ac98c5ceafcc75e57ace7230", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rickettsiales; f__mitochondria", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.010735994110401516, "Axis 2": 0.012252702696702132, "Axis 3": -0.006801561019207772, "Axis 4": -0.03321930050297912, "Axis 5": -0.020792992920435613, "Confidence": "0.9137511106249239", "Feature ID": "880968796af86b3d6270c228fe8e7026", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.031498941008828094, "Axis 2": 0.005233630856057284, "Axis 3": 0.015206295078149348, "Axis 4": -0.0015094826318836614, "Axis 5": -0.007053088280721391, "Confidence": "0.9942060500954276", "Feature ID": "81351ef6b4d49a3a6b2fc24745d70305", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Moraxella; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.0636045440429169, "Axis 2": -0.09200695916608236, "Axis 3": 0.03268879431093272, "Axis 4": -0.02578049553473545, "Axis 5": 0.016559614733102555, "Confidence": "0.9999999998570956", "Feature ID": "26b8b1509edf09c438db1634308c3c90", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__nanceiensis", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.017280294743419806, "Axis 2": 0.017113414541680638, "Axis 3": -0.014625448494378546, "Axis 4": -0.05631811656992309, "Axis 5": -0.02915653692862028, "Confidence": "0.999950484751643", "Feature ID": "26133b4163fdcd22d86f4e04e74154f1", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Lachnospira; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.06475258553456933, "Axis 2": 0.01530396009404185, "Axis 3": 0.03697154219987121, "Axis 4": -0.02237345414232735, "Axis 5": -0.0033525687075118774, "Confidence": "0.7048708913049944", "Feature ID": "c4aad64f84f51ff331b986a67af4ed3d", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Acinetobacter; s__johnsonii", "qurro_classification": "None", "qurro_spc": 9.0}, {"Axis 1": 0.009157376142483742, "Axis 2": -0.016868945395963158, "Axis 3": 0.010949739899500027, "Axis 4": 0.04121637264181663, "Axis 5": 0.010006585613179773, "Confidence": "0.9987854966688494", "Feature ID": "29a92aecac56c855cbfc0debf9bda0c8", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 8.0}, {"Axis 1": 0.04538165859454285, "Axis 2": 0.014166751824925774, "Axis 3": 0.02071215183554606, "Axis 4": -0.015551769000178418, "Axis 5": -0.005225148621895502, "Confidence": "0.9999983493613525", "Feature ID": "e737a3a864791ec52f1398d83786f4f2", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.012049570541522036, "Axis 2": 0.01824282522753648, "Axis 3": -0.011180353593419049, "Axis 4": -0.04195617119491657, "Axis 5": -0.0188901504249501, "Confidence": "0.9123822288465733", "Feature ID": "7a5d5e6f85da7ca91daa2d803e8f9279", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.018417769822115546, "Axis 2": 0.024844253539481758, "Axis 3": -0.01692522841134843, "Axis 4": -0.05957698866954188, "Axis 5": -0.024102146759280414, "Confidence": "0.9345433630619265", "Feature ID": "acfe4c003905a7074aeaf385b78ad9e0", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Gemmiger; s__formicilis", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.07694948597991902, "Axis 2": 0.028747154155836816, "Axis 3": -0.0799229034442227, "Axis 4": 0.05476221894196101, "Axis 5": -0.002148151110861498, "Confidence": "0.998008582884101", "Feature ID": "75258a676bcd7e73c2437d6a2012d490", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__intermedia", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.022103939778491788, "Axis 2": 0.08619705256748139, "Axis 3": -0.019076747534222126, "Axis 4": 0.027429706315868045, "Axis 5": 0.038569815036490325, "Confidence": "0.9999959632597544", "Feature ID": "5c82bad13c4ebd2ed1bd23a8c2e37fc5", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Veillonella; s__", "qurro_classification": "None", "qurro_spc": 10.0}, {"Axis 1": -0.007361258527053002, "Axis 2": 0.02874900565725531, "Axis 3": 0.022787756243965764, "Axis 4": 0.0020151671989149284, "Axis 5": 0.01744282826931496, "Confidence": "0.999999999995751", "Feature ID": "401d7866836c54f3cd18bd0fc814885e", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Anaerococcus; s__", "qurro_classification": "None", "qurro_spc": 11.0}, {"Axis 1": 0.06064909419883879, "Axis 2": 0.02284207267119489, "Axis 3": 0.010913905598668805, "Axis 4": -0.008301660510382248, "Axis 5": -0.01978900457189835, "Confidence": "0.9540232431020493", "Feature ID": "684721318896ed01048f3502333c214d", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Caulobacterales; f__Caulobacteraceae; g__Brevundimonas; s__diminuta", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.06176530570388358, "Axis 2": -3.1468156774684326e-06, "Axis 3": -0.08314138192204504, "Axis 4": 0.04219514398928005, "Axis 5": -0.020443798673261855, "Confidence": "0.999989496404673", "Feature ID": "839fafb762395fab1ba257442ec29e7f", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.05197425886913749, "Axis 2": 0.03219954448501822, "Axis 3": -0.021754723504365078, "Axis 4": -0.005748717152776916, "Axis 5": -0.017373266677342698, "Confidence": "0.9991242404904648", "Feature ID": "6b82e6cb771d45d6c925405b66299d7f", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.021881923828308846, "Axis 2": 0.017892361125266053, "Axis 3": -0.007154218199484958, "Axis 4": -0.035793070249655876, "Axis 5": -0.015404610359948237, "Confidence": "0.9905797052740418", "Feature ID": "eecc4a4317225eb579540e82ab785716", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Faecalibacterium; s__prausnitzii", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.024194992350273534, "Axis 2": 0.015419584706776988, "Axis 3": -0.0380128860897282, "Axis 4": 0.020968201315952572, "Axis 5": -0.00763213198647777, "Confidence": "0.9999999454936713", "Feature ID": "a895b66cac813ac67ce1c908259b646f", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Fusobacteriaceae; g__Fusobacterium; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.015499356734955736, "Axis 2": -0.01764945222071187, "Axis 3": 0.0247573261062347, "Axis 4": 0.07213086208354912, "Axis 5": 0.013098320147247428, "Confidence": "0.9999936730923399", "Feature ID": "f59a4d48a03cc224462bf83e4d4ab126", "Taxon": "k__Bacteria; p__Firmicutes; c__Erysipelotrichi; o__Erysipelotrichales; f__Erysipelotrichaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": -0.07892852326423294, "Axis 2": 0.03496367726422074, "Axis 3": -0.09484575227398151, "Axis 4": 0.04502132366442368, "Axis 5": -0.002919037069400265, "Confidence": "0.9937646508675011", "Feature ID": "79dcabe7f92f8cf2723b796dcd2f239f", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.0025182801136315208, "Axis 2": 0.011160058490462709, "Axis 3": -0.012385645978979324, "Axis 4": -0.033943927880386686, "Axis 5": -0.005086508880165583, "Confidence": "0.9774218954495508", "Feature ID": "d781fa7e866ac295ce9a56bd97912983", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Faecalibacterium; s__prausnitzii", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.008501550623501709, "Axis 2": 0.0024233742771967064, "Axis 3": 0.022096376437268216, "Axis 4": -0.011886013781192669, "Axis 5": -0.0023022286274856415, "Confidence": "0.9830874316702818", "Feature ID": "0b925631436d3775231b60f9d0011cae", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Sphingomonadales; f__Sphingomonadaceae; g__Sphingomonas; s__", "qurro_classification": "None", "qurro_spc": 10.0}, {"Axis 1": 0.051706301617740646, "Axis 2": 0.015957635626028255, "Axis 3": 0.015092587094390979, "Axis 4": -0.013176594093299524, "Axis 5": -0.011779858946006534, "Confidence": "0.9529606097769646", "Feature ID": "4075a90811bf9c19f02f5aa2ece6da37", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Oxalobacteraceae; g__Janthinobacterium; s__lividum", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.005629944958625623, "Axis 2": 0.0715085553469058, "Axis 3": 0.006126064851695884, "Axis 4": 0.021885485033484326, "Axis 5": 0.035282899596009554, "Confidence": "0.9999510705946077", "Feature ID": "2ff525a1e58c54525e7f2d68a6c0b23e", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__pallens", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.004453073686437314, "Axis 2": -0.001594466998204803, "Axis 3": 0.009033605869196961, "Axis 4": 0.008845018789607507, "Axis 5": -0.015980009924126213, "Confidence": "0.9969552443768318", "Feature ID": "f91c81859bf6eede55eef9c915dd8bab", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.012701655676404997, "Axis 2": 0.0032501064532851763, "Axis 3": 0.030226490284788757, "Axis 4": 0.035299505362093045, "Axis 5": -0.032523047718542135, "Confidence": "0.9997683832047143", "Feature ID": "a5551fc60aa8bbaab737487552ea2a75", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__Paraprevotella; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.008786499508215879, "Axis 2": -0.017166122814748597, "Axis 3": -0.009041615858741197, "Axis 4": -0.017855499047576138, "Axis 5": 0.004341055660090475, "Confidence": "0.9860115943569704", "Feature ID": "a4c08e2c3a34038ea877b16d01736837", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Clostridium; s__clostridioforme", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.051007819837909654, "Axis 2": 0.01547730264138417, "Axis 3": 0.009387751373709024, "Axis 4": -0.0037500352184228532, "Axis 5": -0.016238474324674963, "Confidence": "0.9999999943030247", "Feature ID": "4980b85712efeef1fc4563a9a949fe2e", "Taxon": "k__Bacteria; p__Cyanobacteria; c__Chloroplast; o__Streptophyta; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.004149524487853225, "Axis 2": -0.00021534813926404948, "Axis 3": -0.004642437398393503, "Axis 4": 0.006360744157849227, "Axis 5": -0.005355594276175747, "Confidence": "0.9549961920669491", "Feature ID": "5601f094afc823d75ccb34440645a99e", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Actinomycetaceae; g__Actinomyces; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.018100440548892614, "Axis 2": -0.007314612684567363, "Axis 3": -0.044607911423650295, "Axis 4": -0.03862228538138508, "Axis 5": 0.043948137116985315, "Confidence": "0.9898612700491094", "Feature ID": "21a0198d0a83a8f3ec0e401067138940", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": 0.020217944037303086, "Axis 2": 0.007621920821328518, "Axis 3": 0.02631491755827132, "Axis 4": -0.005615683074952445, "Axis 5": -0.002241700623564624, "Confidence": "0.8602568875560238", "Feature ID": "56c98126dde3abb2d263088db55e12c8", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Sphingobacteriia; o__Sphingobacteriales; f__Sphingobacteriaceae; g__Pedobacter", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.026350541773895432, "Axis 2": -0.027315706492553358, "Axis 3": 0.005910764874980312, "Axis 4": 0.037191819161583484, "Axis 5": 0.022535429619194074, "Confidence": "0.99772915681385", "Feature ID": "393e6e2cbe258ed27a4ca0a2ee0d2cdc", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Blautia; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.005204737577541904, "Axis 2": 0.02785724550093963, "Axis 3": 0.0009722887006086162, "Axis 4": 0.012820780017245698, "Axis 5": 0.012153794610423685, "Confidence": "0.994914384030354", "Feature ID": "a659784c026bd9c8cde94da36aa656d7", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.01977410501693467, "Axis 2": 0.002396333886415167, "Axis 3": -0.010279672084945835, "Axis 4": 0.014463229227499748, "Axis 5": 0.026016172309361353, "Confidence": "0.9999728938417287", "Feature ID": "f16a387e898dbae6432b2ed0241120bd", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Lachnospira; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.03446775789224943, "Axis 2": 0.005174681820346677, "Axis 3": 0.02886246507819102, "Axis 4": -0.01330003889118763, "Axis 5": -0.004999263126220688, "Confidence": "0.9999999999911751", "Feature ID": "3125abe90c7ae91aec06eb104d71845f", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Anaerococcus; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.001843441285778217, "Axis 2": -0.001443529615400843, "Axis 3": -0.0014905246819889534, "Axis 4": 0.0008159320545841827, "Axis 5": -0.004916668221491786, "Confidence": "0.9884890079146773", "Feature ID": "b383ade799e9c83c649cec37705a251d", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.012558936904330404, "Axis 2": -0.010139972142540931, "Axis 3": -0.007866081550225733, "Axis 4": 0.00562498348950487, "Axis 5": 0.01328105235095623, "Confidence": "0.998874483925578", "Feature ID": "1d17561d16d803f652b0d6bdd671c1cc", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": -0.07268137197077666, "Axis 2": 0.09143639733779323, "Axis 3": -0.020955824067153253, "Axis 4": 0.052401276691677934, "Axis 5": 0.06362097071657909, "Confidence": "0.999721146498203", "Feature ID": "b0f7e29de400c6b517b39230dc1b4365", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__[Weeksellaceae]; g__; s__", "qurro_classification": "None", "qurro_spc": 11.0}, {"Axis 1": 0.033221231617735984, "Axis 2": -0.05717733626404257, "Axis 3": -0.003830905193838555, "Axis 4": 0.019595032610085276, "Axis 5": 0.005903892111484256, "Confidence": "0.9650811546263296", "Feature ID": "3bf2fc236887eda11c969b84d30f9fbf", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.037412378301592476, "Axis 2": 0.06534501021386047, "Axis 3": 0.049048671765126554, "Axis 4": -0.014051613450066967, "Axis 5": 0.025145734203452612, "Confidence": "0.8580489315242544", "Feature ID": "3cdd97ba69a504117de24626ba790e96", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Enhydrobacter; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.030889621251091907, "Axis 2": 0.004158951877823284, "Axis 3": -0.05772042572038993, "Axis 4": 0.027408339030792893, "Axis 5": -0.014306525498770059, "Confidence": "0.7909375392457091", "Feature ID": "4132561a08d25757e4bee9f73ec4a70a", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Neisseriales; f__Neisseriaceae; g__Neisseria; s__oralis", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.01035357714955025, "Axis 2": -0.0021997360809056948, "Axis 3": 0.01113688305072321, "Axis 4": 0.0014314220080007772, "Axis 5": -0.006291155409673585, "Confidence": "0.7737813345100648", "Feature ID": "3a1c2d5547ddb7f76306a042f8bef6a4", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Oxalobacteraceae; g__Massilia", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.010866668864726783, "Axis 2": -0.008547063284311403, "Axis 3": -0.023787841879536455, "Axis 4": -0.026600452126541007, "Axis 5": 0.01959444069517445, "Confidence": "0.9973290313734372", "Feature ID": "30faafef155964edd9db9374f36c45bf", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.06339280466322551, "Axis 2": 0.034097065884069265, "Axis 3": -0.017022825871145522, "Axis 4": 0.02857795485803677, "Axis 5": 0.03882437296006469, "Confidence": "0.9999984029694493", "Feature ID": "b1e22f094d8c64fb56dbacf680dab8c9", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__", "qurro_classification": "None", "qurro_spc": 8.0}, {"Axis 1": -0.024737279322327423, "Axis 2": 0.001780890688813918, "Axis 3": -0.02104590995948949, "Axis 4": 0.022046728058454753, "Axis 5": -0.010025696035164705, "Confidence": "0.9999545574424196", "Feature ID": "b92e89d105e0a6e09e5984879c4c7809", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Megamonas; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.00499709543283298, "Axis 2": -0.004177412793958145, "Axis 3": 0.0008117302892846303, "Axis 4": 0.006975263014887635, "Axis 5": 0.002868871573473661, "Confidence": "0.9900385008368525", "Feature ID": "ff3df50eea7490dd794148649c480fd3", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.005348583905416966, "Axis 2": -0.0027137247495598728, "Axis 3": -0.008288157586861978, "Axis 4": -0.009182265055480142, "Axis 5": -0.004349417707026112, "Confidence": "0.9996690616762142", "Feature ID": "3982159c2603cacc4bc4893003bda323", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Parabacteroides; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.004203587654917971, "Axis 2": -0.014596464818034798, "Axis 3": 0.04390526917739022, "Axis 4": -0.020142014837210297, "Axis 5": 0.013369930949814543, "Confidence": "0.9999719106725472", "Feature ID": "846cbaf603b77be035fe0cb61d14a23c", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": 0.03445312316335236, "Axis 2": -0.0296493408539448, "Axis 3": 0.005289141002801777, "Axis 4": 0.057910696313264516, "Axis 5": 0.04778243724310988, "Confidence": "0.9999996943418066", "Feature ID": "a5df9a825c3d8eeb228a6781c3db134c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.009528067916826555, "Axis 2": 0.003398135898953263, "Axis 3": -0.0005231217460485645, "Axis 4": 0.000772634666024979, "Axis 5": -0.0039312945157261355, "Confidence": "0.9991097278192894", "Feature ID": "8da02c7114ba0d9ee40312926e037a8f", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.01837353147728977, "Axis 2": 0.005135231184952951, "Axis 3": 0.02029492315927462, "Axis 4": -0.0074330936221167305, "Axis 5": 0.0005808862118742226, "Confidence": "0.8656250097934397", "Feature ID": "7eedfc5c8d0d6b8852fabb20d52a8c5d", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__Flavobacterium; s__succinicans", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.017853195724276908, "Axis 2": -0.02636204209447959, "Axis 3": 0.008964078630157678, "Axis 4": 0.042008034320535875, "Axis 5": 0.012191128494816387, "Confidence": "0.9975132509654797", "Feature ID": "145f11599b92ad3a4c93896b0edf8c0c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.005261257588061949, "Axis 2": 0.008875074157924804, "Axis 3": -0.006804580508078328, "Axis 4": -0.021163487352809218, "Axis 5": -0.008004262224433763, "Confidence": "0.9564599351165705", "Feature ID": "87899779aec8d38dfaf48d895cfe8021", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Rikenellaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.04025822020809567, "Axis 2": 0.01235920861618078, "Axis 3": 0.007008701482640178, "Axis 4": -0.0027483892331994766, "Axis 5": -0.013343509057832425, "Confidence": "0.998903603258265", "Feature ID": "9d3ec96491b522546acbdfa3b21b6071", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Psychrobacter", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.01807142952043878, "Axis 2": 0.002978762570293272, "Axis 3": 0.007447176561054377, "Axis 4": -0.002952829183808343, "Axis 5": -0.003371709584518054, "Confidence": "0.9999999599575932", "Feature ID": "1d284bea12006c939c03d622ce2abd5e", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.0327273865972227, "Axis 2": -0.01906736845927857, "Axis 3": 0.023836500907835883, "Axis 4": -0.008607041357419529, "Axis 5": 0.014449465537130994, "Confidence": "0.9644387874118897", "Feature ID": "d46bfd723f625e317606ae28580eba3e", "Taxon": "k__Bacteria", "qurro_classification": "None", "qurro_spc": 9.0}, {"Axis 1": 0.006068250912129451, "Axis 2": -0.007602303184543357, "Axis 3": 0.006003715073857178, "Axis 4": 0.028485995082470027, "Axis 5": 0.004284751058165605, "Confidence": "0.9420256738876459", "Feature ID": "d3e265209c342d15d93a910e38ad9be2", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.09428697985323656, "Axis 2": 0.06317164117465288, "Axis 3": -0.05352670729611291, "Axis 4": 0.05716705761750452, "Axis 5": 0.03003440265489542, "Confidence": "0.9999999410271148", "Feature ID": "e8fb2b3d01d369dbb5d3764548193ae9", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Parvimonas; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.05031864424126368, "Axis 2": 0.01911330997493681, "Axis 3": 0.00637165779360242, "Axis 4": -0.0056319871184768505, "Axis 5": -0.018373857905417495, "Confidence": "0.9687879625820189", "Feature ID": "1b963d0d7457ac133aed9497f03b5a64", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Sphingomonadales; f__Sphingomonadaceae; g__Sphingomonas", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0016682497552694474, "Axis 2": 0.002160500801112463, "Axis 3": 0.0004262498874400199, "Axis 4": -1.4067361415598595e-06, "Axis 5": -0.0038803022062870213, "Confidence": "0.7290668587474988", "Feature ID": "fb4f7d9d3f91ac2f22a542fbd13019c1", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Oribacterium; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.011136907633069865, "Axis 2": -0.0035292007730316644, "Axis 3": -0.013391957197000912, "Axis 4": 0.009665485597363075, "Axis 5": -0.0014477078534354886, "Confidence": "0.999999956754622", "Feature ID": "c4f955168102011d272b685aa772c10a", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Aerococcaceae; g__Alloiococcus; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.024105334630334846, "Axis 2": 0.009102240883500904, "Axis 3": -0.0032680816642409504, "Axis 4": 0.0002023159861289732, "Axis 5": -0.009139409278270783, "Confidence": "0.9999637718126778", "Feature ID": "185df2b73b4805164470dfaea2d05223", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Enterobacteriales; f__Enterobacteriaceae", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.018000596497001115, "Axis 2": 0.004398843174735229, "Axis 3": -0.040055925954773274, "Axis 4": 0.01786301773532959, "Axis 5": -0.011775969741667102, "Confidence": "0.9906830844572889", "Feature ID": "513de43781dc4c2831eb83b23940d66b", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Veillonella; s__dispar", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.046239937786063716, "Axis 2": -0.0003619213727271617, "Axis 3": -0.06932860646225465, "Axis 4": 0.03673355349574234, "Axis 5": -0.016202264155268417, "Confidence": "0.7153312379710223", "Feature ID": "24443b70088636edf08f0c9572d7faf4", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Gemellales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.04006216246762562, "Axis 2": 0.010682112765352473, "Axis 3": -0.04670176547525562, "Axis 4": 0.026638434382955444, "Axis 5": -0.008557387972002485, "Confidence": "0.9407660429381492", "Feature ID": "475741f076c42d2c75d2d63c14fe4d3f", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae; g__Aggregatibacter; s__segnis", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.02173160857569391, "Axis 2": 0.009074512588388761, "Axis 3": -0.016090436944351128, "Axis 4": 0.003726019580077626, "Axis 5": -0.01147057265705783, "Confidence": "0.9999972038258291", "Feature ID": "848587c4a03949500c5815bd6edb7b6e", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__melaninogenica", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.015611878495109447, "Axis 2": -0.031991286609931315, "Axis 3": 0.05711127124407835, "Axis 4": -0.03428009984499687, "Axis 5": 0.02921442603370206, "Confidence": "0.9999588589418271", "Feature ID": "2f4c5e75c0e4cdfcbddbe93ef1f410a3", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__1-68; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.01032352884849615, "Axis 2": 0.001380149130665124, "Axis 3": 0.023291021012831255, "Axis 4": 0.024887148127320586, "Axis 5": -0.026475237412666365, "Confidence": "0.9174790673639953", "Feature ID": "ed950935b660fb10449d5f229dc13fb9", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.03449572974622592, "Axis 2": 0.02005362431159184, "Axis 3": 0.005282833613626769, "Axis 4": 0.003928359391883669, "Axis 5": -0.01583317471245775, "Confidence": "0.8655003325990382", "Feature ID": "626b8ee112be0ec208bb16445611d001", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Sphingobacteriia; o__Sphingobacteriales; f__Sphingobacteriaceae; g__Pedobacter; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.03433648409691715, "Axis 2": -0.0251433488296833, "Axis 3": -0.025591202792447722, "Axis 4": 0.020323707288369852, "Axis 5": 0.06206530931675069, "Confidence": "0.9991191526445343", "Feature ID": "bb370945a6777f712cfd963c55f2ff54", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Blautia; s__obeum", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.0031415261805519687, "Axis 2": -0.0029058229035710853, "Axis 3": 0.0021160667963708506, "Axis 4": -0.00015515515803076236, "Axis 5": -0.007401858936170485, "Confidence": "0.9762673079160837", "Feature ID": "59fefb91cc66ef6930b0201e4bf24cbb", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Ruminococcus; s__flavefaciens", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.013723420238687863, "Axis 2": -0.024941514069882664, "Axis 3": 0.015612920277800476, "Axis 4": 0.05979217701083854, "Axis 5": 0.014583422697846682, "Confidence": "0.9999978377628835", "Feature ID": "1f0a072da4906270a684a389c1586582", "Taxon": "k__Bacteria; p__Proteobacteria; c__Deltaproteobacteria; o__Desulfovibrionales; f__Desulfovibrionaceae; g__Bilophila; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.01442434651959139, "Axis 2": -0.002818848529594206, "Axis 3": 0.009129221496998288, "Axis 4": 0.04605051491196479, "Axis 5": 0.014479616716637356, "Confidence": "0.805127918950262", "Feature ID": "aa668eb01ca9dcc59aeb1454b600c8c8", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.03639960764127133, "Axis 2": -0.005048228362998272, "Axis 3": -0.015679898157385665, "Axis 4": 0.016862784776679473, "Axis 5": -0.0023718167532648187, "Confidence": "0.8475985645371472", "Feature ID": "8cd2a871fab61bdea4ef23a295c371cf", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Carnobacteriaceae; g__Granulicatella; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.10520781789293886, "Axis 2": 0.06898424114890078, "Axis 3": -0.03985402532134436, "Axis 4": 0.018716777580404857, "Axis 5": 0.06264739586750591, "Confidence": "0.9999999417370747", "Feature ID": "3a69cb2f27ac76a05405efbb5088d249", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__Capnocytophaga; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.0225891522911369, "Axis 2": 0.015223933977877895, "Axis 3": -0.003915050334452562, "Axis 4": 0.0008940969708139847, "Axis 5": 0.019390928246354886, "Confidence": "0.8785385254229211", "Feature ID": "44543d9c6bb193c64d38c9bdb6790eec", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Actinomycetaceae; g__Actinomyces; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.029318696255007295, "Axis 2": -0.021471530952852327, "Axis 3": -0.05481516060870411, "Axis 4": -0.06121822450120288, "Axis 5": 0.058025766182413535, "Confidence": "0.986092983892428", "Feature ID": "5437cb1c86c72638cbbc12896f88d1b1", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Ruminococcus; s__lactaris", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.04091179673182258, "Axis 2": 0.020844310581526564, "Axis 3": 0.004428336060497016, "Axis 4": 0.0022345356165588423, "Axis 5": -0.01619691356421287, "Confidence": "0.955601884458892", "Feature ID": "724c43ad3632cb8c5c6230c874551bd2", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Pseudomonadaceae; g__Pseudomonas; s__viridiflava", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.07277914752414885, "Axis 2": -0.0057263622875007, "Axis 3": 0.09961088700752148, "Axis 4": -0.05523989570331762, "Axis 5": 0.020494081019431155, "Confidence": "0.999999992909153", "Feature ID": "9590aed21545774c71a124f2b5200691", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__ph2; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.04206115660144539, "Axis 2": -0.026179678669552637, "Axis 3": -0.019999498826722778, "Axis 4": 0.04364454779794894, "Axis 5": 0.07057286886849178, "Confidence": "0.9949926072117541", "Feature ID": "cba5f5b1153235425628bd77a28257c7", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Clostridiaceae; g__Clostridium; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.032377892541001214, "Axis 2": -0.022841656832494936, "Axis 3": -0.02788864525609714, "Axis 4": 0.01415425091548319, "Axis 5": 0.058149041878132426, "Confidence": "0.9956645108439693", "Feature ID": "2fa276cce32e900f0f68d30e460b8f61", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": -0.024932926239533113, "Axis 2": -0.0069184060103739484, "Axis 3": -0.013234794608234643, "Axis 4": 0.008623880087124431, "Axis 5": 0.0010031465990818272, "Confidence": "0.9999999996367137", "Feature ID": "24523c45ca39b6c81a01ce286c0c092b", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Leptotrichia; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.0070900099065655045, "Axis 2": 0.004293059661080954, "Axis 3": -0.0005555101866314949, "Axis 4": -0.008428535270031763, "Axis 5": -0.012817946303004406, "Confidence": "0.9857077983339365", "Feature ID": "91d0b3b7c0329b9a164b6e04a181f1d6", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.024792935553089004, "Axis 2": 0.007776219673795433, "Axis 3": 0.0036889722306842573, "Axis 4": -0.00157493323814641, "Axis 5": -0.00908849237326641, "Confidence": "0.9591829681018331", "Feature ID": "c99439f78b73ffcf55858ae828aac608", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Psychrobacter; s__pulmonis", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.0042643281815740825, "Axis 2": -0.0004922459251995301, "Axis 3": 0.0016965816315364526, "Axis 4": 0.013082199896975157, "Axis 5": 0.003770613611895213, "Confidence": "0.9929738438255035", "Feature ID": "84755bc954af6d3b39bb4c369e5992e7", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.0037011824478312668, "Axis 2": 0.002821011347620241, "Axis 3": -0.0013965157410967457, "Axis 4": 0.002852029031212432, "Axis 5": -0.006448740101094042, "Confidence": "0.9931024657896309", "Feature ID": "063fa4f5a6fa894f7f8243468324ac5e", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Acinetobacter; s__lwoffii", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.004289040009790504, "Axis 2": 0.03182634858715974, "Axis 3": 0.013810321673830468, "Axis 4": 0.013764451421048849, "Axis 5": 0.005039069372451233, "Confidence": "0.9999911857418131", "Feature ID": "49232f27012731b0a65805c0919e2bbc", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0399330745913786, "Axis 2": -0.031560354839224404, "Axis 3": -0.0470356307093604, "Axis 4": -0.0001313650483264741, "Axis 5": 0.08768790227713102, "Confidence": "0.998754751628425", "Feature ID": "4b8228f4d7d3809aa6827e8d9e11a9ae", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.008484519589210175, "Axis 2": -0.01240864303167473, "Axis 3": 0.009680087120991568, "Axis 4": 0.016147576548187027, "Axis 5": 0.011653652674130792, "Confidence": "0.8020812046700789", "Feature ID": "f023384b8f989d014dd2ead7f10db307", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Ruminococcus; s__callidus", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.00163220134780486, "Axis 2": 0.0068403874749906135, "Axis 3": -0.01208106347955469, "Axis 4": -0.0010790722258893117, "Axis 5": -0.0026824566443013204, "Confidence": "0.7952806765114179", "Feature ID": "4ce1be9cea00a1eb7f960600e1ff3cfa", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Acinetobacter; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.02864717999501918, "Axis 2": 0.018018709359936626, "Axis 3": -0.010385309582305683, "Axis 4": -0.004246428637323008, "Axis 5": -0.013283729930968996, "Confidence": "0.993393689329706", "Feature ID": "1b75626f6834620dc2c729a1a81f497a", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Acinetobacter; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.002953229954825219, "Axis 2": -0.01951370023539883, "Axis 3": 0.0038084643734328815, "Axis 4": 0.031883433385007626, "Axis 5": 0.009900231416597714, "Confidence": "0.9350726816419417", "Feature ID": "b5bf6383b53e0add0d6589b73949462a", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.02795261534305823, "Axis 2": 0.008721199004094233, "Axis 3": 0.004338187653930309, "Axis 4": -0.0016539040000985875, "Axis 5": -0.010022772541363247, "Confidence": "0.785607893370775", "Feature ID": "344b020d867e3210563eaf40b0c557ef", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Xanthomonadales; f__Xanthomonadaceae; g__Xanthomonas", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.015288179655810832, "Axis 2": -0.005770022420377895, "Axis 3": -0.0285362351268749, "Axis 4": -0.025184857262266047, "Axis 5": 0.029929658456474825, "Confidence": "0.9918685937608366", "Feature ID": "136e9f5aa470119165e59d202fdb318c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.07863756911229164, "Axis 2": 0.01587727903304156, "Axis 3": -0.00021151587375863306, "Axis 4": 0.006677610008310882, "Axis 5": 0.04637170559984204, "Confidence": "0.9615396835933923", "Feature ID": "ca96b8fd01aa6c508305bacac37da6c2", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Fusobacteriaceae; g__Fusobacterium; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.0032357257717623503, "Axis 2": -0.004614211544468113, "Axis 3": -0.0026455123105380463, "Axis 4": -0.0019578385145357143, "Axis 5": -0.0015778739342928285, "Confidence": "0.7173595608652419", "Feature ID": "07b2b1c3771f46d82c90b20a79fb3d04", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Neisseriales; f__Neisseriaceae; g__Kingella; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.043460987088331675, "Axis 2": 0.01682112117411976, "Axis 3": 0.004674170425390746, "Axis 4": -0.0054960127747602245, "Axis 5": -0.017042367223892498, "Confidence": "0.7124092571658878", "Feature ID": "dd7e1e45831871f719cc3cd68f568e7c", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Lactobacillaceae; g__Lactobacillus", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.033610352364541546, "Axis 2": -0.014359727999149278, "Axis 3": -0.004051869670987613, "Axis 4": 0.008110284115911744, "Axis 5": 0.0025670801763102583, "Confidence": "0.9988059612946599", "Feature ID": "51ddb685cfb1775931489ebbd3eef6ca", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Paludibacter; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.03639167749498094, "Axis 2": -0.0002934296917379019, "Axis 3": -0.055063908668448826, "Axis 4": 0.029105853166521926, "Axis 5": -0.013381605950780796, "Confidence": "0.712305817313309", "Feature ID": "16564bc936c839c893f951bab613a30b", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Sphingomonadales; f__Erythrobacteraceae; g__Erythromicrobium; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.028009501638360232, "Axis 2": 0.008557775781940957, "Axis 3": 0.004489591309933497, "Axis 4": -0.0017960384802289486, "Axis 5": -0.010020447243945614, "Confidence": "0.9229137931177458", "Feature ID": "4a5387c4bc61f2d8f3d9d2de983ba556", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__[Weeksellaceae]; g__Chryseobacterium; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.02348308764392459, "Axis 2": 0.007935980215146868, "Axis 3": 0.002818293442595768, "Axis 4": -0.000833555184852666, "Axis 5": -0.008900882173765659, "Confidence": "0.9717233647886103", "Feature ID": "c5b61a414bdb4305544bb4f941e0bfc9", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.048562682615365615, "Axis 2": -0.027755020721757374, "Axis 3": 0.028839242542541253, "Axis 4": 0.0245828048423685, "Axis 5": -0.0026944894594436624, "Confidence": "0.9342962626361514", "Feature ID": "465e9cab9abce306c1e0f7459b325c33", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Ruminococcus; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.025921700959958733, "Axis 2": -0.0025158409091951455, "Axis 3": -0.03909149976040855, "Axis 4": 0.020390402598516336, "Axis 5": -0.013356992333952508, "Confidence": "0.9990271839583306", "Feature ID": "7cdabbffaaa6cc6d9f478d91f312a8ee", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.03597780681068634, "Axis 2": 0.039525431011776815, "Axis 3": -0.041184033835941325, "Axis 4": 0.02148133908514597, "Axis 5": 0.012253375087975128, "Confidence": "0.9999999999998721", "Feature ID": "3e2c7eb0316409806267a8d9845b0b13", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__[Prevotella]; s__tannerae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.008074166591769332, "Axis 2": -0.006730148303000945, "Axis 3": 0.0057203402456876065, "Axis 4": 0.027003506243922185, "Axis 5": 0.005869227396545924, "Confidence": "0.7679735559093147", "Feature ID": "77a517253ff10afeb78a37bc13d649a0", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.008893390483515319, "Axis 2": 0.005364414713086859, "Axis 3": -0.0038669922760150095, "Axis 4": -0.0011697998547795488, "Axis 5": -0.00538955927998605, "Confidence": "0.9733980627805193", "Feature ID": "62bf37c50994a06e6c8c93355ad1caa0", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Pseudomonadaceae; g__Pseudomonas", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.04134814029545221, "Axis 2": -0.03214262453270531, "Axis 3": -0.03229120128605616, "Axis 4": 0.01972263484257933, "Axis 5": 0.08222061199836016, "Confidence": "0.994490308435181", "Feature ID": "fea5c05e9b8245c5ca46f6673f59e0bf", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.02657622104550795, "Axis 2": 0.010483283366824993, "Axis 3": 0.0022374020860127446, "Axis 4": -0.003983712775656102, "Axis 5": -0.01193672795120518, "Confidence": "0.9999999993900656", "Feature ID": "dd222108ed685d6a936d2011ea220998", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.010549171707220311, "Axis 2": -0.0011362735510885567, "Axis 3": -0.013304155166115529, "Axis 4": 0.006469555429330181, "Axis 5": -0.0034192900223062456, "Confidence": "0.9722250180468371", "Feature ID": "30a88dc67e6a522087c3dfc8019550a6", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Micrococcaceae; g__Rothia; s__aeria", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.0012059139846769212, "Axis 2": 0.0031229043225982998, "Axis 3": -0.011353739861240473, "Axis 4": 0.00850585380196902, "Axis 5": -0.007848106841399782, "Confidence": "0.999995138789156", "Feature ID": "126d3c82f184c4d9058cab124f287968", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Intrasporangiaceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.015193396764811054, "Axis 2": -0.0004101641293370931, "Axis 3": -0.020498330736528316, "Axis 4": 0.00988644974096019, "Axis 5": -0.007802832039788948, "Confidence": "0.999698730867463", "Feature ID": "9616cf56be891f816aa7abc6a13c9e8f", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Selenomonas; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.043904039285775354, "Axis 2": -0.020909466946980697, "Axis 3": -0.05698723104380806, "Axis 4": -0.029998391688783824, "Axis 5": 0.0844808412092883, "Confidence": "0.9999798313174182", "Feature ID": "ae881162d813e498f40bf33b8e42d54a", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.019453733144986583, "Axis 2": -0.014507568930733891, "Axis 3": 0.011765402737333893, "Axis 4": 0.04196351057631818, "Axis 5": 0.01274584523361176, "Confidence": "0.9989737678620044", "Feature ID": "32875774cffdc8c820f91d8e86f9a0e6", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Coprococcus; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.02058098560512401, "Axis 2": 0.010600362493568022, "Axis 3": -0.005767294056233352, "Axis 4": 0.004740862798621236, "Axis 5": -0.01315027324350455, "Confidence": "0.9778564644357421", "Feature ID": "14d168c89e381de6fc3091837a557e48", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Bacillales; f__Bacillaceae; g__Bacillus", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.006464993784670799, "Axis 2": -0.005227765605877006, "Axis 3": -0.003364221373025761, "Axis 4": 0.00018176452114549127, "Axis 5": 0.0027792456875617173, "Confidence": "0.997901111050797", "Feature ID": "868a4fe285b85fa1b8eb40071d5397be", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Clostridium; s__lavalense", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.07005192449619943, "Axis 2": -0.03491955342330977, "Axis 3": -0.012009456616035816, "Axis 4": 0.004546517500511769, "Axis 5": 0.02045285139948835, "Confidence": "0.9950919478250861", "Feature ID": "38aff035451e491e5905508b9a173fb6", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Lactobacillaceae; g__Lactobacillus; s__helveticus", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": 0.01768050545660955, "Axis 2": -0.0038109484996928307, "Axis 3": -0.038928494819520654, "Axis 4": -0.03678248203429785, "Axis 5": 0.03973585824767198, "Confidence": "0.9971580442708626", "Feature ID": "201b6484b6abe3d4c587464be6cbd574", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.014730495063852468, "Axis 2": -0.002718064819054104, "Axis 3": -0.021283567478175034, "Axis 4": -0.013838727101594676, "Axis 5": 0.025434083576484922, "Confidence": "0.9847013272156114", "Feature ID": "67f9c74eeea5a4609bd1d2fab66ad3cc", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.044403387313431956, "Axis 2": -0.020652601223201325, "Axis 3": -0.00873485918786062, "Axis 4": 0.0006251983797443579, "Axis 5": 0.01566373383223978, "Confidence": "0.7779518198168166", "Feature ID": "2e202c4e4e803dbc6d54c9e3117afedd", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Aerococcaceae; g__Abiotrophia; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.003668418027877322, "Axis 2": -0.0020551562110563497, "Axis 3": 0.0041071945122555875, "Axis 4": 0.014651268745511483, "Axis 5": 0.0019258507758233548, "Confidence": "0.9628589979651925", "Feature ID": "0c4b17f88dae47697d3bceb3663f47ce", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__[Ruminococcus]; s__torques", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.02414354236531051, "Axis 2": -0.01567595471339506, "Axis 3": -0.008593847800447082, "Axis 4": 0.028073539994202215, "Axis 5": 0.03703469482255616, "Confidence": "0.7400148422878492", "Feature ID": "fc1f49989e78fa71bc6404ff2a148576", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.01623921893171035, "Axis 2": -0.0002343529711746499, "Axis 3": -0.02260837145924734, "Axis 4": 0.011091986644684436, "Axis 5": -0.007850251885434908, "Confidence": "0.9929207907548342", "Feature ID": "c18826df5af5da174f580164c805a38a", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus; s__anginosus", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0012669892069271402, "Axis 2": 7.184826970275135e-05, "Axis 3": -4.634569188242835e-05, "Axis 4": 0.002009875448147674, "Axis 5": -0.0027075103927885207, "Confidence": "0.9944915065245113", "Feature ID": "919764896275058362e55f0849d2b38b", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.014345857616992327, "Axis 2": -0.005557925612053426, "Axis 3": -0.010163043948388295, "Axis 4": 0.002785205856731088, "Axis 5": 0.018402174038894402, "Confidence": "0.8015059534818364", "Feature ID": "4b13979d719e78a50cb0eac34d72dec1", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae; g__Methylibium; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.05898813799025467, "Axis 2": -0.033942522675440755, "Axis 3": 0.02200545794506672, "Axis 4": 0.003472978142201757, "Axis 5": 0.01693954926756204, "Confidence": "0.9999999999183748", "Feature ID": "0bd7addf1b999f01ad58fec8412b8931", "Taxon": "k__Bacteria; p__Proteobacteria; c__Epsilonproteobacteria; o__Campylobacterales; f__Campylobacteraceae; g__Campylobacter", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.010604555489612056, "Axis 2": 0.01115485522598413, "Axis 3": -0.007194202042682941, "Axis 4": -0.02152786771096379, "Axis 5": -0.011051326583686924, "Confidence": "0.9572154761327839", "Feature ID": "b8b19c4f0719a5d5b965a0f50f05827c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Roseburia; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.07784686452628632, "Axis 2": -0.03769221615839265, "Axis 3": 0.017870401427135266, "Axis 4": -0.0038148009235485806, "Axis 5": 0.02154560796384187, "Confidence": "0.9893859948303412", "Feature ID": "1c7d1f74c2c43b872972f974eb196915", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Clostridiaceae; g__Clostridium; s__hiranonis", "qurro_classification": "None", "qurro_spc": 8.0}, {"Axis 1": 0.0002842179830861542, "Axis 2": -0.002021944207896776, "Axis 3": 0.0027820047117567037, "Axis 4": -0.00380375781627455, "Axis 5": -0.001286747555424706, "Confidence": "0.97304019825929", "Feature ID": "d8f7f446987e67092b6256c10b1ee69e", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus; s__luteciae", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.010508370855099331, "Axis 2": -0.012006273435267743, "Axis 3": 0.00624426043728005, "Axis 4": 0.026892977377127366, "Axis 5": 0.008856656711014469, "Confidence": "0.9999999671639591", "Feature ID": "9e1c6b703a4312cce306c7757688a351", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Odoribacteraceae]; g__Odoribacter; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.010352066695723305, "Axis 2": -0.010269870954260305, "Axis 3": 0.005950142201557386, "Axis 4": 0.027118152279967805, "Axis 5": 0.010016370622677774, "Confidence": "0.7718189260622333", "Feature ID": "a0b0961c7ba318abff3e5a93f09f495e", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.03532096660120185, "Axis 2": 0.01359003559817301, "Axis 3": 0.003604731451199542, "Axis 4": -0.004414532594059224, "Axis 5": -0.014287553985851449, "Confidence": "0.9999999978408027", "Feature ID": "96a7dbb0e2c57e289c05b82e2db880be", "Taxon": "k__Bacteria; p__Cyanobacteria; c__Chloroplast; o__Streptophyta; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.0049771063486559195, "Axis 2": -0.00158469260618067, "Axis 3": 0.0018096837945186205, "Axis 4": 0.00849781565116398, "Axis 5": 0.00029452675066940644, "Confidence": "0.9753418330938859", "Feature ID": "24dfe6a7325e4f2be7dbd522ef613e42", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Roseburia; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.057085028212951194, "Axis 2": -0.026432215776509196, "Axis 3": 0.00873569575131395, "Axis 4": -0.0030349292524820596, "Axis 5": 0.011534610321403942, "Confidence": "0.9999998128718521", "Feature ID": "1edc5497d3daf6d914427d32b71daa52", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Parvimonas; s__", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": -0.005671157932115266, "Axis 2": -0.004410543499879878, "Axis 3": 0.009270863777857654, "Axis 4": -0.001043637286516979, "Axis 5": -0.001515077823867277, "Confidence": "0.9992636753455588", "Feature ID": "6fea19332b7fb980e2124d0339c596c2", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.005915004994860867, "Axis 2": -0.002984797892849849, "Axis 3": -0.01423658055112118, "Axis 4": -0.016910867311996605, "Axis 5": 0.008630962647817823, "Confidence": "0.9999999305672086", "Feature ID": "55937e5781c91185e27a91216008e4ca", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.030116998236325535, "Axis 2": -0.015803603378137878, "Axis 3": -0.01696082369531139, "Axis 4": 0.01623718947061016, "Axis 5": 0.0464007155413955, "Confidence": "0.9920177082468982", "Feature ID": "43a9c44adeac51fd3ab95081da56d02d", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.008194741586397271, "Axis 2": -0.003920471667273676, "Axis 3": -0.0014186904566639762, "Axis 4": 0.0008056602031096398, "Axis 5": 0.00043914808908185365, "Confidence": "0.9995250392794505", "Feature ID": "f3194c2eb241f821239009ca55dbb30c", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__copri", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.03384432839450913, "Axis 2": 0.013003901396412663, "Axis 3": 0.0034107301644074792, "Axis 4": -0.004218346975469069, "Axis 5": -0.013787817838255013, "Confidence": "0.9999703090697017", "Feature ID": "ecf9eb9fa3970ff27a221e626395c75d", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rickettsiales; f__mitochondria; g__Raphanus; s__sativus", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.015336167939168185, "Axis 2": -0.008371980834773666, "Axis 3": -0.019687506070985655, "Axis 4": -0.010739054014033913, "Axis 5": 0.023892720368687097, "Confidence": "0.8739714578120822", "Feature ID": "823698689031b0b9c2c5152f92ffc70f", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.004811522896097674, "Axis 2": 0.000692059656760412, "Axis 3": 0.01151300081842744, "Axis 4": 0.01284317574339304, "Axis 5": -0.014888262506648257, "Confidence": "0.8296866048462425", "Feature ID": "3b65e1db6742cc44493248fff266f564", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0239736630487734, "Axis 2": -0.014521221514758851, "Axis 3": 0.0062625443298443976, "Axis 4": -0.010659603566887988, "Axis 5": 0.014044267819788046, "Confidence": "0.9935932009352713", "Feature ID": "10710d3d706451c3536228e4b7d146db", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.021791891909727412, "Axis 2": 0.013199021764514896, "Axis 3": -0.008939507100087092, "Axis 4": -0.002234355294527517, "Axis 5": -0.010366821610694743, "Confidence": "0.9540567647955874", "Feature ID": "b428acd97e6af974db1b053a2bc2b5c8", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.02314766907481476, "Axis 2": -0.014238309284375706, "Axis 3": 0.005500771292520823, "Axis 4": 0.000634035308371979, "Axis 5": 0.004047784479788531, "Confidence": "0.891376189191897", "Feature ID": "7f4909ae8d31a3995fa2c200c690a21f", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Caulobacterales; f__Caulobacteraceae; g__Brevundimonas", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.0012420182545551973, "Axis 2": -0.00854943855220191, "Axis 3": 0.021768269477612835, "Axis 4": -0.009558356413661309, "Axis 5": 0.008119908125195498, "Confidence": "0.9998361987269812", "Feature ID": "e7a3af060bcc6686986ddfdf5536fac8", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__durum", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.00940966094593414, "Axis 2": -0.002172560963540753, "Axis 3": -0.005330000498766105, "Axis 4": 0.005024845536392569, "Axis 5": -0.00239902450932303, "Confidence": "0.9693629412283876", "Feature ID": "aadef7fba5a0754fb631409c11fb331f", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae; g__Aggregatibacter; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.002563155957365868, "Axis 2": -0.0018656097450193332, "Axis 3": -0.003780522600932057, "Axis 4": -0.004176487099818141, "Axis 5": -0.00013700404353021804, "Confidence": "0.9996922563908524", "Feature ID": "b00d44992702bd3743d7f353638d42f9", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Clostridium", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.019284862586917858, "Axis 2": 0.006447894832145491, "Axis 3": 0.0021231692540611656, "Axis 4": -0.0006507633497527147, "Axis 5": -0.007737839989069959, "Confidence": "0.9524048183615398", "Feature ID": "e22afe3cb91239d19aeb01ba79015173", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.01623170177814488, "Axis 2": 0.006685070730406982, "Axis 3": -0.011561362021855292, "Axis 4": 0.00016932639356282285, "Axis 5": -0.008391681560134793, "Confidence": "0.9689772414414087", "Feature ID": "dab4d3e6078cfc510502a47c98e82081", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Veillonella; s__dispar", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.019959746270761147, "Axis 2": -0.01881145811803803, "Axis 3": 0.010182841811997963, "Axis 4": -0.014837584974189081, "Axis 5": 0.017870056472133775, "Confidence": "0.9999977902381723", "Feature ID": "7dd981802694dec3ecdb61ee53805956", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.01454576546219153, "Axis 2": 0.006298137442689687, "Axis 3": 0.007841524324713968, "Axis 4": -0.0011311302394948184, "Axis 5": -0.0045347512788966255, "Confidence": "0.9932181769991136", "Feature ID": "bfdc8d2e7693336b4f3781920d3fa253", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rickettsiales; f__mitochondria; g__Cucurbita; s__pepo", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.021956358956114433, "Axis 2": 0.12331944371897906, "Axis 3": -0.016613388944641358, "Axis 4": 0.044558703693112545, "Axis 5": 0.0542595064474456, "Confidence": "0.9998117035543563", "Feature ID": "0dcaf9358eddf685864afb883cdf2363", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Moryella; s__", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": 0.05262999929956726, "Axis 2": 0.15708547574797152, "Axis 3": 0.07615385698206083, "Axis 4": 0.013056188318624843, "Axis 5": 0.08893990648049546, "Confidence": "0.9999999998645563", "Feature ID": "9b0549bb6e63f681bf133d2c7996055d", "Taxon": "k__Bacteria; p__Firmicutes; c__Erysipelotrichi; o__Erysipelotrichales; f__Erysipelotrichaceae; g__Bulleidia; s__moorei", "qurro_classification": "None", "qurro_spc": 8.0}, {"Axis 1": -0.01416912214766668, "Axis 2": -0.01034672977422787, "Axis 3": 0.009688669180342223, "Axis 4": -0.00787118313040791, "Axis 5": 0.008525587487723182, "Confidence": "0.7054879293393869", "Feature ID": "ed75725613954c459019eec50b431f9f", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.0023119389633842803, "Axis 2": 0.02620182460469045, "Axis 3": 0.0004008754491632283, "Axis 4": 0.00878304144689757, "Axis 5": 0.008861312829402338, "Confidence": "0.9996740314861042", "Feature ID": "9f1913b781d2cde1c8a4c57b7dc2ab83", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Oribacterium; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.04182312323977441, "Axis 2": 0.08104123084264758, "Axis 3": -0.005028449678366363, "Axis 4": 0.015829243742504162, "Axis 5": 0.054379120755705376, "Confidence": "0.9966085648122125", "Feature ID": "4fccea69a702bcb90cc0147c0fff2995", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.025110701828286047, "Axis 2": 0.0568144096465121, "Axis 3": -0.019948925317711867, "Axis 4": 0.010394522140177885, "Axis 5": 0.02598451826626768, "Confidence": "0.9999918346793044", "Feature ID": "7f99061140cbf6c9081a204380efd8e1", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.03532210077486676, "Axis 2": -0.02513755212052839, "Axis 3": 0.016543279220100706, "Axis 4": -0.011856252933277696, "Axis 5": 0.018393483366336727, "Confidence": "0.9995729889203091", "Feature ID": "50e96bbd1a8267119529843a1acb43a5", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Nocardiaceae; g__Rhodococcus; s__fascians", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.030136897626438446, "Axis 2": 0.011532280274884236, "Axis 3": 0.0029236465061096514, "Axis 4": -0.003725779063222531, "Axis 5": -0.012533118372184862, "Confidence": "0.9970102380850145", "Feature ID": "2de266b1ffa8e9ec6383c98096caf8f0", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Microbacteriaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.03769349641176014, "Axis 2": -0.02445961226290711, "Axis 3": 0.014393602985050687, "Axis 4": -0.007625483276622759, "Axis 5": 0.016104120604179113, "Confidence": "0.9829793160137641", "Feature ID": "2ca928ad9749bb9726c35d6528fefec1", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhizobiales; f__Methylobacteriaceae; g__Methylobacterium; s__adhaesivum", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.024910405629297732, "Axis 2": -0.01311747420651664, "Axis 3": 0.003920185600812238, "Axis 4": 0.0018169219875791246, "Axis 5": 0.005760126947433406, "Confidence": "0.9858179696769461", "Feature ID": "5a02c9985adcd7543dff8c846cff62a5", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhodobacterales; f__Rhodobacteraceae; g__Paracoccus; s__marcusii", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.018946662510292304, "Axis 2": -0.0018726638974820612, "Axis 3": -0.029197649032260166, "Axis 4": 0.01514514163631955, "Axis 5": -0.010588699637392424, "Confidence": "0.9999998749553007", "Feature ID": "9acad60e1ad588fb9250aab68dee645d", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Fusobacteriaceae; g__Fusobacterium; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.02690279039545447, "Axis 2": 0.03542640126586526, "Axis 3": 0.0008553949421472035, "Axis 4": 0.02905960441449003, "Axis 5": 0.013139371343704511, "Confidence": "0.9999853730895673", "Feature ID": "cfe4948493ea1b183b006512be10924a", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__[Prevotella]; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.003034313447389754, "Axis 2": 0.11585407747925822, "Axis 3": 0.011774487664667354, "Axis 4": 0.018419984265902262, "Axis 5": 0.057389389449277746, "Confidence": "0.999997737790675", "Feature ID": "53729ba7429e5bd2fe96229b14452bdc", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__Capnocytophaga", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.0007611482856685337, "Axis 2": 0.0024965164020640117, "Axis 3": -0.011091031882867766, "Axis 4": 0.004458580443684524, "Axis 5": -0.006166150791454575, "Confidence": "0.9999998722619746", "Feature ID": "9da7a39de7e82006cc9533681adf765a", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Fusobacteriaceae; g__Fusobacterium; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.00910357598277239, "Axis 2": 0.0044959296301510104, "Axis 3": 0.011932900872687887, "Axis 4": -0.0033130085911343464, "Axis 5": -0.0064340316331445825, "Confidence": "0.9990592114034101", "Feature ID": "7ee56e891d069e18c3c8eb866924a26c", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Nocardioidaceae; g__Aeromicrobium; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.01894011468979505, "Axis 2": 0.008134215429418655, "Axis 3": -0.0005091000801706103, "Axis 4": -0.00034875475562205565, "Axis 5": -0.00951445834563303, "Confidence": "0.9769762371456536", "Feature ID": "955d8fcbb35e8bc04c8df0c6aae34d34", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhizobiales; f__Rhizobiaceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.042744558643798336, "Axis 2": -0.03254064535010821, "Axis 3": -0.014464131115836353, "Axis 4": 0.026312718314239033, "Axis 5": 0.05335643791610474, "Confidence": "0.9979579551901666", "Feature ID": "c04b03fdea7f81c8c52fc540c50a24a4", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Blautia; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.01680356098427702, "Axis 2": 0.005568382991886898, "Axis 3": 0.0017123259239336744, "Axis 4": -0.0005427268183080273, "Axis 5": -0.007050440338589588, "Confidence": "0.9997733656407869", "Feature ID": "f99678fdc17d27a97c79faac3f2980a4", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Neisseriales; f__Neisseriaceae; g__Conchiformibius; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.015263671102305993, "Axis 2": 0.004453052933201474, "Axis 3": 0.0019832064585727865, "Axis 4": -0.0009183598664314781, "Axis 5": -0.006547906092520517, "Confidence": "0.9999999999999141", "Feature ID": "54a5af5112600a1faf06be268f95616e", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rickettsiales; f__mitochondria", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.017729610771432033, "Axis 2": 0.012468847924636895, "Axis 3": -0.013162873949542771, "Axis 4": 0.009233841334751339, "Axis 5": -0.01689398663425861, "Confidence": "0.7117140223130716", "Feature ID": "8b111e12f8f73205bac732c7479a97e8", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Pseudomonadaceae; g__Pseudomonas; s__viridiflava", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.013882846148335848, "Axis 2": -0.00230043471525753, "Axis 3": -0.04499368839356741, "Axis 4": -0.05091511982673276, "Axis 5": 0.04028205383551613, "Confidence": "0.9652597238343168", "Feature ID": "3add7df323955b22d1cea664ef38165d", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.056594219914112814, "Axis 2": -0.026910390675986693, "Axis 3": -0.0568828921000195, "Axis 4": -0.013362166834532478, "Axis 5": 0.10584366536133603, "Confidence": "0.9079699344129013", "Feature ID": "a1b971c01ce0b220275c218adbe717c1", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Subdoligranulum; s__variabile", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.008712186261926182, "Axis 2": 0.005172299701239001, "Axis 3": -0.003145984391630901, "Axis 4": -0.001097210373586032, "Axis 5": -0.005254373734207807, "Confidence": "0.7776037753918941", "Feature ID": "01b99cb344ed2530f7d80897ffe257a9", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae; g__Acidovorax", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.019781467530355493, "Axis 2": -0.0001779106895551641, "Axis 3": -0.031004875048918742, "Axis 4": 0.016240869883097368, "Axis 5": -0.008624245398744472, "Confidence": "0.999870776947763", "Feature ID": "4ab53e40e06f3a9b0b9b2669d8a52f65", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.005980867198950709, "Axis 2": -0.0007705785963857396, "Axis 3": -0.014973204458621858, "Axis 4": -0.01574293844960214, "Axis 5": 0.010433758296522594, "Confidence": "0.9907840422123194", "Feature ID": "66a605fcdaa020dbdd6136f241ea79d9", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.028520661571552145, "Axis 2": -0.029757373534344628, "Axis 3": 0.034565884687237966, "Axis 4": -0.01510838707208818, "Axis 5": 0.023382533480763874, "Confidence": "0.9999999923322633", "Feature ID": "0be23adca941c1335eb04db17dc66e98", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__endodontalis", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.03327854186230128, "Axis 2": -0.02037553176754413, "Axis 3": 0.009065737016958134, "Axis 4": -0.010676006296394439, "Axis 5": 0.01590758809233698, "Confidence": "0.9959180901576317", "Feature ID": "e73fc2655e1cca4a2b1c419da3630c72", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Lactobacillaceae; g__Lactobacillus", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.013437895887437502, "Axis 2": 0.0037997219722799938, "Axis 3": 0.0016745983082882723, "Axis 4": -0.0008423364093836478, "Axis 5": -0.006044073321424787, "Confidence": "0.8704891323015692", "Feature ID": "7a20f7055ca2c7462cfa6a7aef16ec28", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Enterococcaceae; g__Enterococcus", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.01918653583142723, "Axis 2": -0.00017377311896613778, "Axis 3": -0.030143147125170505, "Axis 4": 0.015780081826968554, "Axis 5": -0.008453849925016872, "Confidence": "0.9001078812622654", "Feature ID": "39b5567d2d979a9172c02435a5ede59d", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.008975536732038198, "Axis 2": 0.0006034030067679016, "Axis 3": -0.01890783516158932, "Axis 4": -0.018251255317764836, "Axis 5": 0.015097999148055949, "Confidence": "0.999326980024856", "Feature ID": "c57b70d65a63c4bf9f12c179c2416839", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.023834945617984406, "Axis 2": -0.025557142890867267, "Axis 3": 0.014920347183715205, "Axis 4": 0.05936412260221452, "Axis 5": 0.0228081993698909, "Confidence": "0.7852865158778395", "Feature ID": "5df503c1ddf8f3f4ac9e49e983e3d7fd", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.04912696040287474, "Axis 2": -0.023200207749096008, "Axis 3": 0.014496430993936127, "Axis 4": -0.00036229650897406034, "Axis 5": 0.01089561071557049, "Confidence": "0.9999376911888057", "Feature ID": "28560cffcd31045fa07dd88557b43e05", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Clostridiaceae; g__Clostridium; s__perfringens", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.02660917656012456, "Axis 2": -0.009862574003908801, "Axis 3": -0.012487506903801609, "Axis 4": 0.005124942808759067, "Axis 5": 0.004687997085837612, "Confidence": "0.9966632930278283", "Feature ID": "da247df6fe91b74bf38d3ecc1c05b4b0", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Micrococcaceae; g__Micrococcus", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.009155122118328906, "Axis 2": 0.041458506644302555, "Axis 3": -0.007000368282933693, "Axis 4": 0.008953533190394122, "Axis 5": 0.020022583131050195, "Confidence": "0.9999999420308273", "Feature ID": "6be3ad080a12e28c46c9ca4f94710ac7", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Leptotrichia; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.002327086396086458, "Axis 2": 0.02982472383239497, "Axis 3": -0.0005355838288956753, "Axis 4": 0.0030000621848694812, "Axis 5": 0.013663669024552547, "Confidence": "0.9999995257954523", "Feature ID": "95f07780b7e9b8b504c2563e63950663", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.009457635735926447, "Axis 2": 0.0211220241936373, "Axis 3": 0.041639848094790426, "Axis 4": -0.014618353779128321, "Axis 5": 0.022905831495742473, "Confidence": "0.9999756253127183", "Feature ID": "7f2aa6f3481a4039dcc8d1b8be32beb7", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Lachnoanaerobaculum; s__orale", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.0022356439600685835, "Axis 2": -0.00018038429793359792, "Axis 3": 0.0013327596330915167, "Axis 4": -0.0011042873523557477, "Axis 5": -0.0025300195696019542, "Confidence": "0.9996141401422101", "Feature ID": "41cb0c62655aa8da8968a06cde0f14a1", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Tannerella; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.012086827591453546, "Axis 2": -0.0026672581394578355, "Axis 3": -0.020819018971685605, "Axis 4": -0.01823763575464264, "Axis 5": 0.0187782760709845, "Confidence": "0.8368653694709228", "Feature ID": "ebd1dcd162acede67bb633c42c7b2ac2", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Coprococcus; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.07231895936091663, "Axis 2": 0.008083789125815703, "Axis 3": 0.003619232253226912, "Axis 4": 0.017921161481038277, "Axis 5": 0.035401594651386585, "Confidence": "0.9921378560668366", "Feature ID": "88b4862756df007aa0c6bc2ba049708b", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.0034501370045101117, "Axis 2": -0.00021363094562932135, "Axis 3": 0.0030618581705286834, "Axis 4": -0.0020120084649509007, "Axis 5": -0.0022324783866751164, "Confidence": "0.9998328109943339", "Feature ID": "498ae808db957a63e20e836e1bf77f54", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Oribacterium; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.010037503193706871, "Axis 2": 0.0007745221815017246, "Axis 3": 0.007509632218921965, "Axis 4": -0.003570244145898264, "Axis 5": 0.0010390309531158946, "Confidence": "0.9999999990888", "Feature ID": "3b74a95b189e134bb34c191b7693455d", "Taxon": "k__Bacteria; p__Cyanobacteria; c__Chloroplast; o__Streptophyta; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.016688947596745666, "Axis 2": -0.00015640314583827256, "Axis 3": -0.02652551920632308, "Axis 4": 0.013845643252351726, "Axis 5": -0.007738511120257095, "Confidence": "0.7308884297928181", "Feature ID": "6be678de197b54f9a04f6c984b91ef22", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Sphingomonadales; f__Sphingomonadaceae; g__Blastomonas; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0040574567853884835, "Axis 2": 0.0029073683827774504, "Axis 3": -0.0013616547807951034, "Axis 4": -0.004682953485074549, "Axis 5": -0.007446136366256602, "Confidence": "0.9999999113367195", "Feature ID": "80b20e907aa4fcf2309796bc303d151d", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0917459482190679, "Axis 2": -0.043668565486856624, "Axis 3": -0.0005493598799644467, "Axis 4": -0.001320399543359517, "Axis 5": 0.023173665444220923, "Confidence": "0.8232558062116176", "Feature ID": "58d6cee566e26e231916ccc2093ae053", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Clostridium; s__colinum", "qurro_classification": "None", "qurro_spc": 6.0}, {"Axis 1": 0.008543576387430234, "Axis 2": -0.005362689318374009, "Axis 3": 0.02251571817304759, "Axis 4": -0.009006181192314602, "Axis 5": 0.0048689571523579025, "Confidence": "0.9997856789187582", "Feature ID": "acba6a53153faccd2c02a9c0e8a2d941", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.005616403175468089, "Axis 2": 0.0019745845586225173, "Axis 3": -0.00013099534593164215, "Axis 4": -0.00015413574224248732, "Axis 5": -0.004099514777857829, "Confidence": "0.9915045847832368", "Feature ID": "f094a383692eb30761eb3d5c93240236", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Neisseriales; f__Neisseriaceae; g__Conchiformibius; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0028295245891016355, "Axis 2": 5.526957161960813e-05, "Axis 3": 0.0011152568692001917, "Axis 4": -0.0008226571921393103, "Axis 5": -0.002027151670135565, "Confidence": "0.9999999979509937", "Feature ID": "ba0941f03086680ee946a10dfe90cf12", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Leptotrichia; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0160326785899802, "Axis 2": -0.00015183899276697118, "Axis 3": -0.025574947351370492, "Axis 4": 0.013337348064064036, "Axis 5": -0.00755054791624227, "Confidence": "0.7339563163981687", "Feature ID": "c9f68eb27669d95f1e365fc085b51ee6", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Enterobacteriales; f__Enterobacteriaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.07928591092216562, "Axis 2": -0.06823571518690025, "Axis 3": -0.028392426901692733, "Axis 4": 0.0767546836217122, "Axis 5": 0.1127097109591539, "Confidence": "0.9999999977203187", "Feature ID": "7fee9350277038eef98dee70b4190563", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales", "qurro_classification": "None", "qurro_spc": 7.0}, {"Axis 1": -0.07204598616911792, "Axis 2": -0.04287663718954408, "Axis 3": 0.027700745569339824, "Axis 4": -0.013981052422489789, "Axis 5": 0.026712937213759707, "Confidence": "0.8145189208104493", "Feature ID": "1a4ff0ff25ff4e919711422c2f605519", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhodobacterales; f__Rhodobacteraceae; g__Rubellimicrobium; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.028969734082379028, "Axis 2": -0.014895349352549036, "Axis 3": 0.0067479952803693325, "Axis 4": -0.0022694772733944006, "Axis 5": 0.008588956179983438, "Confidence": "0.9999727340019683", "Feature ID": "5042942b77f5b924b8f8c11de37a3626", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Micrococcaceae; g__Rothia; s__dentocariosa", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.0026990679565906625, "Axis 2": 0.0019166313527800693, "Axis 3": -0.0037237440694912935, "Axis 4": 0.0020944567600038318, "Axis 5": -0.005144955391934102, "Confidence": "0.9927524116508102", "Feature ID": "5decdad9c550489629ce441d32a69a1c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Blautia; s__producta", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.009299721691612842, "Axis 2": -0.0005100006652210468, "Axis 3": 0.011964931646005903, "Axis 4": -0.00677639442744784, "Axis 5": -0.0009926490700194258, "Confidence": "0.9999999950396727", "Feature ID": "101968ec709b68fcd964a68ff226dcd1", "Taxon": "k__Bacteria; p__Synergistetes; c__Synergistia; o__Synergistales; f__Dethiosulfovibrionaceae; g__TG5; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.004972168588206219, "Axis 2": -0.00017875871816684186, "Axis 3": 0.004905829488857676, "Axis 4": -0.002929158632330638, "Axis 5": -0.0017510131083204694, "Confidence": "0.9999999748181526", "Feature ID": "bb173654871d294466912ef22f685faa", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Dialister; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.019070491579035148, "Axis 2": 0.0071396003038855, "Axis 3": 0.0014697378887996069, "Axis 4": -0.0022555003543692632, "Axis 5": -0.008787933464465611, "Confidence": "0.9999999999999684", "Feature ID": "f9bc8716f02b0a22f03b1a686895aae1", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rickettsiales; f__mitochondria", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.02252582569336681, "Axis 2": -0.026127267538541433, "Axis 3": 0.016234205075976244, "Axis 4": 0.06525663041814274, "Axis 5": 0.022957905178605187, "Confidence": "0.9999999999388791", "Feature ID": "34e40677eda6fb724e9323b0835d5ab0", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Odoribacteraceae]; g__Butyricimonas; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.04117792126390124, "Axis 2": -0.023205125758129358, "Axis 3": 0.023603710239539548, "Axis 4": -0.009406022882646952, "Axis 5": 0.018402274536617063, "Confidence": "0.9997864914543096", "Feature ID": "ce0a68ef210192a51f60ec3eb8e3e92e", "Taxon": "k__Bacteria; p__Proteobacteria; c__Epsilonproteobacteria; o__Campylobacterales; f__Campylobacteraceae; g__Campylobacter; s__ureolyticus", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.053240450198291725, "Axis 2": -0.07243760977469443, "Axis 3": 0.052570252061628096, "Axis 4": -0.1027963399923997, "Axis 5": 0.09031883711060805, "Confidence": "0.999999999947704", "Feature ID": "48eda83fda558aea8fdd32b9c8dfff98", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__WAL_1855D; s__", "qurro_classification": "None", "qurro_spc": 8.0}, {"Axis 1": 0.04121411366768698, "Axis 2": -0.018944708873401148, "Axis 3": -0.023840797028554985, "Axis 4": 0.003798894231880547, "Axis 5": 0.05499518285837749, "Confidence": "0.999918830896101", "Feature ID": "0f55566622d8244073432b2e67b24baa", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.0020704870636965834, "Axis 2": 0.0029267438797485872, "Axis 3": -0.002568529976658251, "Axis 4": -0.005588820517847653, "Axis 5": -0.004889158497081418, "Confidence": "0.8587515680106617", "Feature ID": "956d0a6f5a8e1d2fbb39df909cc14894", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Coprococcus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.07825367007590929, "Axis 2": -0.03241799563408322, "Axis 3": -0.012283677275358736, "Axis 4": 0.00856949933751214, "Axis 5": 0.01905233190308135, "Confidence": "0.9838778812968548", "Feature ID": "5fb5ace22c46fefb30969da7bb0dcb74", "Taxon": "k__Bacteria", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": 0.0011781462581517703, "Axis 2": -0.0010347097941758576, "Axis 3": -0.000490197253150911, "Axis 4": -0.0017839177348298897, "Axis 5": -0.0007773897681383357, "Confidence": "0.9999909731425789", "Feature ID": "0f2a155a57fe6d0bf34767080706b3e1", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Enterobacteriales; f__Enterobacteriaceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.06712721249644919, "Axis 2": -0.03380135070924589, "Axis 3": -0.0014056659042028603, "Axis 4": -0.00550928482852174, "Axis 5": 0.021047912505221276, "Confidence": "0.9992464577991468", "Feature ID": "aa9f89f9af07d53e077462471423f3ab", "Taxon": "k__Bacteria; p__Firmicutes; c__Erysipelotrichi; o__Erysipelotrichales; f__Erysipelotrichaceae; g__Catenibacterium; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.03480706914447931, "Axis 2": -0.016337759085676785, "Axis 3": -0.007387411260260895, "Axis 4": 0.00189386444644834, "Axis 5": 0.008236217175841805, "Confidence": "0.92202728645503", "Feature ID": "921966b15e5f1508e8650d053443c385", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__[Weeksellaceae]; g__; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.0019577629553963792, "Axis 2": -0.01599785426396846, "Axis 3": 0.035449984795928195, "Axis 4": -0.02182245318939674, "Axis 5": 0.01740243763064722, "Confidence": "0.9986461374377613", "Feature ID": "1a5ff65c7f309159df626f810d96ae8b", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Cardiobacteriales; f__Cardiobacteriaceae; g__Cardiobacterium; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.024742049926751136, "Axis 2": -0.011490073779646627, "Axis 3": -0.001820960824891632, "Axis 4": 0.0011342336489370526, "Axis 5": 0.007234929064512146, "Confidence": "0.7342325732125753", "Feature ID": "f32674aec6d3fa6a7aa2323cb35699fc", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Blautia; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.017506320872189913, "Axis 2": 0.0065187211037413635, "Axis 3": 0.0012642365489893034, "Axis 4": -0.0020476851994368156, "Axis 5": -0.008258573842264876, "Confidence": "0.9325293168155139", "Feature ID": "ecbf086d6ccbe5e8c2a69d0afb144662", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Micrococcaceae; g__Arthrobacter", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.00324460833100698, "Axis 2": 0.007506557775997406, "Axis 3": -0.0019309338252507633, "Axis 4": 0.0016201938080043444, "Axis 5": 0.00044365906568606743, "Confidence": "0.9919495400741297", "Feature ID": "1c40ac02c49ea9e03881b0f183373417", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Micrococcaceae; g__Rothia; s__mucilaginosa", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.01669736462632099, "Axis 2": 0.006197615418352509, "Axis 3": 0.001157955571058658, "Axis 4": -0.0019402075649093851, "Axis 5": -0.007984800160903843, "Confidence": "0.8956114729901508", "Feature ID": "3f448350064694e647b284259bdebb91", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.01669736462632099, "Axis 2": 0.006197615418352509, "Axis 3": 0.001157955571058658, "Axis 4": -0.0019402075649093851, "Axis 5": -0.007984800160903843, "Confidence": "0.9013688351379086", "Feature ID": "c9a1082e87563e01347729352358bbcf", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Bacillales; f__Planococcaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.009507939309929327, "Axis 2": -0.0011442774271922971, "Axis 3": -0.02456592564826244, "Axis 4": -0.026418361646060047, "Axis 5": 0.019451537545717473, "Confidence": "0.9998782498264798", "Feature ID": "816b94bcd935ca38afe71fd1e3c5356c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Dorea; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.03116858804475557, "Axis 2": -0.014055916240101274, "Axis 3": 0.0007503063834597685, "Axis 4": 0.002675935896509251, "Axis 5": 0.009799849010951826, "Confidence": "0.9574848934610196", "Feature ID": "bfbf3b84b315e741c4345ebb43e2b9cc", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Geodermatophilaceae; g__Blastococcus; s__aggregatus", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.04238634885044217, "Axis 2": -0.03605470798818688, "Axis 3": 0.03385115932004602, "Axis 4": -0.01948920996566902, "Axis 5": 0.028081801042292725, "Confidence": "0.9999999754236913", "Feature ID": "37c7d17f9e371c1e11a0e22b1ce15ab0", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Peptoniphilus; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.06856070353794728, "Axis 2": 0.1564582145859381, "Axis 3": 0.14401146837258186, "Axis 4": -0.05165820967168272, "Axis 5": 0.12509321694054185, "Confidence": "0.9993999015917799", "Feature ID": "fe98555e63f547c33b3987391cd34d5d", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 8.0}, {"Axis 1": 0.015021426603965419, "Axis 2": 0.005532371494362934, "Axis 3": 0.0009377701990107833, "Axis 4": -0.0017175430448229138, "Axis 5": -0.007417615316907298, "Confidence": "0.7371380275016326", "Feature ID": "d329ff7ff76454d2282c9f01c2798588", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhizobiales; f__Brucellaceae; g__Ochrobactrum; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.016786321565871416, "Axis 2": -0.020751688327956767, "Axis 3": -0.02918884622069374, "Axis 4": -0.014163355339276295, "Axis 5": 0.04426066625482244, "Confidence": "0.9999872271687765", "Feature ID": "ee7ce85e38500b28d9d79b63c7fbf9a6", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Dialister; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.04273196138675392, "Axis 2": -0.028085185018381, "Axis 3": 0.0643580507553782, "Axis 4": -0.010850559610272056, "Axis 5": 0.04370608979110787, "Confidence": "0.9559872430385798", "Feature ID": "8659c05e82a2d1399cbc3fd26ab938e4", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.016995262212028867, "Axis 2": -0.011868188100433818, "Axis 3": -0.008039478737325844, "Axis 4": -0.0010786780211682115, "Axis 5": 0.01552635201365304, "Confidence": "0.9987167204816891", "Feature ID": "3677e15d86603bf0a6bb50f8b010afe7", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Clostridium; s__hathewayi", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.045788927695983285, "Axis 2": -0.019938598811704903, "Axis 3": 0.007504158131824356, "Axis 4": 0.004042902274053664, "Axis 5": 0.0093067998751784, "Confidence": "0.9999999999999574", "Feature ID": "30ebe1a33c21c25c55e4fdbb5894b832", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__[Prevotella]; s__tannerae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.04539860378112661, "Axis 2": -0.027148189286350145, "Axis 3": 0.011791225345756159, "Axis 4": -0.012822751288253062, "Axis 5": 0.02394072641268282, "Confidence": "0.9706084029685352", "Feature ID": "30273eb317696f87e7b6fd37ada4bb8f", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Enhydrobacter; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.03617848809106428, "Axis 2": -0.018686898210313125, "Axis 3": -0.03358433571520985, "Axis 4": -0.010324262786893596, "Axis 5": 0.05336554176852038, "Confidence": "0.7029392152404603", "Feature ID": "54b4964000ad1631e547c46a828ed1a0", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.002023340284748299, "Axis 2": 0.0006372482255885156, "Axis 3": -0.0009661873623701695, "Axis 4": 0.00033420674695014245, "Axis 5": -0.002984593002277101, "Confidence": "0.9999997661307906", "Feature ID": "55ec4b057c122957d25013675512c73d", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.03044918838583634, "Axis 2": -0.026415138915431482, "Axis 3": 0.05709051749182485, "Axis 4": -0.023940903954428466, "Axis 5": 0.02673956448878017, "Confidence": "0.9999999805512803", "Feature ID": "072698f9668d5a094cdc1a672acc4747", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Anaerococcus; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.010158721965178759, "Axis 2": -0.0010623169180774218, "Axis 3": -0.016732259401991613, "Axis 4": 0.008536569968647245, "Axis 5": -0.0071008921070976755, "Confidence": "0.9882360418387107", "Feature ID": "8c43291754ba53fa1e206f0ac7a18772", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Selenomonas; s__noxia", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.013883892709975884, "Axis 2": -0.00024734285098388417, "Axis 3": 0.01685358640313763, "Axis 4": -0.00908477394582605, "Axis 5": 0.0006810810218895602, "Confidence": "0.999999996655319", "Feature ID": "a5185df881810390f29afa3ba3ccf522", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Leptotrichia; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.00027552390023201064, "Axis 2": 0.0006648403576165708, "Axis 3": -0.0012969351357406233, "Axis 4": -0.0012071847489014398, "Axis 5": -0.003195181700639625, "Confidence": "0.9997421553977021", "Feature ID": "1893b0ad352ee7db0f565bc4594e6dc6", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.005195612763396229, "Axis 2": 0.09573284825273261, "Axis 3": 0.006302778112689907, "Axis 4": 0.01979630812161532, "Axis 5": 0.046403368765432766, "Confidence": "0.9984148773250179", "Feature ID": "d3f59bdb915bb43f2ecd96ad9296ae92", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Peptostreptococcaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.020402688379924695, "Axis 2": -0.01392701194137147, "Axis 3": -0.06353572248487686, "Axis 4": -0.08572622138648041, "Axis 5": 0.051681937217450694, "Confidence": "0.9976471110735871", "Feature ID": "2b148d88c49e316f85b6e7863089a886", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Coprococcus; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.015285552559132422, "Axis 2": -0.011206328455596881, "Axis 3": 0.00696970831500126, "Axis 4": 0.03317684719338412, "Axis 5": 0.01348343321087553, "Confidence": "0.7670245986392509", "Feature ID": "cbb7ea319a7633cf0917c6e5cde0e923", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.017411177528779964, "Axis 2": -0.03056645004980421, "Axis 3": 0.06865697480844847, "Axis 4": -0.04189822410195765, "Axis 5": 0.04216840767370405, "Confidence": "0.9999996985716023", "Feature ID": "a70441600c181b747a763ce5a7414a3f", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Peptoniphilus; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.005350386764298217, "Axis 2": -0.0014966655002539005, "Axis 3": -0.0037966176648119277, "Axis 4": 0.0028456676643727422, "Axis 5": -0.0013557923343457204, "Confidence": "0.7197191851538617", "Feature ID": "68c05655a58355526692d3a1f0968aff", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Microbacteriaceae; g__Salinibacterium", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.011409227414768026, "Axis 2": 0.004098551430136345, "Axis 3": 0.00046319810160914054, "Axis 4": -0.0012376275657356313, "Axis 5": -0.006195144911510211, "Confidence": "0.9999999994104058", "Feature ID": "f8026fa73c97b3f69cf4369cf194fb8b", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Anaerococcus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.013611689579808043, "Axis 2": -0.0005606110820668351, "Axis 3": -0.03319178975784299, "Axis 4": -0.03489146477772278, "Axis 5": 0.028141781739923207, "Confidence": "0.9996515020757827", "Feature ID": "edacf632dcadc21c328669befafe2af6", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Coprococcus; s__catus", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.020277191275591508, "Axis 2": -0.007642091587454594, "Axis 3": -0.024336351373867637, "Axis 4": -0.015544993071601731, "Axis 5": 0.03181971267951232, "Confidence": "0.9720704829075013", "Feature ID": "e2c355360209f0b71b70b85ed0f9532d", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Shuttleworthia; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.020459213999688454, "Axis 2": -0.01075220014195061, "Axis 3": 0.009427902095627895, "Axis 4": -0.0005974509632060754, "Axis 5": 0.005618110850107012, "Confidence": "0.9977060808607247", "Feature ID": "97e0a84031c426df75af82aeff951f26", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__Capnocytophaga; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.019586327181580147, "Axis 2": -0.0004505297124238859, "Axis 3": 0.025170941766449215, "Axis 4": -0.013482414677903736, "Axis 5": 0.002011338168860442, "Confidence": "0.969880964288689", "Feature ID": "1f926dee6544b252d38067cc7753383a", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Cardiobacteriales; f__Cardiobacteriaceae; g__Cardiobacterium", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0015915328228041003, "Axis 2": -0.0006039879909680663, "Axis 3": -0.0005836263821694397, "Axis 4": 0.0012507201185754473, "Axis 5": -0.002244935255493284, "Confidence": "0.9996147551119303", "Feature ID": "3b795f0122b28b0e6a07bec73894acee", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Ruminococcus; s__bromii", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.018374090332988785, "Axis 2": -0.01595222734799514, "Axis 3": 0.00917020130601831, "Axis 4": 0.038447591103233175, "Axis 5": 0.01539167800520551, "Confidence": "0.8411550294883348", "Feature ID": "e2f0caba18b002ca9762ed56167c6188", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.015009870204998683, "Axis 2": -0.0013358538829430031, "Axis 3": -0.034201848605042405, "Axis 4": -0.03415375161972031, "Axis 5": 0.031037211838547754, "Confidence": "0.9687251036465712", "Feature ID": "02ef9a59d6da8b642271166d3ffd1b52", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.01053967036851265, "Axis 2": -0.005213081685296001, "Axis 3": -0.002933653626958015, "Axis 4": 0.0006686639498756648, "Axis 5": 0.0008236508165913364, "Confidence": "0.8719338683216702", "Feature ID": "3bb6760ebcd348e0c695a5fb5fccf994", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Sphingomonadales; f__Sphingomonadaceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.011580734179210864, "Axis 2": 0.08852383790594608, "Axis 3": -0.006091254666803417, "Axis 4": 0.029388193956717924, "Axis 5": 0.04003453520434629, "Confidence": "0.9999989418046397", "Feature ID": "42872dc875fef6070dfa78984184c096", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Mogibacteriaceae]; g__; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.005979736441169675, "Axis 2": -8.192381117055376e-05, "Axis 3": -0.011013778428851245, "Axis 4": 0.005551117006833809, "Axis 5": -0.00467126640730844, "Confidence": "0.982245621057858", "Feature ID": "7103ca740aeadee8bdf7cedaefac990b", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Enterobacteriales; f__Enterobacteriaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 7.735755617029661e-05, "Axis 2": -0.00028132698532884985, "Axis 3": -0.0011236608999280852, "Axis 4": 0.0002462280027688877, "Axis 5": -0.002425794073597377, "Confidence": "0.854052663454411", "Feature ID": "de391a8294254c47e8f460325eea85f8", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhizobiales; f__Brucellaceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.008433818077734792, "Axis 2": 0.002917497622394006, "Axis 3": 7.228769613450473e-05, "Axis 4": -0.0008423157563167388, "Axis 5": -0.00518818220874922, "Confidence": "0.9558938267210237", "Feature ID": "1efd43e712291698f34853dac3b67f54", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Psychrobacter; s__sanguinis", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.030657121789874765, "Axis 2": -0.020427722707384882, "Axis 3": -0.05115851938588531, "Axis 4": -0.056129895591741225, "Axis 5": 0.05384293825037883, "Confidence": "0.9910410640079611", "Feature ID": "c7ec57695a6d83b461eba523752755ec", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Ruminococcus; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.04234025254136775, "Axis 2": -0.017962733877723073, "Axis 3": -0.008544581596009501, "Axis 4": 0.0030482439536386866, "Axis 5": 0.010101049536480947, "Confidence": "0.9104021814838891", "Feature ID": "b1141c1ab18997c3339e8229e0b9f41a", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides; s__coprophilus", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.02032327019432754, "Axis 2": -0.00836156940784047, "Axis 3": -0.003996296778252359, "Axis 4": 0.002739931122652737, "Axis 5": 0.00421204759174489, "Confidence": "0.9297295545455417", "Feature ID": "dc7d3610c77e7c118082f25002f26cd4", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Bacteroidaceae; g__Bacteroides; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.023429639629731987, "Axis 2": -0.0004590274618722057, "Axis 3": 0.030234633409461434, "Axis 4": -0.016076403972541807, "Axis 5": 0.0030901198327837713, "Confidence": "0.9999812762063819", "Feature ID": "4516f28133b919f8d8039ece23d8dd2e", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.00437016165303776, "Axis 2": -0.0003353339384804627, "Axis 3": 0.009076250889165688, "Axis 4": -3.8481952381634914e-08, "Axis 5": -0.0012216610582813955, "Confidence": "0.9999779321388014", "Feature ID": "2cec2792e54f61e12e1a0b2507826118", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Oxalobacteraceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.010331254997408584, "Axis 2": -0.0036730661144331296, "Axis 3": 0.007829123356929965, "Axis 4": -0.0001428294438257026, "Axis 5": 0.0007653984739697884, "Confidence": "0.9057073208689316", "Feature ID": "66fb1fc4317badb5dfaec2bf8e5055d7", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0029637374100710285, "Axis 2": -0.0010205258536929507, "Axis 3": -0.0019069658897923549, "Axis 4": 0.0006382883669004141, "Axis 5": -0.0016208156904979655, "Confidence": "0.8783025380437198", "Feature ID": "bcb349a220a0c33a6b780dbc29a25f71", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Sphingobacteriia; o__Sphingobacteriales; f__Sphingobacteriaceae; g__Pedobacter; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.024472998138224736, "Axis 2": -0.0004351224157333424, "Axis 3": 0.031498682845100025, "Axis 4": -0.0167051139421322, "Axis 5": 0.003420166134119556, "Confidence": "0.9999958910580067", "Feature ID": "ce1d8d111ba2aaec28d68a04e483bf3f", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Mogibacteriaceae]; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.04752988013249994, "Axis 2": -0.020268975277354242, "Axis 3": -0.030949777353849153, "Axis 4": 0.009270849550215586, "Axis 5": 0.07231779864609948, "Confidence": "0.9998564450158812", "Feature ID": "74c2326ccd0bc2bd9e0f23f15b79ea16", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Blautia; s__producta", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.01804000653175665, "Axis 2": -0.0109137401463014, "Axis 3": 0.0021243028312609553, "Axis 4": 0.003256054553113456, "Axis 5": 0.003394096745561441, "Confidence": "0.9993459392413974", "Feature ID": "ac809fd715cced98911f73f1dfb1ffb9", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhodobacterales; f__Rhodobacteraceae; g__Paracoccus", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.014783179381485306, "Axis 2": 0.0069896823239766264, "Axis 3": 0.0015641250481467682, "Axis 4": 0.00046414442075546546, "Axis 5": -0.0070728471271285604, "Confidence": "0.9999981527761016", "Feature ID": "22ed70e219c67c2bf4e20e0b144b12bb", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Sphingobacteriia; o__Sphingobacteriales; f__Sphingobacteriaceae; g__Sphingobacterium; s__faecium", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.00703127431071753, "Axis 2": 0.0021045389244630313, "Axis 3": 9.427240087438465e-05, "Axis 4": -0.00011723885853286157, "Axis 5": -0.004343205379062938, "Confidence": "0.9280493436642588", "Feature ID": "cf8a25fe1a1b134a027842e7769a285b", "Taxon": "k__Bacteria; p__Bacteroidetes; c__[Saprospirae]; o__[Saprospirales]; f__Chitinophagaceae; g__Flavisolibacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.025339042103550057, "Axis 2": 0.0653952832526021, "Axis 3": 0.05353157537999059, "Axis 4": -0.02792490790145796, "Axis 5": 0.04512153402346141, "Confidence": "0.7116952010524998", "Feature ID": "04c7e0ea3038f942f5a28778a74cd1c0", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__[Prevotella]; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.05766723523615654, "Axis 2": 0.1367039483652594, "Axis 3": -0.017734527053440148, "Axis 4": 0.02782555263095473, "Axis 5": 0.09283174618941134, "Confidence": "0.9999999426373892", "Feature ID": "a875cba4e2e4da128cec805cd014731f", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Parvimonas; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.00211707289207129, "Axis 2": -5.506015081287122e-05, "Axis 3": -0.00541890922571609, "Axis 4": 0.00255939672789243, "Axis 5": -0.0035649538902839946, "Confidence": "0.99708108001927", "Feature ID": "b8329e527429f07e08f04ecf93563779", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae; g__Aggregatibacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.00211707289207129, "Axis 2": -5.506015081287122e-05, "Axis 3": -0.00541890922571609, "Axis 4": 0.00255939672789243, "Axis 5": -0.0035649538902839946, "Confidence": "0.9999693651606395", "Feature ID": "d9efe89c658c7996e7738e1bb777c9f0", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Selenomonas", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.028015964047209737, "Axis 2": -0.017413770292956116, "Axis 3": 0.004766005990748617, "Axis 4": -0.00040588230791806994, "Axis 5": 0.009458877145034012, "Confidence": "0.9448822071285029", "Feature ID": "e0f1938338e6f9b8cf8408e672ee6cd1", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Sphingobacteriia; o__Sphingobacteriales; f__Sphingobacteriaceae; g__Pedobacter; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.014079028000895832, "Axis 2": 0.006630897317151622, "Axis 3": 0.0014380159306326317, "Axis 4": 0.0004478596576200769, "Axis 5": -0.006848036336180492, "Confidence": "0.7989595935724313", "Feature ID": "c1dedbc2ee20ed310022b9a1976d56c4", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae; g__Pelomonas", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.006519775262418912, "Axis 2": 0.0019232351003810085, "Axis 3": 9.580571337665222e-06, "Axis 4": -9.496805398551226e-05, "Axis 5": -0.0042015038355475084, "Confidence": "0.9971193953497702", "Feature ID": "d5ef913e6aee3067001dc610ac8af1d1", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Micrococcaceae; g__Arthrobacter", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.04162961142677185, "Axis 2": -0.0011822532157745459, "Axis 3": 0.05709577910482851, "Axis 4": -0.030327203397269655, "Axis 5": 0.007229770235955772, "Confidence": "0.982915684319251", "Feature ID": "a621ed0faf5f6d7f3ad8f5e66cd41faf", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.023211682337880707, "Axis 2": -0.014473570135092704, "Axis 3": 0.007203152948446798, "Axis 4": -0.006171602430049565, "Axis 5": 0.011604625422765519, "Confidence": "0.9947305162541714", "Feature ID": "1c0a00b159b2154357cc9bc7499c58b2", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Pseudonocardiaceae; g__Actinomycetospora; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.02137663441557891, "Axis 2": 0.11093896942030917, "Axis 3": -0.017015896716909965, "Axis 4": 0.029376877399917237, "Axis 5": 0.057994910867253106, "Confidence": "0.9997127504780694", "Feature ID": "6de4955c509e8f32f905760cad0beeae", "Taxon": "k__Bacteria; p__Actinobacteria; c__Coriobacteriia; o__Coriobacteriales; f__Coriobacteriaceae; g__Atopobium; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.03370632285252711, "Axis 2": -0.037953373814598006, "Axis 3": 0.02492716014714248, "Axis 4": 0.09977976423790613, "Axis 5": 0.037796793558158126, "Confidence": "0.9627023033250163", "Feature ID": "8f0a7d866b4e5ebf1e34d0a44eb950a4", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Ruminococcus; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.03346691084293668, "Axis 2": -0.03725310072059164, "Axis 3": 0.025075561120578675, "Axis 4": 0.10071848102345193, "Axis 5": 0.037382579827167986, "Confidence": "0.9966501765682045", "Feature ID": "d8db52dac1023a8fa0e56e92670d7ac1", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Clostridium; s__colinum", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.0040247509616971044, "Axis 2": -0.001897314733822735, "Axis 3": 0.0003473238591278616, "Axis 4": 0.005435507316550111, "Axis 5": 0.0005077057157691233, "Confidence": "0.9271052775057103", "Feature ID": "51757b1a0a985640893725af5d87d350", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.03133870386743173, "Axis 2": -0.01177489926800732, "Axis 3": -0.004933096967196334, "Axis 4": 0.005499720287024072, "Axis 5": 0.008357826127360014, "Confidence": "0.9988407651093453", "Feature ID": "c5dfb8aa2b481cb89e2602fc20941587", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0043382541290831415, "Axis 2": -0.0005256043054363915, "Axis 3": -0.008476127144961126, "Axis 4": 0.004159551412734564, "Axis 5": -0.004790831923558911, "Confidence": "0.9999999999933351", "Feature ID": "726f76e9275bfa07ccb329dda324c58f", "Taxon": "k__Bacteria; p__Spirochaetes; c__Spirochaetes; o__Spirochaetales; f__Spirochaetaceae; g__Treponema; s__socranskii", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.004206558909797022, "Axis 2": -0.010487221409014827, "Axis 3": 0.020310895793674278, "Axis 4": -0.005499820230711432, "Axis 5": 0.006400973562468193, "Confidence": "0.9974078145162044", "Feature ID": "41c686088d124f17c99dcf9bf3acf9d5", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Methylophilales; f__Methylophilaceae; g__Methylotenera; s__mobilis", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.014642216791043753, "Axis 2": -0.03755610780571334, "Axis 3": 0.0845915498365849, "Axis 4": -0.0311203835131875, "Axis 5": 0.03443002322156369, "Confidence": "0.9999816595219104", "Feature ID": "01ce91fd8dbecf637eb5e67cdab5c5aa", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Mogibacteriaceae]; g__; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.005443533152314508, "Axis 2": 0.0015417548007615315, "Axis 3": -0.00016861900426738604, "Axis 4": -4.810818638753796e-05, "Axis 5": -0.003903350459299072, "Confidence": "0.7713914624979867", "Feature ID": "c2562f279f2b32428e71ef8e8e1cd3d8", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Xanthomonadales; f__Xanthomonadaceae; g__Lysobacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.004322538273320066, "Axis 2": -0.003728946908939443, "Axis 3": -0.006863427726674229, "Axis 4": -0.008991033995105018, "Axis 5": 0.002453207713206224, "Confidence": "0.9992661908836902", "Feature ID": "d51cd90e95b57acb614698dc580759fb", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Clostridium; s__symbiosum", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.011816443266584375, "Axis 2": 0.005478046521542155, "Axis 3": 0.0010328011259607838, "Axis 4": 0.00039553332909515374, "Axis 5": -0.0061256725409383735, "Confidence": "0.981721683982049", "Feature ID": "8c255f9dc0be58d1389877ec645f1a17", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhizobiales; f__Rhizobiaceae; g__Rhizobium", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.00032214076323369066, "Axis 2": -0.00030233746390077117, "Axis 3": -0.000993427541303298, "Axis 4": 0.00023539876071000126, "Axis 5": -0.0024429611022377027, "Confidence": "0.9982079914766592", "Feature ID": "d12759fe8dda1d65fe9077cc1ca9cf28", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__[Weeksellaceae]; g__Chryseobacterium; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.07067731995478939, "Axis 2": -0.04038531152201702, "Axis 3": 0.010861394598499404, "Axis 4": 0.00040828653809723664, "Axis 5": 0.022246626288659945, "Confidence": "0.9999999688431847", "Feature ID": "44f993a57b632b8fde0c34ed075e1d66", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Alcaligenaceae; g__Oligella; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.027550213348532027, "Axis 2": -0.014846764098356445, "Axis 3": -0.00620865334187142, "Axis 4": -0.0006126926002585379, "Axis 5": 0.006431871282534246, "Confidence": "0.9991591595144182", "Feature ID": "6401660183a33dded59f163fc63aab4d", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__Capnocytophaga; s__canimorsus", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.037412443185437676, "Axis 2": 0.01588868449788088, "Axis 3": -0.001292548242374014, "Axis 4": 0.006226503433924985, "Axis 5": 0.014900647852124523, "Confidence": "0.999999998761993", "Feature ID": "1e9fc37a1112b198ed3d0543db7863c8", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Leptotrichia; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.03362722227525994, "Axis 2": -0.00043947344521037064, "Axis 3": 0.043492626247278815, "Axis 4": -0.022837866598682026, "Axis 5": 0.006012212134870142, "Confidence": "0.9999852663690645", "Feature ID": "685ea779ee012329ec2a171f1823f8a8", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Neisseriales; f__Neisseriaceae; g__Kingella; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0010058676684552112, "Axis 2": -0.000829474821251409, "Axis 3": -0.0011679017919698864, "Axis 4": 0.00041183748109727375, "Axis 5": -0.0019935254756774214, "Confidence": "0.7662268435353211", "Feature ID": "b1413b635612c7db2c140bc671789ec7", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae; g__Polaromonas; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.04341110777540181, "Axis 2": -0.02173626852131505, "Axis 3": 0.09840462125120258, "Axis 4": -0.08400764287746927, "Axis 5": 0.05891379758627806, "Confidence": "0.9948977751013081", "Feature ID": "b0ca0d2568c23c26c6704017eae471e1", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.03855446137158246, "Axis 2": -0.04591165327981964, "Axis 3": 0.02998656830436945, "Axis 4": 0.11724270698718922, "Axis 5": 0.040529589622965045, "Confidence": "0.9758054414909917", "Feature ID": "1a8d25f7529d783a219ef689701dd4e2", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Barnesiellaceae]; g__; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.020625709402136736, "Axis 2": -0.002258604247046182, "Axis 3": -0.045035394148265157, "Axis 4": -0.04476969625350162, "Axis 5": 0.044736824987266846, "Confidence": "0.8822773605791377", "Feature ID": "491ef1635067f62c395bdffd58966092", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.01257582668182167, "Axis 2": -0.019372935028296425, "Axis 3": 0.054929666614484285, "Axis 4": -0.018339570694864575, "Axis 5": 0.014230214791818279, "Confidence": "0.9999987841154196", "Feature ID": "aa24dbd408e5d69c6b0d62846145a244", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Peptoniphilus; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.034158982464917206, "Axis 2": -0.0002132007077631352, "Axis 3": 0.04323344412044236, "Axis 4": -0.022541722223867567, "Axis 5": 0.006484140094939034, "Confidence": "0.9999991603443704", "Feature ID": "459244e45f29ce28991de0114a16f9fa", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Mogibacteriaceae]; g__Mogibacterium; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0023859679629752596, "Axis 2": -0.0013772894320418926, "Axis 3": -0.001349219891302204, "Axis 4": 0.0005951971075580339, "Axis 5": -0.0015264604889025843, "Confidence": "0.9986188894567068", "Feature ID": "bb2704c9052362b112da42bf843e7d9b", "Taxon": "k__Bacteria; p__Bacteroidetes; c__[Saprospirae]; o__[Saprospirales]; f__Chitinophagaceae; g__Flavisolibacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.07832257855829648, "Axis 2": -0.03425965515223672, "Axis 3": 0.0010317168147447643, "Axis 4": 0.005772717699868433, "Axis 5": 0.02401694631367692, "Confidence": "0.8296446638415885", "Feature ID": "7595e123b71bdae8a8c1c28b7405a5c0", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus; s__agalactiae", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": 0.003038886855447547, "Axis 2": 0.0006894138811902995, "Axis 3": -0.0005667700760001035, "Axis 4": 5.6590752664580386e-05, "Axis 5": -0.003237186772371197, "Confidence": "0.9968776329227055", "Feature ID": "cbc2f795edfaebaf35d10b85062b426d", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__[Weeksellaceae]; g__Bergeyella; s__zoohelcum", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0389149891289084, "Axis 2": -0.015617080950623944, "Axis 3": -0.006698506593372911, "Axis 4": 0.004990735796938302, "Axis 5": 0.010203253255604212, "Confidence": "0.9799402304518465", "Feature ID": "b1e686a5c5f127a8b92de2863503a9e5", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.041955248345652944, "Axis 2": -0.0007988077255961317, "Axis 3": 0.05590370370027193, "Axis 4": -0.029440596310817926, "Axis 5": 0.007866166588733315, "Confidence": "0.9999992411129481", "Feature ID": "a03aa6a23dc8f296567452ec2242a5fd", "Taxon": "k__Bacteria; p__Actinobacteria; c__Coriobacteriia; o__Coriobacteriales; f__Coriobacteriaceae; g__Atopobium", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.04428133179457525, "Axis 2": -0.0009217253239361744, "Axis 3": 0.059465384176144886, "Axis 4": -0.03134974230414132, "Axis 5": 0.008351996516427415, "Confidence": "0.9999992033329943", "Feature ID": "d32d15407d86a2044eead0d72cd3f9e7", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.009095989502583128, "Axis 2": 0.0021311443841210797, "Axis 3": 0.0009901963650244725, "Axis 4": -0.0007472052298998472, "Axis 5": -0.004855191344361827, "Confidence": "0.9999513412177715", "Feature ID": "d30b3fb9c1dc7d9f0d4bd6ce8e975238", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Microbacteriaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.0014062627529066523, "Axis 2": 0.0002704316242447357, "Axis 3": -0.0012022998394770688, "Axis 4": 0.0003662348665533285, "Axis 5": -0.003017870596427081, "Confidence": "0.9268383581575461", "Feature ID": "1e00822422afb942c9955cd450385a8b", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Dorea; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.10488640344251035, "Axis 2": 0.09355518520048348, "Axis 3": -0.03395151924995479, "Axis 4": 0.04076156303124531, "Axis 5": 0.08892000237048966, "Confidence": "0.9999997695989701", "Feature ID": "12ed71ced0f4e45c0aa5b37144e6f84b", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Mogibacteriaceae]; g__Mogibacterium; s__", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.13254320760217808, "Axis 2": -0.0626166651494192, "Axis 3": -0.0013250676897605255, "Axis 4": 0.0016656647518511409, "Axis 5": 0.04348359902525999, "Confidence": "0.7268353412067828", "Feature ID": "684b032107a3a32f6664dea4ef723a42", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rickettsiales; f__mitochondria", "qurro_classification": "None", "qurro_spc": 5.0}, {"Axis 1": -0.09935530456271889, "Axis 2": -0.05677870428979, "Axis 3": 0.006337173702976944, "Axis 4": -0.0061473720834985075, "Axis 5": 0.033217431004913485, "Confidence": "0.9999999999938965", "Feature ID": "3d6f762d8cda1915ad93d014e391c118", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Leuconostocaceae", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.02287195081017551, "Axis 2": -0.011771213102456945, "Axis 3": -0.005286051113244813, "Axis 4": -0.0002368321340242352, "Axis 5": 0.00475697463500416, "Confidence": "0.9881406365736627", "Feature ID": "87a04eba5a3dc45f9e899d8ab4c050b4", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.06106368428117304, "Axis 2": -0.025912662137266982, "Axis 3": -0.0015261894956712957, "Axis 4": 0.004760227420670258, "Axis 5": 0.01927960161345065, "Confidence": "0.999999593429874", "Feature ID": "4738a05820f1a7840410c66476953498", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__endodontalis", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.03354943914868034, "Axis 2": -0.01312853603498924, "Axis 3": -0.006342969504176308, "Axis 4": 0.0035798999433788578, "Axis 5": 0.007720518257936001, "Confidence": "0.9751580030188439", "Feature ID": "0effb4592c11dcdd619141df770563e1", "Taxon": "k__Bacteria; p__Actinobacteria; c__Thermoleophilia; o__Gaiellales; f__Gaiellaceae; g__Gaiella; s__occulta", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0400583236278134, "Axis 2": -0.0005420514479986902, "Axis 3": 0.05233867353083714, "Axis 4": -0.0274329186509309, "Axis 5": 0.0076920127308159674, "Confidence": "0.9996585654713689", "Feature ID": "e2cbf79a06f1221cf49d1bef8e5db9cd", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Peptostreptococcaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.03823220121326969, "Axis 2": -0.00011987661894755119, "Axis 3": 0.048168229065576315, "Axis 4": -0.024996174087313038, "Axis 5": 0.007772624131329734, "Confidence": "0.999992430517906", "Feature ID": "3d6555a4886c6e4a89104136dd5ca39e", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.005320003930261387, "Axis 2": -0.00254192056634876, "Axis 3": -0.0017346946477915408, "Axis 4": 0.0009850120660216935, "Axis 5": -0.0005334997050387105, "Confidence": "0.7742397885289987", "Feature ID": "74106ca246bcf2da5c4f95b82aa6867a", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhodobacterales; f__Rhodobacteraceae; g__Paracoccus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0006542917325344237, "Axis 2": 0.007505817658327304, "Axis 3": -0.0009656828361570892, "Axis 4": 0.001615193429961754, "Axis 5": 0.001807187662474372, "Confidence": "0.9999999961884214", "Feature ID": "955280212814a2050dd2f640e10fc25d", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Leptotrichia; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.021324079402989898, "Axis 2": -0.01616274939913428, "Axis 3": -0.004847426006397903, "Axis 4": -0.017119347707878443, "Axis 5": 0.029177124663799132, "Confidence": "0.9219861177870753", "Feature ID": "e80d9134b601511a2702b54268b57249", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.007317011681650508, "Axis 2": -0.0008220020204056712, "Axis 3": -0.014403176779872094, "Axis 4": -0.013658199032580556, "Axis 5": 0.010607541926942774, "Confidence": "0.9566805975328451", "Feature ID": "3111520c8424a2a5bdd46558ae7650e8", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.04248990796395716, "Axis 2": 0.05050862138637105, "Axis 3": 0.13501617352372622, "Axis 4": -0.050789373545914264, "Axis 5": 0.07144649960259754, "Confidence": "0.9727458761626698", "Feature ID": "867e71db0537674539934bf97db51bc0", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.001089047320031595, "Axis 2": -2.5146056654314753e-05, "Axis 3": -0.0007776878056378345, "Axis 4": 7.819578630399733e-05, "Axis 5": -0.0026368138386359836, "Confidence": "0.9621645177330894", "Feature ID": "c961cc0ecd0ac693e2fb7dcf7794c3e5", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__Capnocytophaga; s__ochracea", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.06068128569628161, "Axis 2": -0.025841230609399163, "Axis 3": -0.007896083733211332, "Axis 4": 0.006409180995157694, "Axis 5": 0.017826499912471802, "Confidence": "0.9997534752147893", "Feature ID": "e6df6369108817c93a749fa640528e92", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Cytophagia; o__Cytophagales; f__Cytophagaceae; g__Adhaeribacter; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0002700273152917522, "Axis 2": -0.000982257717971724, "Axis 3": 2.596482582933909e-05, "Axis 4": -0.0005444043377607813, "Axis 5": -0.0015928935958149915, "Confidence": "0.9533204770686079", "Feature ID": "f351326f9505ffc18da207391818c48e", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhodobacterales; f__Rhodobacteraceae; g__Paracoccus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0002700273152917522, "Axis 2": -0.000982257717971724, "Axis 3": 2.596482582933909e-05, "Axis 4": -0.0005444043377607813, "Axis 5": -0.0015928935958149915, "Confidence": "0.8101196745237768", "Feature ID": "d1c7ee5172f16dda522e46aaa4e5fa79", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae; g__Variovorax; s__paradoxus", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.006884174637106624, "Axis 2": -0.0031627997664928995, "Axis 3": -0.0019401959876018456, "Axis 4": 0.001192827220954142, "Axis 5": -4.140082837975263e-06, "Confidence": "0.9974565599881857", "Feature ID": "9548347b69043c274ff7a1ce599a69ef", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.0049214669458375005, "Axis 2": -0.002109764549565566, "Axis 3": -0.012567677629001826, "Axis 4": -0.01392575328318648, "Axis 5": 0.007641631064029969, "Confidence": "0.8674388246020718", "Feature ID": "02878fe3ccc81d4c884ca5574178d6a0", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.058788150264906275, "Axis 2": -0.03844111992059718, "Axis 3": 0.027111647482168776, "Axis 4": -0.0038746595534665984, "Axis 5": 0.022090755275748487, "Confidence": "0.9999892716625944", "Feature ID": "9f4cdae8a020a8d9c4f54e5abf5a5769", "Taxon": "k__Bacteria; p__[Thermi]; c__Deinococci; o__Deinococcales; f__Deinococcaceae; g__Deinococcus; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.014060097104339024, "Axis 2": -0.004694375767461704, "Axis 3": -0.004011587143125223, "Axis 4": 0.0013260825734033655, "Axis 5": 0.0014121743748123463, "Confidence": "0.9949755572544664", "Feature ID": "d9095748835ade1b8914c5f57b6acbcf", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Aeromonadales; f__Aeromonadaceae; g__Oceanisphaera; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.013584851619054676, "Axis 2": -0.004681000044451265, "Axis 3": -0.003810372471316453, "Axis 4": 0.001187133501021619, "Axis 5": 0.0012963939779094766, "Confidence": "0.9998782156971152", "Feature ID": "a826883ed572461c97a23561f7ecea3c", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__Flavobacterium; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.05069147326771816, "Axis 2": -0.0009746311724897142, "Axis 3": 0.06807440366450208, "Axis 4": -0.03578772615725946, "Axis 5": 0.010096315109530263, "Confidence": "0.9991245518556969", "Feature ID": "1ca133f4d30ab344f11e6624e841d9cd", "Taxon": "k__Bacteria; p__Spirochaetes; c__Spirochaetes; o__Spirochaetales; f__Spirochaetaceae; g__Treponema; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.04807154015385618, "Axis 2": -0.0008348854649931274, "Axis 3": 0.06405729644647544, "Axis 4": -0.03363365695371578, "Axis 5": 0.009550955685390125, "Confidence": "0.9992293660294053", "Feature ID": "6ffdeb862aed8aedda8a8624fa960c57", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Peptostreptococcaceae; g__Peptostreptococcus; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.05069147326771816, "Axis 2": -0.0009746311724897142, "Axis 3": 0.06807440366450208, "Axis 4": -0.03578772615725946, "Axis 5": 0.010096315109530263, "Confidence": "0.9999840282225356", "Feature ID": "8bcc747f27b10bb3e1182fe530c7ed24", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Megasphaera; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.04879386184142123, "Axis 2": -0.007915390089224202, "Axis 3": 0.08455209806675343, "Axis 4": -0.04104343519066523, "Axis 5": 0.017936951640548055, "Confidence": "0.9241721737070745", "Feature ID": "faf2bd479f04891ef2afba2f407749ac", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.033227666036650526, "Axis 2": -0.010649136853927434, "Axis 3": -0.0082525812285336, "Axis 4": 0.0041068552844803685, "Axis 5": 0.006645078368279474, "Confidence": "0.7134842956250642", "Feature ID": "2ab2f3551b7aa27fd483fdcbaa1a0afb", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhodospirillales; f__Acetobacteraceae; g__Roseomonas", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0011662439122374529, "Axis 2": -0.0016519991908887518, "Axis 3": 0.0006826478184528276, "Axis 4": -0.0010312711302204358, "Axis 5": -0.0008310397481769086, "Confidence": "0.9994608634628026", "Feature ID": "6f384c926424d43c215fbe9337d55324", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Sphingomonadales; f__Sphingomonadaceae; g__Sphingomonas", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.008521123129804312, "Axis 2": -0.0038125672543863113, "Axis 3": -0.002155258900478092, "Axis 4": 0.0014103116062182807, "Axis 5": 0.000549849601193519, "Confidence": "0.8864263688673648", "Feature ID": "831514b8b3617bed49e2a4bd9d3d6268", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Blautia; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.008521123129804312, "Axis 2": -0.0038125672543863113, "Axis 3": -0.002155258900478092, "Axis 4": 0.0014103116062182807, "Axis 5": 0.000549849601193519, "Confidence": "0.9991394649235182", "Feature ID": "53dd9f9a89854c8ebdcfb105b7a26df1", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Nocardioidaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.018528842004221772, "Axis 2": -0.013079597592123968, "Axis 3": -0.04750197323849912, "Axis 4": -0.06291878807693384, "Axis 5": 0.037779187699066144, "Confidence": "0.9980934837410905", "Feature ID": "f4eefbd4edf2a372131825289fffcca6", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.042316530019716546, "Axis 2": -0.019155377197087924, "Axis 3": 0.0027985255935927262, "Axis 4": 0.002706856917559953, "Axis 5": 0.012518559571144451, "Confidence": "0.9992799355091816", "Feature ID": "752621a2dcf600f86357e9c2fa1fc985", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Porphyromonadaceae; g__Porphyromonas; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0053717892580553185, "Axis 2": 0.002194313369589525, "Axis 3": -0.00012139618459362686, "Axis 4": 0.0002464891506536442, "Axis 5": -0.004068120990260174, "Confidence": "0.9440239270971985", "Feature ID": "6a9b2745a31a3e5ae16682a323c28a4d", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae; g__Acinetobacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.0029615206388416034, "Axis 2": 0.00014751704798596175, "Axis 3": 0.00187835081586006, "Axis 4": -0.0013299127528509256, "Axis 5": -0.0018936560409591465, "Confidence": "0.9998155279516854", "Feature ID": "c81e310dae79b8767597762a093082c8", "Taxon": "k__Bacteria; p__Proteobacteria; c__Epsilonproteobacteria; o__Campylobacterales; f__Campylobacteraceae; g__Campylobacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.04487093344984923, "Axis 2": -0.0003016113706004937, "Axis 3": 0.05761992765968818, "Axis 4": -0.029958011818364275, "Axis 5": 0.009399060982365585, "Confidence": "0.9999999982512975", "Feature ID": "9df911e407318b496425698999a1d81f", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Schwartzia; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0020739376093739767, "Axis 2": 0.0006483777574608915, "Axis 3": -0.0013695562095941568, "Axis 4": 7.115697184597226e-05, "Axis 5": -0.0031990323804471014, "Confidence": "0.9999999965474444", "Feature ID": "5ed23cabf504db9af85bce57e9008ea2", "Taxon": "k__Bacteria; p__Cyanobacteria; c__Chloroplast; o__Streptophyta; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.002106195335287991, "Axis 2": -0.0023544236412835974, "Axis 3": 0.0013713765426397228, "Axis 4": -0.0015418967267203294, "Axis 5": -3.20078950686025e-05, "Confidence": "0.9844659045872064", "Feature ID": "7cd67e7e02db4db794fd67ab72755f8b", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Sphingomonadales; f__Sphingomonadaceae; g__Novosphingobium; s__stygium", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.002106195335287991, "Axis 2": -0.0023544236412835974, "Axis 3": 0.0013713765426397228, "Axis 4": -0.0015418967267203294, "Axis 5": -3.20078950686025e-05, "Confidence": "0.7863447584082709", "Feature ID": "a3dc97e11838f1bf157aa875f2f6367d", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__[Weeksellaceae]; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.020461141787152016, "Axis 2": -0.012350693974413785, "Axis 3": -0.0569897401220704, "Axis 4": -0.07292901945038058, "Axis 5": 0.04631245853491589, "Confidence": "0.999580466542268", "Feature ID": "aee707afe3847427a6d3d34e31437923", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__[Ruminococcus]; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.016391420720526413, "Axis 2": -0.008748963897185475, "Axis 3": -0.004573367718059184, "Axis 4": -5.7035950353764255e-06, "Axis 5": 0.0026260129438130924, "Confidence": "0.9723775421209669", "Feature ID": "31ed03e41d53de58a6348a242165c05b", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Vibrionales; f__Vibrionaceae; g__Vibrio; s__rumoiensis", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.003969233827209741, "Axis 2": 0.00024043954036153875, "Axis 3": 0.003307757110097425, "Axis 4": -0.002087717700620215, "Axis 5": -0.0014937091331797055, "Confidence": "0.9999999989869224", "Feature ID": "458462fa1e15c439f12deec2f19af933", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Schwartzia; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.003094370019125909, "Axis 2": -0.0030928852704348634, "Axis 3": 0.0020954398001479624, "Axis 4": -0.0020787194550090237, "Axis 5": 0.0008080174822633409, "Confidence": "0.9973687740610333", "Feature ID": "b901052d2411ea898be450af4a818744", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Micrococcaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.012042864565031647, "Axis 2": -0.00521048117506605, "Axis 3": -0.002617946623907171, "Axis 4": 0.0018782089007980422, "Axis 5": 0.001741706543330381, "Confidence": "0.9713959297387582", "Feature ID": "8c5f2b5fce1b357f54ed4c8c047b6845", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Sphingobacteriia; o__Sphingobacteriales; f__Sphingobacteriaceae; g__Pedobacter; s__cryoconitis", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.035515065030252424, "Axis 2": -0.013313501862260452, "Axis 3": -0.03475802876088526, "Axis 4": -0.017290030607697664, "Axis 5": 0.0507855760898242, "Confidence": "0.9233283322306867", "Feature ID": "33176e81f3e7ef2b9de1b783ff1ca33c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.012193112171428806, "Axis 2": -0.006542366684286261, "Axis 3": 0.00010764958284153476, "Axis 4": 0.010832275348405286, "Axis 5": 0.007894078616597997, "Confidence": "0.9642379799939774", "Feature ID": "f66effc279917d65747b7c3ef8d62432", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.08266103894797208, "Axis 2": -0.043110817647045746, "Axis 3": -0.05094762418008264, "Axis 4": 0.03966003845503601, "Axis 5": 0.13373216906098215, "Confidence": "0.99999952875545", "Feature ID": "160029903cd9c779390f4719179aeea2", "Taxon": "k__Bacteria; p__Firmicutes; c__Erysipelotrichi; o__Erysipelotrichales; f__Erysipelotrichaceae; g__Holdemania; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": 0.007775649675344493, "Axis 2": -0.007569408777841464, "Axis 3": -0.013056093736508866, "Axis 4": -0.01848567326366776, "Axis 5": 0.007779649660077135, "Confidence": "0.7260908381180646", "Feature ID": "0741ae033054073fece98b9948ec4387", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Peptostreptococcaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0014487588102828554, "Axis 2": -0.0009012583263697674, "Axis 3": -0.0013098152937916913, "Axis 4": 0.00025198403801219454, "Axis 5": -0.0019939658520204896, "Confidence": "0.9998282422605921", "Feature ID": "7fa8f515ee1ac5cb8b529b13e6a89790", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pasteurellales; f__Pasteurellaceae; g__Pasteurella", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.05286068613021423, "Axis 2": -0.0007251583150262191, "Axis 3": 0.0698594413653408, "Axis 4": -0.036519514304426196, "Axis 5": 0.011065909465119735, "Confidence": "0.9998149381925086", "Feature ID": "ff8c7f94f941a0c647120d4e142db316", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Dialister; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.05127975938622807, "Axis 2": -0.0005851679605173285, "Axis 3": 0.06720053295167831, "Axis 4": -0.035059386980608113, "Axis 5": 0.010815795460934053, "Confidence": "0.9999999993832631", "Feature ID": "51588a76b68ff3041e8b272256df5ae2", "Taxon": "k__Bacteria; p__Synergistetes; c__Synergistia; o__Synergistales; f__Dethiosulfovibrionaceae; g__TG5; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0013036121041128642, "Axis 2": 0.00015948796122770823, "Axis 3": -0.0010359994869222656, "Axis 4": 0.00012437999927356492, "Axis 5": -0.0028212922667146586, "Confidence": "0.9721717013874714", "Feature ID": "a54095a893fd5abc045d162bbe20644a", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.007067619424497726, "Axis 2": 0.020337399046506083, "Axis 3": -0.006855744231681268, "Axis 4": 0.0035256118092431574, "Axis 5": 0.008017828289992425, "Confidence": "0.9994274816567739", "Feature ID": "d985172bebaa0bbe61ff5f682d372c6e", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.08542557883825815, "Axis 2": -0.052211512311125766, "Axis 3": -0.04136811282013109, "Axis 4": 0.05612676318280942, "Axis 5": 0.13239841814473477, "Confidence": "0.9993011062402334", "Feature ID": "fbf110ef5de76f86121c8504a0cb786e", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.00011468329300342927, "Axis 2": -0.0007658661236270495, "Axis 3": -0.0005435346336386371, "Axis 4": 0.00034814780787500944, "Axis 5": -0.002268490515716199, "Confidence": "0.9995956608997126", "Feature ID": "f8fe4ee0ae3da9a1432872f5545a0d42", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Pseudomonadaceae; g__Pseudomonas; s__alcaligenes", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.03012661085009136, "Axis 2": -0.02005340375774641, "Axis 3": 0.009234817512667809, "Axis 4": -0.009898278818900073, "Axis 5": 0.016138892582629755, "Confidence": "0.9999999999249525", "Feature ID": "9b959f65abdb6cb9adc1d6160a5384ec", "Taxon": "k__Bacteria; p__Firmicutes; c__Erysipelotrichi; o__Erysipelotrichales; f__Erysipelotrichaceae; g__Allobaculum; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0018817451307798934, "Axis 2": 0.00041603736170067745, "Axis 3": -0.0007464413057260354, "Axis 4": 0.00016577562297846233, "Axis 5": -0.002953872545501555, "Confidence": "0.9659356355314311", "Feature ID": "cee164362eb3296a3d29e33f7b479d2e", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Nocardioidaceae; g__Marmoricola", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.07311248438486179, "Axis 2": -0.02551513632567164, "Axis 3": -0.015369302578318499, "Axis 4": 0.007239785773803482, "Axis 5": 0.01767903968219945, "Confidence": "0.9999742459804555", "Feature ID": "816e266d71b9a9af9d3d74893dee443e", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__; s__", "qurro_classification": "None", "qurro_spc": 3.0}, {"Axis 1": -0.002340391389062551, "Axis 2": -0.0012173026997592898, "Axis 3": -0.0014574480110422416, "Axis 4": 0.0002908059575369779, "Axis 5": -0.001746955201498296, "Confidence": "0.9539814950475789", "Feature ID": "480b52afa972e6deb75357ec39db1998", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Alcaligenaceae; g__Pusillimonas", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.002340391389062551, "Axis 2": -0.0012173026997592898, "Axis 3": -0.0014574480110422416, "Axis 4": 0.0002908059575369779, "Axis 5": -0.001746955201498296, "Confidence": "0.9996891350650701", "Feature ID": "35b6dde81c92eb7f66ca9f741da3514e", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Pseudomonadaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.002340391389062551, "Axis 2": -0.0012173026997592898, "Axis 3": -0.0014574480110422416, "Axis 4": 0.0002908059575369779, "Axis 5": -0.001746955201498296, "Confidence": "0.8222614483070971", "Feature ID": "ae4c61e598c093caa5b66b6919f02ba3", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhizobiales; f__Brucellaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.006154383771729538, "Axis 2": 0.00044193494739093995, "Axis 3": 0.0064073167076125525, "Axis 4": -0.0037309604989569506, "Axis 5": -0.0006264544684269804, "Confidence": "0.9999912016463905", "Feature ID": "0a50155a2def454344e1f2305eff7092", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Prevotellaceae; g__Prevotella; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.005237152192157725, "Axis 2": -0.004694183543193393, "Axis 3": 0.0036655162913915742, "Axis 4": -0.003242778999408351, "Axis 5": 0.002629549072660224, "Confidence": "0.9676772973812197", "Feature ID": "e54bcf1c8ec24811e7c355b8d82fa59e", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Nocardioidaceae; g__Nocardioides", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.015956677431561747, "Axis 2": -0.006764023247840255, "Axis 3": -0.003132144840456643, "Axis 4": 0.0023981966640742227, "Axis 5": 0.0030662515506776843, "Confidence": "0.9997500543684302", "Feature ID": "5b220f66423e4004eb3520bfae1f25d0", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Fusobacteriaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.015956677431561747, "Axis 2": -0.006764023247840255, "Axis 3": -0.003132144840456643, "Axis 4": 0.0023981966640742227, "Axis 5": 0.0030662515506776843, "Confidence": "0.9999654950216446", "Feature ID": "959a178855242ad3833af85d38ccff45", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhizobiales; f__Bradyrhizobiaceae; g__Balneimonas; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.0031469630308341547, "Axis 2": 0.001024945384652512, "Axis 3": -0.001776430399494399, "Axis 4": 0.00020004357783134027, "Axis 5": -0.0037836211855072615, "Confidence": "0.9994592577221576", "Feature ID": "e6dfd15b38618c3c7ff0a025083f56d4", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__[Weeksellaceae]; g__Chryseobacterium; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.003142288361205981, "Axis 2": 0.0005394310457959742, "Axis 3": -0.0004030250870800884, "Axis 4": -9.083354471238325e-05, "Axis 5": -0.0032499524687881138, "Confidence": "0.9893835101243303", "Feature ID": "3253177a44672689e4e154e842d63e35", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Oxalobacteraceae; g__Janthinobacterium; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.05949606550300101, "Axis 2": -0.0297250213601579, "Axis 3": 0.0032658893724539307, "Axis 4": -0.002628908781792772, "Axis 5": 0.023764053915196908, "Confidence": "0.9998990992522439", "Feature ID": "b815913c61abb4a540babe5c3fae17e7", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Blautia; s__producta", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0064050966030510985, "Axis 2": -0.005566986850678144, "Axis 3": 0.0045213018610598486, "Axis 4": -0.0038772610554657083, "Axis 5": 0.0036223927069992333, "Confidence": "0.999999999775909", "Feature ID": "45c36b8b2965484407b8b213419d4c6c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Anaerococcus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.018933864550701764, "Axis 2": 9.134277206284274e-05, "Axis 3": 0.025072289424807565, "Axis 4": -0.013745030421340084, "Axis 5": 0.0024642835237471657, "Confidence": "0.9999999999948557", "Feature ID": "e9f0399c43aff643ceb1480929cf89b2", "Taxon": "k__Bacteria; p__Spirochaetes; c__Spirochaetes; o__Spirochaetales; f__Spirochaetaceae; g__Treponema; s__socranskii", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.018089939468308464, "Axis 2": -0.007610796570775398, "Axis 3": -0.003412413614701935, "Axis 4": 0.0026816210874686264, "Axis 5": 0.003788207780189877, "Confidence": "0.9999287126237506", "Feature ID": "2b427cf77172293239bc1c1cdb32ace4", "Taxon": "k__Bacteria; p__Actinobacteria; c__Thermoleophilia; o__Solirubrobacterales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.012763938944123384, "Axis 2": -0.007675252896915206, "Axis 3": 0.005439202439382136, "Axis 4": 0.02589648875182431, "Axis 5": 0.0072642060103981715, "Confidence": "0.7587033501057657", "Feature ID": "a841dd7e2f38b26bb7bb37179b4141d5", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Ruminococcus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.012763938944123384, "Axis 2": -0.007675252896915206, "Axis 3": 0.005439202439382136, "Axis 4": 0.02589648875182431, "Axis 5": 0.0072642060103981715, "Confidence": "0.7538873511886149", "Feature ID": "73291cac0e802b6a1fb25ae7079390ef", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.014419884606380743, "Axis 2": -0.008302457043695685, "Axis 3": 0.004648728682107641, "Axis 4": 0.023614313147028786, "Axis 5": 0.011435255563513018, "Confidence": "0.9995886401457694", "Feature ID": "63145f49e7efc26729094a53d97c0cd1", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.05454262186735031, "Axis 2": -0.026863271077193582, "Axis 3": -0.00045206338649686473, "Axis 4": 0.008388412589327269, "Axis 5": 0.015143881797725202, "Confidence": "0.9999974911342444", "Feature ID": "678424c0e69dd311d2b536cfd69a91a4", "Taxon": "k__Bacteria; p__Tenericutes; c__Mollicutes; o__Mycoplasmatales; f__Mycoplasmataceae; g__Mycoplasma; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.03562120191209248, "Axis 2": -0.026391205411306677, "Axis 3": 0.020616566158537658, "Axis 4": -0.011593497082559103, "Axis 5": 0.021996485443494352, "Confidence": "0.9999595467133086", "Feature ID": "f8753b9f13abb306b57aedce2cf6e7d0", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__[Weeksellaceae]; g__Cloacibacterium; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.03253236485374524, "Axis 2": -0.020076320702233894, "Axis 3": 0.014487879001930866, "Axis 4": 0.0016369277353472528, "Axis 5": 0.010298131238757197, "Confidence": "0.9874728283022315", "Feature ID": "99e6b8fa779ca2689cdc55d164e593e8", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Lactobacillaceae; g__Lactobacillus; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.05409172953884116, "Axis 2": -0.02766377278466149, "Axis 3": 0.0012828081845433579, "Axis 4": 0.008493915529494748, "Axis 5": 0.014974477173995353, "Confidence": "0.9999755784530566", "Feature ID": "e03d5567ab978eb82490f359c51912b1", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Peptoniphilus; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.03724331825055258, "Axis 2": -0.02240732071630885, "Axis 3": 0.0067879018869218865, "Axis 4": 0.005870181774942457, "Axis 5": 0.010209839385419821, "Confidence": "0.9999999031502018", "Feature ID": "421da954b88f7175953a73ea34b933e0", "Taxon": "k__Bacteria; p__Tenericutes; c__Mollicutes; o__Mycoplasmatales; f__Mycoplasmataceae; g__Mycoplasma; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.12402417986522062, "Axis 2": -0.07280558842466807, "Axis 3": 0.035843237101087735, "Axis 4": -0.01614390750633315, "Axis 5": 0.052323410632256324, "Confidence": "0.9999986195380053", "Feature ID": "20fb19136419ba2826c941aa152fa0eb", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Bacillales; f__Alicyclobacillaceae; g__Alicyclobacillus; s__", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.056562397050615616, "Axis 2": -0.023734806592715547, "Axis 3": -0.00974993613516271, "Axis 4": 0.005749870524178708, "Axis 5": 0.015716062762583017, "Confidence": "0.7246823172313543", "Feature ID": "4aa8e1c58af1b89f613fe3bf2b81604e", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0021405485606109573, "Axis 2": 0.0005289076969770663, "Axis 3": -0.001367714554465212, "Axis 4": 0.00017442141882809665, "Axis 5": -0.0032627322156214577, "Confidence": "0.9995713120491824", "Feature ID": "c7312d5390945aa1e45badeeba28a998", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhodobacterales; f__Rhodobacteraceae; g__Paracoccus", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.050564884005542494, "Axis 2": -0.0023007336042569497, "Axis 3": 0.08079387785727744, "Axis 4": -0.04249500803211424, "Axis 5": 0.01582924624510445, "Confidence": "0.8987845458962096", "Feature ID": "9584fe0b6843a9817e1c217bb65caea8", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Lactobacillaceae; g__Lactobacillus; s__helveticus", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.0419661128153724, "Axis 2": -0.010506406653289096, "Axis 3": 0.08621619828044672, "Axis 4": -0.04884349969771812, "Axis 5": 0.022725405462032992, "Confidence": "0.9999919631273232", "Feature ID": "251eb140eb9387372897c5f7db6f954c", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Neisseriales; f__Neisseriaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.020360923977992156, "Axis 2": -0.008512237212606607, "Axis 3": -0.003710776419596619, "Axis 4": 0.0029833432688544242, "Axis 5": 0.004556773191119044, "Confidence": "0.9999999970166726", "Feature ID": "c66348656c079cbbc916b2c2832f311b", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Actinomycetaceae; g__Varibaculum; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.020360923977992156, "Axis 2": -0.008512237212606607, "Axis 3": -0.003710776419596619, "Axis 4": 0.0029833432688544242, "Axis 5": 0.004556773191119044, "Confidence": "0.9999995079733213", "Feature ID": "457c3dbae079470f3cf0bf146c191e1f", "Taxon": "k__Bacteria; p__Acidobacteria; c__[Chloracidobacteria]; o__RB41; f__Ellin6075; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.020360923977992156, "Axis 2": -0.008512237212606607, "Axis 3": -0.003710776419596619, "Axis 4": 0.0029833432688544242, "Axis 5": 0.004556773191119044, "Confidence": "0.8785380785562831", "Feature ID": "4ea8ed64f727e17c2ecf3616119876eb", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Mycobacteriaceae; g__Mycobacterium; s__vaccae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.020360923977992156, "Axis 2": -0.008512237212606607, "Axis 3": -0.003710776419596619, "Axis 4": 0.0029833432688544242, "Axis 5": 0.004556773191119044, "Confidence": "0.9999999999543832", "Feature ID": "2b6445815ec98d21dbe9640083f30d2f", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Anaerococcus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.015863225033615907, "Axis 2": 0.04206738436988946, "Axis 3": 0.009000513189835467, "Axis 4": 0.037117302733229066, "Axis 5": 0.0373120642135192, "Confidence": "0.999999999820659", "Feature ID": "1ea96d595539133266a3dbd49daac1e4", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Peptoniphilus; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.01625440568425816, "Axis 2": -0.014741178430333114, "Axis 3": 0.007364006331546894, "Axis 4": 0.028636512083362424, "Axis 5": 0.008342639473861359, "Confidence": "0.872007862980504", "Feature ID": "f95cdb71258ef6cc222c673ea4546caf", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Coprococcus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.01384308912755236, "Axis 2": -0.008376252955018301, "Axis 3": 0.006021111305656401, "Axis 4": 0.028258676684849098, "Axis 5": 0.00817569380038924, "Confidence": "0.995211622595342", "Feature ID": "1e1e0cca52fab68a8c7ba5256aeadd6d", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__Oscillospira; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.030016004563488678, "Axis 2": -0.0031245020373934784, "Axis 3": -0.06739739292551608, "Axis 4": -0.06781401785423403, "Axis 5": 0.06732725799996468, "Confidence": "0.9913645537983928", "Feature ID": "1395953fab837ed426f9b2ba24da41b1", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.009915949051138228, "Axis 2": -0.009949794807655543, "Axis 3": -0.01689441739660793, "Axis 4": -0.02437061821157124, "Axis 5": 0.011081072361761736, "Confidence": "0.998852385121035", "Feature ID": "b2d056fa113334bd2797397b162c6ac9", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Anaerostipes; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.00394639212561021, "Axis 2": -0.003284416728172113, "Axis 3": 0.0006972845656251468, "Axis 4": 0.0010453503895061882, "Axis 5": -0.0008801438866773529, "Confidence": "0.9999976346458538", "Feature ID": "94ca1389331a3a9230237844cfd545f6", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Enterobacteriales; f__Enterobacteriaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.002287695684938392, "Axis 2": -0.001708410438531735, "Axis 3": -0.0014931621335081018, "Axis 4": 6.934982880598871e-05, "Axis 5": -0.001622716613082431, "Confidence": "0.7263700876269954", "Feature ID": "15992a34ae0f42d6b5a21eeaaef674ba", "Taxon": "k__Bacteria; p__Bacteroidetes; c__[Saprospirae]; o__[Saprospirales]; f__Chitinophagaceae; g__Flavisolibacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.08798246904672587, "Axis 2": -0.04931378830235274, "Axis 3": 0.017901912123695535, "Axis 4": -0.021029482002015897, "Axis 5": 0.043895859732123566, "Confidence": "0.9999999922326452", "Feature ID": "b46e36edac9cab660cec7ee6f1a335a3", "Taxon": "k__Bacteria; p__Firmicutes; c__Erysipelotrichi; o__Erysipelotrichales; f__Erysipelotrichaceae; g__[Eubacterium]; s__biforme", "qurro_classification": "None", "qurro_spc": 4.0}, {"Axis 1": -0.002287695684938392, "Axis 2": -0.001708410438531735, "Axis 3": -0.0014931621335081018, "Axis 4": 6.934982880598871e-05, "Axis 5": -0.001622716613082431, "Confidence": "0.9581578505539091", "Feature ID": "2ce0fa88ec7cfdda2eeb0698cdad47e8", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__Dorea; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.002287695684938392, "Axis 2": -0.001708410438531735, "Axis 3": -0.0014931621335081018, "Axis 4": 6.934982880598871e-05, "Axis 5": -0.001622716613082431, "Confidence": "0.9997149879224455", "Feature ID": "0310f41e594c49368dde5c5993a7a5d0", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__[Weeksellaceae]; g__Chryseobacterium; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0053690938356756954, "Axis 2": -0.0022908439651908577, "Axis 3": -0.0019589276368190906, "Axis 4": 0.00042267646725730785, "Axis 5": -0.0009079080655132406, "Confidence": "0.9228367861357153", "Feature ID": "82e72255267397b777a1afd44ea22755", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__Flavobacterium; s__succinicans", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.020493859586097507, "Axis 2": -0.009362019169646301, "Axis 3": 0.004048440639515725, "Axis 4": 0.00038955966811783904, "Axis 5": 0.006992446884898708, "Confidence": "0.8187053015696685", "Feature ID": "5ec803f68f3c48cd9ce6436ccbd5b1e3", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Caulobacterales; f__Caulobacteraceae; g__Caulobacter; s__henricii", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.062185197170789394, "Axis 2": -0.0005115185499474365, "Axis 3": 0.08115627061674723, "Axis 4": -0.04213830497421638, "Axis 5": 0.014015538337320489, "Confidence": "0.9508343849868776", "Feature ID": "9d17e47f8102cca1e9a0a5b0776bb85a", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.003701647139858957, "Axis 2": -0.0018446241272455878, "Axis 3": -0.0007620690686874776, "Axis 4": 0.003299732935329917, "Axis 5": -0.001295769757369196, "Confidence": "0.9999997715482482", "Feature ID": "e6953e3ef3e20c6b169ef7a759d868df", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.008977603268195218, "Axis 2": -0.007489417665811641, "Axis 3": 0.006406249518989755, "Axis 4": -0.00527476705223948, "Axis 5": 0.0058092235552494155, "Confidence": "0.9999843644749064", "Feature ID": "025dd300b0ccbd9d5898969c2a1ab138", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__[Prevotella]; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.022788648376750553, "Axis 2": -0.009475893913422613, "Axis 3": -0.004029731770474686, "Axis 4": 0.003305889855268148, "Axis 5": 0.0053783838151450145, "Confidence": "0.9213912242432593", "Feature ID": "9cd30ed12a411f643a9f6c145e3b59d8", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Sphingomonadales; f__Erythrobacteraceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.022788648376750553, "Axis 2": -0.009475893913422613, "Axis 3": -0.004029731770474686, "Axis 4": 0.003305889855268148, "Axis 5": 0.0053783838151450145, "Confidence": "0.9999895799637278", "Feature ID": "8fbf42d21b6c9c4a4e8e260ad1d6a1ab", "Taxon": "k__Bacteria; p__Bacteroidetes; c__[Saprospirae]; o__[Saprospirales]; f__Chitinophagaceae; g__Segetibacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.022788648376750553, "Axis 2": -0.009475893913422613, "Axis 3": -0.004029731770474686, "Axis 4": 0.003305889855268148, "Axis 5": 0.0053783838151450145, "Confidence": "0.9999994783460064", "Feature ID": "a6e9c3caf38d8be5744751bea41aa62f", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Cytophagia; o__Cytophagales; f__Cytophagaceae; g__Hymenobacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.017440312881515978, "Axis 2": -0.015884569363983005, "Axis 3": 0.008006796794603754, "Axis 4": 0.03085142645249824, "Axis 5": 0.009198943773276898, "Confidence": "0.9790687344444653", "Feature ID": "9c6b4f83513e63a49ce33a8aeb1813ad", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.01500224702342807, "Axis 2": -0.009129224844229877, "Axis 3": 0.006646162635285613, "Axis 4": 0.03079599617582819, "Axis 5": 0.009154758887887318, "Confidence": "0.7757239629582907", "Feature ID": "7e4d5b19d3213719048fe55dfad0da3a", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Ruminococcaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0626424472904885, "Axis 2": -0.03361428278530266, "Axis 3": 0.004459816158199787, "Axis 4": 0.010071100235577475, "Axis 5": 0.01767298776395039, "Confidence": "0.9999439082576366", "Feature ID": "ae25381e186978a7230f03484baede7c", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhodospirillales; f__Rhodospirillaceae; g__Skermanella; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0038791416401797534, "Axis 2": -0.002519297079746437, "Axis 3": -0.0017781801715596925, "Axis 4": 3.254478781866789e-05, "Axis 5": -0.0011146238452326965, "Confidence": "0.9998277198923297", "Feature ID": "2328e11c4256f1f05395b7a377381279", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__[Prevotella]; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0633357693140127, "Axis 2": -0.0288612084058984, "Axis 3": -0.012187853843137334, "Axis 4": 0.003133669643012278, "Axis 5": 0.016840984991928543, "Confidence": "0.9999810272535158", "Feature ID": "b3406cb10b6d6882837eaacbaec3553e", "Taxon": "k__Bacteria; p__Tenericutes; c__Mollicutes; o__Mycoplasmatales; f__Mycoplasmataceae; g__Mycoplasma; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.011716148146069914, "Axis 2": 0.07809419884232775, "Axis 3": -0.0020726280096890503, "Axis 4": 0.02311619750561202, "Axis 5": 0.03608741114400473, "Confidence": "0.9336176539767812", "Feature ID": "de35e106a779f81d63e2e058bf18799c", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.007676196201135471, "Axis 2": -0.002849912352606185, "Axis 3": 0.00513124499978206, "Axis 4": -2.544697410046989e-05, "Axis 5": -3.656259899339643e-05, "Confidence": "0.9310865331957705", "Feature ID": "2835a5008083ae7290acbca001520ad1", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Sphingomonadales; f__Sphingomonadaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.011424724865696814, "Axis 2": 0.0009279196856813309, "Axis 3": 0.013883113213455785, "Axis 4": -0.007694281217134518, "Axis 5": 0.00146526830329592, "Confidence": "0.9993428884816767", "Feature ID": "81fad06bda8cf753d87288f1d080da88", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__[Paraprevotellaceae]; g__[Prevotella]; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.011424724865696814, "Axis 2": 0.0009279196856813309, "Axis 3": 0.013883113213455785, "Axis 4": -0.007694281217134518, "Axis 5": 0.00146526830329592, "Confidence": "0.99999225221384", "Feature ID": "9930e78f4486e70ced513d619dae53fb", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Flavobacteriia; o__Flavobacteriales; f__Flavobacteriaceae; g__Capnocytophaga", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.011424724865696814, "Axis 2": 0.0009279196856813309, "Axis 3": 0.013883113213455785, "Axis 4": -0.007694281217134518, "Axis 5": 0.00146526830329592, "Confidence": "0.9999999948261831", "Feature ID": "65fbdc4707be0814fa4faf52571cc2b5", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Leptotrichia; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.001075658474366591, "Axis 2": -0.0013505244950029157, "Axis 3": -5.7574774249248505e-06, "Axis 4": 0.0002887676281281392, "Axis 5": -0.0016545829564595818, "Confidence": "0.9995312015176429", "Feature ID": "5e793ed595a0793ab477b17e78421bc5", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.01040530688573957, "Axis 2": -0.008556338683523006, "Axis 3": 0.0074523679320425435, "Axis 4": -0.006050362464359459, "Axis 5": 0.00702288272873477, "Confidence": "0.9784017334122616", "Feature ID": "538c01338d48c71522ac629b17a01c9d", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae; g__Tepidimonas; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.01040530688573957, "Axis 2": -0.008556338683523006, "Axis 3": 0.0074523679320425435, "Axis 4": -0.006050362464359459, "Axis 5": 0.00702288272873477, "Confidence": "0.9994313593939201", "Feature ID": "8b300bb35321f8c125cdc4c3a242bbc0", "Taxon": "k__Bacteria; p__Bacteroidetes; c__[Saprospirae]; o__[Saprospirales]; f__Chitinophagaceae; g__Flavisolibacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.01040530688573957, "Axis 2": -0.008556338683523006, "Axis 3": 0.0074523679320425435, "Axis 4": -0.006050362464359459, "Axis 5": 0.00702288272873477, "Confidence": "0.7005947976611697", "Feature ID": "5454ea14c70f0323a5e836aba10947b8", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhodospirillales; f__Acetobacteraceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.02539636317775175, "Axis 2": -0.010510995691485666, "Axis 3": -0.004372334328561037, "Axis 4": 0.0036523499014882335, "Axis 5": 0.006260908283749476, "Confidence": "0.999312583786639", "Feature ID": "0f006e3e638afedde4892706134a4fb9", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Caulobacterales; f__Caulobacteraceae; g__Mycoplana; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.02539636317775175, "Axis 2": -0.010510995691485666, "Axis 3": -0.004372334328561037, "Axis 4": 0.0036523499014882335, "Axis 5": 0.006260908283749476, "Confidence": "0.9998545102962137", "Feature ID": "3f61c9eee7bfb0326d3efb8da077b0da", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Actinomycetaceae; g__Arcanobacterium; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.004762176590827662, "Axis 2": -0.032364839614977055, "Axis 3": 0.009440365507948347, "Axis 4": 0.030672049586693964, "Axis 5": 0.03240942251535874, "Confidence": "0.7040839231558271", "Feature ID": "8c001c89f020a1b78b26ee21d1d56746", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0069885874608779045, "Axis 2": -0.005284026624305605, "Axis 3": 0.0016824362420229616, "Axis 4": 0.0015988962183347314, "Axis 5": 0.0002221375817512392, "Confidence": "0.9998371351701231", "Feature ID": "5a61388e52a8005b6747280b9332d2de", "Taxon": "k__Bacteria; p__Bacteroidetes; c__[Saprospirae]; o__[Saprospirales]; f__Chitinophagaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.046824700426275505, "Axis 2": -0.03345176965372636, "Axis 3": 0.02558122698361284, "Axis 4": -0.02150464947234213, "Axis 5": 0.032714601043775556, "Confidence": "0.9520427272281469", "Feature ID": "a5e8aaab366d42b670d589ada160581c", "Taxon": "k__Bacteria", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.0077737401325426595, "Axis 2": -0.0031431848847620902, "Axis 3": -0.0023570787085518074, "Axis 4": 0.0005273754063094268, "Axis 5": -0.00024174437858536432, "Confidence": "0.999996280574892", "Feature ID": "9b07cccc73bd232ffb6edb9427194c06", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Fusobacteriaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.0019155597494659243, "Axis 2": 0.024651589817319797, "Axis 3": 0.002705049867145313, "Axis 4": 0.007886513251689597, "Axis 5": 0.006434688609702893, "Confidence": "0.8114711899854132", "Feature ID": "7456c5136c45202afcf8000e2a8a01c5", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae; g__Hydrogenophaga; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.07133361326198843, "Axis 2": -0.0001257014413294777, "Axis 3": 0.09149617291406564, "Axis 4": -0.04714349590172411, "Axis 5": 0.017159444595290067, "Confidence": "0.9725578357741024", "Feature ID": "99f9d85c50cec960adab2a3f0f401371", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Lachnospiraceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.01194734426690695, "Axis 2": -0.00970870117097952, "Axis 3": 0.008582261894789178, "Axis 4": -0.006888069326942069, "Axis 5": 0.00833373449832691, "Confidence": "0.999999990006657", "Feature ID": "76e8305b47ef8b35c452b5490589fc95", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__[Tissierellaceae]; g__Anaerococcus; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.02809018630401223, "Axis 2": 0.0001550222291473203, "Axis 3": 0.03833474988516807, "Axis 4": -0.0208368087037859, "Axis 5": 0.00508676234874216, "Confidence": "0.9921714931157413", "Feature ID": "328cf8ca7cded30705336cf036a2df45", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Corynebacteriaceae; g__Corynebacterium", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.028212909730658764, "Axis 2": -0.011628990781973363, "Axis 3": -0.004742373281296487, "Axis 4": 0.00402655525880972, "Axis 5": 0.007214107325665277, "Confidence": "0.8613799917759664", "Feature ID": "9f6a3b261bc6acafa3d4a6d2de87f924", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Xanthomonadales; f__Xanthomonadaceae; g__Pseudoxanthomonas", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.028212909730658764, "Axis 2": -0.011628990781973363, "Axis 3": -0.004742373281296487, "Axis 4": 0.00402655525880972, "Axis 5": 0.007214107325665277, "Confidence": "0.9744387709580358", "Feature ID": "2f09559bc1ffcc3ea06ae2766194920b", "Taxon": "k__Bacteria; p__Actinobacteria; c__Actinobacteria; o__Actinomycetales; f__Nakamurellaceae; g__; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": 0.03419542753634405, "Axis 2": -0.0036350117635362967, "Axis 3": -0.0765653815309737, "Axis 4": -0.07709236147296836, "Axis 5": 0.07744033171300697, "Confidence": "0.9999971826427195", "Feature ID": "6bd57e46e038faafe4bb747e1d494df7", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Bacteroidia; o__Bacteroidales; f__Rikenellaceae; g__Alistipes; s__indistinctus", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.024438259442881263, "Axis 2": -0.016589134657105382, "Axis 3": 0.07920754890199679, "Axis 4": -0.033521928600121556, "Axis 5": 0.021060027019050305, "Confidence": "0.9999998284467898", "Feature ID": "37d242005eb3c4239ad2c00158ea99a1", "Taxon": "k__Bacteria; p__Fusobacteria; c__Fusobacteriia; o__Fusobacteriales; f__Leptotrichiaceae; g__Leptotrichia; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.010560729899428876, "Axis 2": -0.006023951652267008, "Axis 3": 0.006359914899522673, "Axis 4": -0.0010734452462492243, "Axis 5": 0.002415209862701907, "Confidence": "0.7595226742982861", "Feature ID": "e9849de9c0f7be74e13c457f05177aad", "Taxon": "k__Bacteria; p__Proteobacteria; c__Alphaproteobacteria; o__Rhizobiales; f__Hyphomicrobiaceae; g__Devosia; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.010560729899428876, "Axis 2": -0.006023951652267008, "Axis 3": 0.006359914899522673, "Axis 4": -0.0010734452462492243, "Axis 5": 0.002415209862701907, "Confidence": "0.9999990472830105", "Feature ID": "72cbf125e17c4e14d748543564d3d4ec", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Streptococcaceae; g__Streptococcus", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.04175867484735691, "Axis 2": -0.01880291026383625, "Axis 3": -0.008566812126115875, "Axis 4": 0.0003362116519785259, "Axis 5": 0.009997944351201339, "Confidence": "0.9999999995056612", "Feature ID": "b59d5976acdb148c29f724d6b7990410", "Taxon": "k__Bacteria; p__SR1; c__; o__; f__; g__; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": -0.06814296285403115, "Axis 2": -0.02627242440443523, "Axis 3": -0.011754195944764196, "Axis 4": 0.007080406586714305, "Axis 5": 0.0181876143890431, "Confidence": "0.9161651875511259", "Feature ID": "7b9b46a7c3fb8b76b1c68911a9b56da1", "Taxon": "k__Bacteria; p__Proteobacteria; c__Gammaproteobacteria; o__Pseudomonadales; f__Moraxellaceae", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.014706686110258577, "Axis 2": 0.0012305534333040926, "Axis 3": 0.018538461694124743, "Axis 4": -0.01016233115259629, "Axis 5": 0.002767831638147222, "Confidence": "0.9483853700390096", "Feature ID": "4cecaa1cfabe89a905940ae23dd94a64", "Taxon": "k__Bacteria; p__Proteobacteria; c__Betaproteobacteria; o__Burkholderiales; f__Comamonadaceae", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.07475931550247411, "Axis 2": -0.045822367278480644, "Axis 3": 0.025987251481680455, "Axis 4": -0.020852124786113976, "Axis 5": 0.042875241720197375, "Confidence": "0.9342511845641011", "Feature ID": "bf6066f701b31c6bba541503797da013", "Taxon": "k__Bacteria; p__Firmicutes; c__Clostridia; o__Clostridiales; f__Veillonellaceae; g__Dialister; s__", "qurro_classification": "None", "qurro_spc": 2.0}, {"Axis 1": 0.030859577379117126, "Axis 2": 0.0001742825090794394, "Axis 3": 0.0423460702190756, "Axis 4": -0.022981764725556044, "Axis 5": 0.005879948701107616, "Confidence": "0.9787616562308198", "Feature ID": "ca1b627f011b52798bfb8fd2c6b76d20", "Taxon": "k__Bacteria; p__Firmicutes; c__Bacilli; o__Lactobacillales; f__Aerococcaceae; g__Facklamia; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.031274670146403165, "Axis 2": -0.012844320636727165, "Axis 3": -0.005144628524192995, "Axis 4": 0.004433339641345097, "Axis 5": 0.00825029367658892, "Confidence": "0.999877529465502", "Feature ID": "029cc71dc93341de90188b686798aa0d", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Cytophagia; o__Cytophagales; f__Cytophagaceae; g__Hymenobacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}, {"Axis 1": -0.031274670146403165, "Axis 2": -0.012844320636727165, "Axis 3": -0.005144628524192995, "Axis 4": 0.004433339641345097, "Axis 5": 0.00825029367658892, "Confidence": "0.9978127922032284", "Feature ID": "c9ffd432429a7600931358e3a09860f5", "Taxon": "k__Bacteria; p__Bacteroidetes; c__Cytophagia; o__Cytophagales; f__Cytophagaceae; g__Adhaeribacter; s__", "qurro_classification": "None", "qurro_spc": 1.0}], "qurro_feature_metadata_ordering": ["Taxon", "Confidence"], "qurro_rank_ordering": ["Axis 1", "Axis 2", "Axis 3", "Axis 4", "Axis 5"], "qurro_rank_type": "Feature Loading"}, "encoding": {"color": {"field": "qurro_classification", "scale": {"domain": ["None", "Numerator", "Denominator", "Both"], "range": ["#e0e0e0", "#f00", "#00f", "#949"]}, "title": "Log-Ratio Classification", "type": "nominal"}, "tooltip": [{"field": "qurro_x", "title": "Current Ranking", "type": "quantitative"}, {"field": "qurro_classification", "title": "Log-Ratio Classification", "type": "nominal"}, {"field": "qurro_spc", "title": "Sample Presence Count", "type": "quantitative"}, {"field": "Feature ID", "type": "nominal"}, {"field": "Taxon", "type": "nominal"}, {"field": "Confidence", "type": "nominal"}, {"field": "Axis 1", "type": "quantitative"}, {"field": "Axis 2", "type": "quantitative"}, {"field": "Axis 3", "type": "quantitative"}, {"field": "Axis 4", "type": "quantitative"}, {"field": "Axis 5", "type": "quantitative"}], "x": {"axis": {"labelAngle": 0, "ticks": false}, "field": "qurro_x", "scale": {"paddingInner": 0, "paddingOuter": 1, "rangeStep": 1}, "title": "Feature Rankings", "type": "ordinal"}, "y": {"field": "Axis 1", "type": "quantitative"}}, "mark": "bar", "selection": {"selector001": {"bind": "scales", "encodings": ["x", "y"], "type": "interval"}}, "title": "Features", "transform": [{"sort": [{"field": "Axis 1", "order": "ascending"}], "window": [{"as": "qurro_x", "op": "row_number"}]}]};
        var samplePlotJSON = {"$schema": "https://vega.github.io/schema/vega-lite/v3.3.0.json", "autosize": {"resize": true}, "background": "#FFFFFF", "config": {"axis": {"labelBound": true}, "mark": {"tooltip": null}, "range": {"category": {"scheme": "tableau10"}, "ramp": {"scheme": "blues"}}, "view": {"height": 300, "width": 400}}, "data": {"name": "data-b0d4925de56979bb69725388f699381d"}, "datasets": {"data-b0d4925de56979bb69725388f699381d": [{"BarcodeSequence": "AGTGCGATGCGT", "BodySite": "gut", "Day": 17.0, "DaysSinceExperimentStart": 140.0, "Description": "subject-1.gut.2009-3-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 3.0, "ReportedAntibioticUsage": "No", "Sample ID": "L1S105", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "ATGGCAGCTCTA", "BodySite": "gut", "Day": 28.0, "DaysSinceExperimentStart": 0.0, "Description": "subject-2.gut.2008-10-28", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 10.0, "ReportedAntibioticUsage": "Yes", "Sample ID": "L1S140", "Subject": "subject-2", "Year": 2008.0, "qurro_balance": null}, {"BarcodeSequence": "CTGAGATACGCG", "BodySite": "gut", "Day": 20.0, "DaysSinceExperimentStart": 84.0, "Description": "subject-2.gut.2009-1-20", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 1.0, "ReportedAntibioticUsage": "No", "Sample ID": "L1S208", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CCGACTGAGATG", "BodySite": "gut", "Day": 17.0, "DaysSinceExperimentStart": 140.0, "Description": "subject-2.gut.2009-3-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 3.0, "ReportedAntibioticUsage": "No", "Sample ID": "L1S257", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CCTCTCGTGATC", "BodySite": "gut", "Day": 14.0, "DaysSinceExperimentStart": 168.0, "Description": "subject-2.gut.2009-4-14", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 4.0, "ReportedAntibioticUsage": "No", "Sample ID": "L1S281", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "ACACACTATGGC", "BodySite": "gut", "Day": 20.0, "DaysSinceExperimentStart": 84.0, "Description": "subject-1.gut.2009-1-20", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 1.0, "ReportedAntibioticUsage": "No", "Sample ID": "L1S57", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "ACTACGTGTGGT", "BodySite": "gut", "Day": 17.0, "DaysSinceExperimentStart": 112.0, "Description": "subject-1.gut.2009-2-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 2.0, "ReportedAntibioticUsage": "No", "Sample ID": "L1S76", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "AGCTGACTAGTC", "BodySite": "gut", "Day": 28.0, "DaysSinceExperimentStart": 0.0, "Description": "subject-1.gut.2008-10-28", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 10.0, "ReportedAntibioticUsage": "Yes", "Sample ID": "L1S8", "Subject": "subject-1", "Year": 2008.0, "qurro_balance": null}, {"BarcodeSequence": "ACGATGCGACCA", "BodySite": "left palm", "Day": 20.0, "DaysSinceExperimentStart": 84.0, "Description": "subject-1.left-palm.2009-1-20", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 1.0, "ReportedAntibioticUsage": "No", "Sample ID": "L2S155", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "AGCTATCCACGA", "BodySite": "left palm", "Day": 17.0, "DaysSinceExperimentStart": 112.0, "Description": "subject-1.left-palm.2009-2-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 2.0, "ReportedAntibioticUsage": "No", "Sample ID": "L2S175", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "ATGCAGCTCAGT", "BodySite": "left palm", "Day": 17.0, "DaysSinceExperimentStart": 140.0, "Description": "subject-1.left-palm.2009-3-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 3.0, "ReportedAntibioticUsage": "No", "Sample ID": "L2S204", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CACGTGACATGT", "BodySite": "left palm", "Day": 14.0, "DaysSinceExperimentStart": 168.0, "Description": "subject-1.left-palm.2009-4-14", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 4.0, "ReportedAntibioticUsage": "No", "Sample ID": "L2S222", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CATATCGCAGTT", "BodySite": "left palm", "Day": 28.0, "DaysSinceExperimentStart": 0.0, "Description": "subject-2.left-palm.2008-10-28", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 10.0, "ReportedAntibioticUsage": "Yes", "Sample ID": "L2S240", "Subject": "subject-2", "Year": 2008.0, "qurro_balance": null}, {"BarcodeSequence": "CGTGCATTATCA", "BodySite": "left palm", "Day": 20.0, "DaysSinceExperimentStart": 84.0, "Description": "subject-2.left-palm.2009-1-20", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 1.0, "ReportedAntibioticUsage": "No", "Sample ID": "L2S309", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CTAACGCAGTCA", "BodySite": "left palm", "Day": 17.0, "DaysSinceExperimentStart": 140.0, "Description": "subject-2.left-palm.2009-3-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 3.0, "ReportedAntibioticUsage": "No", "Sample ID": "L2S357", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CTCAATGACTCA", "BodySite": "left palm", "Day": 14.0, "DaysSinceExperimentStart": 168.0, "Description": "subject-2.left-palm.2009-4-14", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 4.0, "ReportedAntibioticUsage": "No", "Sample ID": "L2S382", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "ACAGTTGCGCGA", "BodySite": "right palm", "Day": 28.0, "DaysSinceExperimentStart": 0.0, "Description": "subject-1.right-palm.2008-10-28", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 10.0, "ReportedAntibioticUsage": "Yes", "Sample ID": "L3S242", "Subject": "subject-1", "Year": 2008.0, "qurro_balance": null}, {"BarcodeSequence": "CACGACAGGCTA", "BodySite": "right palm", "Day": 20.0, "DaysSinceExperimentStart": 84.0, "Description": "subject-1.right-palm.2009-1-20", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 1.0, "ReportedAntibioticUsage": "No", "Sample ID": "L3S294", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "AGTGTCACGGTG", "BodySite": "right palm", "Day": 17.0, "DaysSinceExperimentStart": 112.0, "Description": "subject-1.right-palm.2009-2-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 2.0, "ReportedAntibioticUsage": "No", "Sample ID": "L3S313", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CAAGTGAGAGAG", "BodySite": "right palm", "Day": 17.0, "DaysSinceExperimentStart": 140.0, "Description": "subject-1.right-palm.2009-3-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 3.0, "ReportedAntibioticUsage": "No", "Sample ID": "L3S341", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CATCGTATCAAC", "BodySite": "right palm", "Day": 14.0, "DaysSinceExperimentStart": 168.0, "Description": "subject-1.right-palm.2009-4-14", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 4.0, "ReportedAntibioticUsage": "No", "Sample ID": "L3S360", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "ATCGATCTGTGG", "BodySite": "right palm", "Day": 28.0, "DaysSinceExperimentStart": 0.0, "Description": "subject-2.right-palm.2008-10-28", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 10.0, "ReportedAntibioticUsage": "Yes", "Sample ID": "L3S378", "Subject": "subject-2", "Year": 2008.0, "qurro_balance": null}, {"BarcodeSequence": "GCGTTACACACA", "BodySite": "right palm", "Day": 17.0, "DaysSinceExperimentStart": 140.0, "Description": "subject-2.right-palm.2009-3-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 3.0, "ReportedAntibioticUsage": "No", "Sample ID": "L4S112", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "GAACTGTATCTC", "BodySite": "right palm", "Day": 14.0, "DaysSinceExperimentStart": 168.0, "Description": "subject-2.right-palm.2009-4-14", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 4.0, "ReportedAntibioticUsage": "No", "Sample ID": "L4S137", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CTCGTGGAGTAG", "BodySite": "right palm", "Day": 20.0, "DaysSinceExperimentStart": 84.0, "Description": "subject-2.right-palm.2009-1-20", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 1.0, "ReportedAntibioticUsage": "No", "Sample ID": "L4S63", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CAGTGTCAGGAC", "BodySite": "tongue", "Day": 28.0, "DaysSinceExperimentStart": 0.0, "Description": "subject-1.tongue.2008-10-28", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 10.0, "ReportedAntibioticUsage": "Yes", "Sample ID": "L5S104", "Subject": "subject-1", "Year": 2008.0, "qurro_balance": null}, {"BarcodeSequence": "ATCTTAGACTGC", "BodySite": "tongue", "Day": 20.0, "DaysSinceExperimentStart": 84.0, "Description": "subject-1.tongue.2009-1-20", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 1.0, "ReportedAntibioticUsage": "No", "Sample ID": "L5S155", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CAGACATTGCGT", "BodySite": "tongue", "Day": 17.0, "DaysSinceExperimentStart": 112.0, "Description": "subject-1.tongue.2009-2-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 2.0, "ReportedAntibioticUsage": "No", "Sample ID": "L5S174", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CGATGCACCAGA", "BodySite": "tongue", "Day": 17.0, "DaysSinceExperimentStart": 140.0, "Description": "subject-1.tongue.2009-3-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 3.0, "ReportedAntibioticUsage": "No", "Sample ID": "L5S203", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CTAGAGACTCTT", "BodySite": "tongue", "Day": 14.0, "DaysSinceExperimentStart": 168.0, "Description": "subject-1.tongue.2009-4-14", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 4.0, "ReportedAntibioticUsage": "No", "Sample ID": "L5S222", "Subject": "subject-1", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "CTGGACTCATAG", "BodySite": "tongue", "Day": 28.0, "DaysSinceExperimentStart": 0.0, "Description": "subject-2.tongue.2008-10-28", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 10.0, "ReportedAntibioticUsage": "Yes", "Sample ID": "L5S240", "Subject": "subject-2", "Year": 2008.0, "qurro_balance": null}, {"BarcodeSequence": "GAGGCTCATCAT", "BodySite": "tongue", "Day": 20.0, "DaysSinceExperimentStart": 84.0, "Description": "subject-2.tongue.2009-1-20", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 1.0, "ReportedAntibioticUsage": "No", "Sample ID": "L6S20", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "GATACGTCCTGA", "BodySite": "tongue", "Day": 17.0, "DaysSinceExperimentStart": 140.0, "Description": "subject-2.tongue.2009-3-17", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 3.0, "ReportedAntibioticUsage": "No", "Sample ID": "L6S68", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}, {"BarcodeSequence": "GATTAGCACTCT", "BodySite": "tongue", "Day": 14.0, "DaysSinceExperimentStart": 168.0, "Description": "subject-2.tongue.2009-4-14", "LinkerPrimerSequence": "GTGCCAGCMGCCGCGGTAA", "Month": 4.0, "ReportedAntibioticUsage": "No", "Sample ID": "L6S93", "Subject": "subject-2", "Year": 2009.0, "qurro_balance": null}], "qurro_sample_metadata_fields": ["BarcodeSequence", "BodySite", "Day", "DaysSinceExperimentStart", "Description", "LinkerPrimerSequence", "Month", "ReportedAntibioticUsage", "Sample ID", "Subject", "Year"]}, "encoding": {"color": {"field": "BarcodeSequence", "type": "nominal"}, "tooltip": [{"field": "Sample ID", "type": "nominal"}, {"field": "qurro_balance", "type": "quantitative"}], "x": {"axis": {"labelAngle": -45}, "field": "BarcodeSequence", "scale": {"zero": false}, "type": "nominal"}, "y": {"field": "qurro_balance", "scale": {"zero": false}, "title": "Current Natural Log-Ratio", "type": "quantitative"}}, "mark": {"type": "circle"}, "selection": {"selector002": {"bind": "scales", "encodings": ["x", "y"], "type": "interval"}}, "title": "Samples"};
        var countJSON = {"0160e14a78b18b903618f11bc732746e": {"L1S105": 202.0, "L1S208": 3.0, "L1S257": 6.0, "L1S57": 32.0, "L1S76": 9.0, "L1S8": 582.0, "L3S242": 23.0}, "01b99cb344ed2530f7d80897ffe257a9": {"L2S155": 30.0, "L3S294": 11.0, "L3S341": 13.0}, "01ce91fd8dbecf637eb5e67cdab5c5aa": {"L2S155": 2.0, "L2S222": 4.0, "L2S382": 16.0, "L4S137": 6.0}, "01e0b7ac306895be84179f2715af269b": {"L1S105": 110.0, "L1S208": 215.0, "L1S257": 54.0, "L1S281": 184.0, "L1S57": 103.0, "L1S76": 74.0}, "025dd300b0ccbd9d5898969c2a1ab138": {"L4S112": 14.0}, "02878fe3ccc81d4c884ca5574178d6a0": {"L1S105": 21.0}, "029cc71dc93341de90188b686798aa0d": {"L4S63": 11.0}, "02ef9a59d6da8b642271166d3ffd1b52": {"L1S57": 13.0, "L1S76": 22.0}, "0305a4993ecf2d8ef4149fdfc7592603": {"L1S105": 1198.0, "L1S140": 647.0, "L1S208": 964.0, "L1S257": 919.0, "L1S281": 532.0, "L1S57": 415.0, "L1S76": 334.0, "L1S8": 243.0, "L3S242": 28.0, "L3S378": 117.0, "L4S137": 5.0}, "0310f41e594c49368dde5c5993a7a5d0": {"L2S204": 14.0}, "047b7fb62a5e9d2711e639ae1cb1519a": {"L1S208": 7.0, "L2S240": 48.0, "L5S104": 81.0, "L5S155": 73.0, "L5S174": 253.0, "L5S203": 101.0, "L5S222": 114.0, "L6S20": 31.0, "L6S68": 20.0, "L6S93": 175.0}, "04c7e0ea3038f942f5a28778a74cd1c0": {"L2S382": 23.0, "L4S137": 5.0, "L6S93": 3.0}, "052128d7d424728578efe7852b0afd0d": {"L1S105": 72.0, "L1S208": 20.0, "L1S57": 125.0, "L1S76": 63.0, "L1S8": 30.0, "L3S242": 8.0}, "063fa4f5a6fa894f7f8243468324ac5e": {"L2S175": 15.0, "L2S222": 21.0, "L4S112": 33.0, "L4S63": 30.0}, "072698f9668d5a094cdc1a672acc4747": {"L2S357": 4.0, "L4S112": 10.0, "L4S137": 12.0, "L4S63": 13.0}, "0741ae033054073fece98b9948ec4387": {"L1S8": 18.0}, "07b2b1c3771f46d82c90b20a79fb3d04": {"L2S204": 6.0, "L2S222": 39.0, "L3S360": 13.0, "L4S63": 34.0}, "0a50155a2def454344e1f2305eff7092": {"L2S382": 17.0}, "0a69950e803a5d9e7166c450e44f43cf": {"L1S140": 104.0, "L1S208": 72.0, "L1S257": 75.0, "L1S281": 177.0, "L1S57": 24.0, "L1S76": 149.0, "L3S378": 31.0}, "0b925631436d3775231b60f9d0011cae": {"L2S155": 25.0, "L2S175": 28.0, "L2S204": 20.0, "L2S222": 17.0, "L2S309": 20.0, "L2S357": 7.0, "L3S313": 7.0, "L3S341": 10.0, "L4S112": 13.0, "L4S63": 56.0}, "0bd7addf1b999f01ad58fec8412b8931": {"L2S155": 4.0, "L2S175": 4.0, "L2S382": 48.0, "L4S137": 20.0}, "0be23adca941c1335eb04db17dc66e98": {"L2S155": 6.0, "L2S382": 20.0, "L4S112": 7.0, "L4S137": 20.0}, "0c4b17f88dae47697d3bceb3663f47ce": {"L1S140": 63.0, "L1S281": 15.0}, "0dcaf9358eddf685864afb883cdf2363": {"L2S240": 4.0, "L5S155": 7.0, "L5S174": 6.0, "L5S203": 17.0, "L5S222": 8.0, "L6S20": 14.0, "L6S93": 10.0}, "0effb4592c11dcdd619141df770563e1": {"L2S222": 9.0, "L4S63": 14.0}, "0f006e3e638afedde4892706134a4fb9": {"L4S63": 13.0}, "0f2a155a57fe6d0bf34767080706b3e1": {"L2S175": 25.0, "L4S112": 19.0}, "0f55566622d8244073432b2e67b24baa": {"L1S140": 5.0, "L1S57": 26.0, "L1S76": 13.0}, "101968ec709b68fcd964a68ff226dcd1": {"L2S382": 29.0, "L4S137": 18.0}, "10710d3d706451c3536228e4b7d146db": {"L2S155": 27.0, "L2S175": 18.0, "L4S112": 8.0, "L4S63": 16.0}, "126d3c82f184c4d9058cab124f287968": {"L2S222": 20.0, "L4S112": 42.0, "L4S63": 20.0}, "12ed71ced0f4e45c0aa5b37144e6f84b": {"L4S63": 3.0, "L5S174": 7.0, "L5S203": 4.0, "L6S20": 3.0, "L6S68": 7.0}, "136e9f5aa470119165e59d202fdb318c": {"L1S105": 16.0, "L1S140": 20.0, "L1S57": 19.0, "L1S76": 38.0}, "1395953fab837ed426f9b2ba24da41b1": {"L1S57": 7.0, "L1S76": 7.0}, "145f11599b92ad3a4c93896b0edf8c0c": {"L1S140": 11.0, "L1S208": 8.0, "L1S257": 20.0, "L1S281": 98.0}, "14d168c89e381de6fc3091837a557e48": {"L2S222": 42.0, "L4S112": 39.0}, "154709e160e8cada6bfb21115acc80f5": {"L1S105": 812.0, "L1S140": 1176.0, "L1S208": 713.0, "L1S257": 407.0, "L1S281": 242.0, "L1S57": 1084.0, "L1S76": 929.0, "L1S8": 1622.0, "L2S240": 3.0, "L2S309": 17.0, "L3S242": 234.0, "L3S378": 201.0, "L5S155": 8.0}, "15992a34ae0f42d6b5a21eeaaef674ba": {"L2S204": 14.0}, "160029903cd9c779390f4719179aeea2": {"L1S257": 4.0, "L1S281": 4.0, "L1S57": 6.0, "L1S76": 4.0}, "162ed46308ef9dd1600fb0fe7c90b186": {"L2S175": 10.0, "L2S357": 46.0, "L4S112": 203.0}, "16564bc936c839c893f951bab613a30b": {"L4S137": 91.0}, "1685b25b43eb070cd7655de8c2d8c0a4": {"L2S155": 118.0, "L2S175": 50.0, "L2S204": 56.0, "L2S222": 36.0, "L2S309": 25.0, "L2S357": 9.0, "L3S294": 9.0, "L3S313": 5.0, "L3S341": 9.0, "L3S360": 15.0, "L4S112": 14.0, "L4S137": 4.0, "L4S63": 360.0}, "185df2b73b4805164470dfaea2d05223": {"L2S175": 38.0, "L2S204": 20.0, "L3S294": 5.0, "L3S313": 19.0, "L4S63": 45.0}, "1893b0ad352ee7db0f565bc4594e6dc6": {"L1S208": 38.0}, "1a4ff0ff25ff4e919711422c2f605519": {"L2S175": 3.0, "L2S204": 4.0, "L2S309": 3.0, "L4S112": 9.0, "L4S63": 28.0}, "1a5ff65c7f309159df626f810d96ae8b": {"L2S382": 19.0, "L4S112": 8.0, "L4S137": 17.0}, "1a8d25f7529d783a219ef689701dd4e2": {"L1S208": 6.0, "L1S257": 7.0, "L1S281": 12.0}, "1b448e00c078f81e49a61933072345d2": {"L2S175": 24.0, "L2S204": 35.0, "L2S222": 62.0, "L2S309": 22.0, "L3S360": 22.0, "L4S63": 91.0}, "1b75626f6834620dc2c729a1a81f497a": {"L2S155": 56.0, "L3S294": 39.0}, "1b963d0d7457ac133aed9497f03b5a64": {"L2S222": 40.0, "L4S63": 91.0}, "1c0a00b159b2154357cc9bc7499c58b2": {"L4S112": 11.0, "L4S63": 19.0}, "1c40ac02c49ea9e03881b0f183373417": {"L5S155": 22.0, "L5S203": 22.0}, "1c7d1f74c2c43b872972f974eb196915": {"L2S175": 3.0, "L2S204": 10.0, "L2S222": 12.0, "L2S309": 2.0, "L3S341": 6.0, "L3S360": 5.0, "L4S112": 18.0, "L4S63": 19.0}, "1ca133f4d30ab344f11e6624e841d9cd": {"L2S382": 14.0, "L4S137": 7.0}, "1d17561d16d803f652b0d6bdd671c1cc": {"L1S105": 25.0, "L1S140": 34.0, "L1S208": 26.0, "L1S257": 23.0, "L1S8": 43.0, "L3S242": 9.0}, "1d284bea12006c939c03d622ce2abd5e": {"L2S222": 59.0, "L3S360": 33.0, "L4S112": 20.0, "L4S63": 24.0}, "1d2e5f3444ca750c85302ceee2473331": {"L1S208": 5.0, "L1S8": 5.0, "L2S155": 27.0, "L2S175": 51.0, "L2S240": 1209.0, "L2S309": 25.0, "L2S357": 36.0, "L2S382": 76.0, "L3S242": 5.0, "L3S313": 20.0, "L3S341": 16.0, "L4S112": 124.0, "L4S137": 355.0, "L4S63": 84.0, "L5S104": 549.0, "L5S155": 453.0, "L5S174": 255.0, "L5S203": 343.0, "L5S222": 374.0, "L5S240": 551.0, "L6S20": 950.0, "L6S68": 1215.0, "L6S93": 541.0}, "1e00822422afb942c9955cd450385a8b": {"L4S112": 24.0}, "1e1e0cca52fab68a8c7ba5256aeadd6d": {"L1S257": 14.0}, "1e9fc37a1112b198ed3d0543db7863c8": {"L2S382": 19.0, "L3S360": 2.0, "L5S155": 5.0}, "1ea96d595539133266a3dbd49daac1e4": {"L1S140": 10.0, "L2S240": 4.0}, "1edc5497d3daf6d914427d32b71daa52": {"L2S155": 12.0, "L2S204": 3.0, "L2S222": 8.0, "L2S309": 7.0, "L2S357": 5.0, "L4S63": 37.0}, "1efd43e712291698f34853dac3b67f54": {"L4S63": 34.0}, "1f0a072da4906270a684a389c1586582": {"L1S140": 52.0, "L1S208": 10.0, "L1S257": 26.0, "L1S281": 15.0, "L3S378": 9.0}, "1f50ac250618ced095a2a5c34bae7651": {"L2S240": 34.0, "L4S137": 14.0, "L5S104": 10.0, "L5S155": 8.0, "L5S174": 21.0, "L5S203": 38.0, "L5S222": 18.0, "L5S240": 7.0, "L6S20": 73.0, "L6S68": 31.0, "L6S93": 107.0}, "1f926dee6544b252d38067cc7753383a": {"L2S382": 20.0, "L4S137": 16.0}, "201b6484b6abe3d4c587464be6cbd574": {"L1S105": 18.0, "L1S140": 22.0, "L1S57": 14.0, "L1S76": 25.0}, "20fb19136419ba2826c941aa152fa0eb": {"L2S155": 5.0, "L2S175": 3.0, "L4S112": 2.0, "L4S63": 5.0}, "21a0198d0a83a8f3ec0e401067138940": {"L1S140": 51.0, "L1S208": 21.0, "L1S257": 40.0, "L1S281": 29.0, "L1S57": 10.0, "L1S76": 14.0, "L3S378": 12.0}, "22ed70e219c67c2bf4e20e0b144b12bb": {"L2S204": 31.0}, "2328e11c4256f1f05395b7a377381279": {"L2S204": 13.0}, "24443b70088636edf08f0c9572d7faf4": {"L4S137": 124.0}, "24523c45ca39b6c81a01ce286c0c092b": {"L2S175": 12.0, "L2S382": 16.0, "L4S112": 20.0, "L4S137": 53.0}, "24dfe6a7325e4f2be7dbd522ef613e42": {"L1S140": 26.0, "L1S8": 46.0}, "2514cdaab96a1a42cf15506f2ecf6439": {"L2S240": 46.0, "L4S137": 11.0, "L5S104": 22.0, "L5S155": 10.0, "L5S174": 15.0, "L5S203": 25.0, "L5S222": 18.0, "L5S240": 17.0, "L6S20": 83.0, "L6S68": 36.0, "L6S93": 30.0}, "251eb140eb9387372897c5f7db6f954c": {"L4S112": 10.0, "L4S137": 5.0}, "26133b4163fdcd22d86f4e04e74154f1": {"L1S208": 40.0, "L1S257": 67.0, "L1S281": 136.0}, "26b8b1509edf09c438db1634308c3c90": {"L2S175": 14.0, "L3S341": 3.0, "L4S112": 5.0, "L4S137": 21.0, "L4S63": 5.0, "L6S68": 61.0, "L6S93": 136.0}, "2835a5008083ae7290acbca001520ad1": {"L2S357": 13.0}, "28560cffcd31045fa07dd88557b43e05": {"L2S175": 9.0, "L2S204": 14.0, "L2S222": 9.0, "L3S313": 3.0, "L4S63": 17.0}, "29a92aecac56c855cbfc0debf9bda0c8": {"L1S140": 44.0, "L1S208": 16.0, "L1S257": 19.0, "L1S281": 24.0, "L1S57": 48.0, "L1S76": 32.0, "L1S8": 37.0, "L3S378": 16.0}, "2ab2f3551b7aa27fd483fdcbaa1a0afb": {"L3S360": 3.0, "L4S63": 18.0}, "2b148d88c49e316f85b6e7863089a886": {"L1S105": 7.0, "L1S57": 23.0, "L1S8": 7.0}, "2b427cf77172293239bc1c1cdb32ace4": {"L4S63": 16.0}, "2b6445815ec98d21dbe9640083f30d2f": {"L4S63": 15.0}, "2ca928ad9749bb9726c35d6528fefec1": {"L2S155": 9.0, "L2S222": 11.0, "L2S309": 7.0, "L4S112": 9.0, "L4S63": 26.0}, "2ce0fa88ec7cfdda2eeb0698cdad47e8": {"L2S204": 14.0}, "2cec2792e54f61e12e1a0b2507826118": {"L2S204": 22.0, "L2S357": 10.0}, "2de266b1ffa8e9ec6383c98096caf8f0": {"L4S63": 63.0}, "2e202c4e4e803dbc6d54c9e3117afedd": {"L2S382": 20.0, "L4S112": 6.0, "L4S137": 53.0}, "2e55763e77234a7bfc3a311067a0c7e1": {"L1S281": 196.0, "L1S57": 73.0}, "2f09559bc1ffcc3ea06ae2766194920b": {"L4S63": 12.0}, "2f4c5e75c0e4cdfcbddbe93ef1f410a3": {"L2S155": 10.0, "L2S222": 5.0, "L2S382": 6.0, "L3S313": 6.0, "L4S112": 3.0, "L4S137": 28.0, "L4S63": 59.0}, "2fa276cce32e900f0f68d30e460b8f61": {"L1S140": 18.0, "L1S208": 30.0, "L1S257": 29.0, "L1S281": 11.0, "L1S57": 8.0, "L3S378": 6.0}, "2ff525a1e58c54525e7f2d68a6c0b23e": {"L2S240": 14.0, "L5S174": 6.0, "L5S222": 13.0, "L5S240": 5.0, "L6S20": 17.0, "L6S68": 8.0, "L6S93": 133.0}, "30273eb317696f87e7b6fd37ada4bb8f": {"L2S204": 8.0, "L2S222": 20.0, "L3S360": 6.0, "L4S112": 6.0}, "30a88dc67e6a522087c3dfc8019550a6": {"L2S382": 23.0, "L4S112": 22.0, "L4S137": 38.0}, "30ebe1a33c21c25c55e4fdbb5894b832": {"L2S175": 3.0, "L2S382": 37.0}, "30faafef155964edd9db9374f36c45bf": {"L1S105": 15.0, "L1S208": 19.0, "L1S257": 52.0, "L1S281": 36.0, "L1S76": 27.0}, "3111520c8424a2a5bdd46558ae7650e8": {"L1S57": 22.0}, "3125abe90c7ae91aec06eb104d71845f": {"L2S155": 15.0, "L2S357": 18.0, "L3S294": 10.0, "L4S112": 21.0, "L4S137": 19.0, "L4S63": 82.0}, "31ed03e41d53de58a6348a242165c05b": {"L2S204": 7.0, "L3S341": 12.0}, "3253177a44672689e4e154e842d63e35": {"L3S360": 16.0}, "32875774cffdc8c820f91d8e86f9a0e6": {"L1S140": 14.0, "L1S257": 16.0, "L1S57": 51.0}, "328cf8ca7cded30705336cf036a2df45": {"L4S137": 12.0}, "33176e81f3e7ef2b9de1b783ff1ca33c": {"L1S140": 10.0, "L1S57": 8.0}, "344b020d867e3210563eaf40b0c557ef": {"L2S222": 67.0, "L3S360": 27.0}, "34e40677eda6fb724e9323b0835d5ab0": {"L1S208": 13.0, "L1S257": 17.0, "L1S281": 15.0}, "35b6dde81c92eb7f66ca9f741da3514e": {"L2S222": 17.0}, "3677e15d86603bf0a6bb50f8b010afe7": {"L1S140": 17.0, "L1S8": 23.0}, "37c7d17f9e371c1e11a0e22b1ce15ab0": {"L2S155": 5.0, "L4S112": 3.0, "L4S63": 33.0}, "37d242005eb3c4239ad2c00158ea99a1": {"L2S155": 5.0, "L4S137": 6.0}, "38aff035451e491e5905508b9a173fb6": {"L2S155": 7.0, "L2S175": 27.0, "L2S222": 9.0, "L3S313": 14.0, "L3S360": 6.0, "L4S112": 10.0, "L4S63": 7.0}, "393e6e2cbe258ed27a4ca0a2ee0d2cdc": {"L1S105": 26.0, "L1S140": 18.0, "L1S208": 10.0, "L1S57": 45.0, "L1S76": 41.0, "L1S8": 28.0}, "3982159c2603cacc4bc4893003bda323": {"L1S140": 32.0, "L1S208": 45.0, "L1S257": 64.0, "L3S378": 4.0}, "39b5567d2d979a9172c02435a5ede59d": {"L4S137": 53.0}, "3a1c2d5547ddb7f76306a042f8bef6a4": {"L2S155": 6.0, "L2S175": 18.0, "L2S222": 33.0, "L3S341": 10.0, "L4S112": 28.0, "L4S63": 55.0}, "3a69cb2f27ac76a05405efbb5088d249": {"L2S175": 6.0, "L2S382": 41.0, "L3S341": 3.0, "L4S112": 14.0, "L4S137": 41.0, "L5S203": 3.0, "L6S93": 3.0}, "3add7df323955b22d1cea664ef38165d": {"L1S105": 11.0, "L1S57": 29.0, "L1S76": 14.0}, "3ae3e825c5e3862af6c17798e2b40a37": {"L1S257": 122.0, "L1S281": 126.0}, "3b65e1db6742cc44493248fff266f564": {"L1S57": 69.0}, "3b74a95b189e134bb34c191b7693455d": {"L2S382": 7.0, "L4S137": 42.0}, "3b795f0122b28b0e6a07bec73894acee": {"L1S208": 35.0}, "3bb6760ebcd348e0c695a5fb5fccf994": {"L2S204": 12.0, "L4S63": 23.0}, "3bf2fc236887eda11c969b84d30f9fbf": {"L1S140": 11.0, "L2S240": 141.0, "L3S378": 6.0}, "3c9c437f27aca05f8db167cd080ff1ec": {"L2S240": 207.0, "L3S313": 8.0, "L4S112": 19.0, "L4S137": 45.0, "L4S63": 10.0, "L5S104": 183.0, "L5S155": 118.0, "L5S174": 695.0, "L5S203": 159.0, "L5S222": 414.0, "L5S240": 78.0, "L6S20": 167.0, "L6S68": 137.0, "L6S93": 808.0}, "3cdd97ba69a504117de24626ba790e96": {"L2S155": 75.0, "L2S175": 17.0, "L2S240": 4.0, "L2S382": 5.0, "L3S294": 29.0, "L3S313": 8.0, "L4S112": 17.0}, "3d6555a4886c6e4a89104136dd5ca39e": {"L2S382": 8.0, "L4S137": 15.0}, "3d6f762d8cda1915ad93d014e391c118": {"L2S155": 4.0, "L2S204": 2.0, "L4S112": 6.0, "L4S63": 11.0}, "3e2c7eb0316409806267a8d9845b0b13": {"L2S382": 34.0, "L4S137": 45.0, "L6S93": 8.0}, "3ef461f213bfc675ddf0b1bfeef2dc52": {"L1S105": 35.0, "L1S257": 79.0, "L1S281": 48.0, "L1S57": 120.0, "L1S76": 86.0}, "3f448350064694e647b284259bdebb91": {"L4S63": 43.0}, "3f61c9eee7bfb0326d3efb8da077b0da": {"L4S63": 13.0}, "401d7866836c54f3cd18bd0fc814885e": {"L2S155": 16.0, "L2S175": 16.0, "L2S222": 10.0, "L2S240": 7.0, "L2S309": 9.0, "L2S382": 10.0, "L3S313": 8.0, "L3S341": 4.0, "L4S112": 16.0, "L4S137": 41.0, "L4S63": 77.0}, "4075a90811bf9c19f02f5aa2ece6da37": {"L2S222": 31.0, "L2S309": 27.0, "L3S360": 26.0, "L4S112": 15.0, "L4S63": 97.0}, "4132561a08d25757e4bee9f73ec4a70a": {"L2S175": 22.0, "L2S382": 39.0, "L3S313": 22.0, "L4S137": 72.0}, "41735c13fb7f63db49b10fba5d959ce3": {"L2S155": 51.0, "L2S175": 66.0, "L2S382": 102.0, "L3S294": 23.0, "L4S137": 187.0, "L5S104": 19.0, "L5S203": 29.0}, "41c686088d124f17c99dcf9bf3acf9d5": {"L2S155": 8.0, "L4S137": 20.0}, "41cb0c62655aa8da8968a06cde0f14a1": {"L2S382": 25.0, "L4S137": 25.0}, "41fedaa9200e2933821f84ecdc0b0772": {"L1S105": 91.0, "L1S140": 48.0, "L1S208": 32.0, "L1S257": 14.0, "L1S281": 13.0, "L1S57": 188.0, "L1S76": 75.0, "L1S8": 26.0, "L2S155": 8.0, "L3S378": 16.0}, "421da954b88f7175953a73ea34b933e0": {"L2S155": 4.0, "L2S222": 11.0}, "42872dc875fef6070dfa78984184c096": {"L2S240": 8.0, "L5S174": 7.0, "L5S222": 12.0, "L6S20": 8.0}, "43a9c44adeac51fd3ab95081da56d02d": {"L1S257": 18.0, "L1S281": 13.0, "L1S57": 26.0, "L1S76": 14.0}, "44543d9c6bb193c64d38c9bdb6790eec": {"L2S240": 27.0, "L4S112": 13.0, "L4S137": 30.0, "L5S174": 27.0, "L6S93": 14.0}, "44f993a57b632b8fde0c34ed075e1d66": {"L2S155": 6.0, "L2S175": 5.0, "L2S204": 3.0, "L3S313": 12.0}, "44ff26d8105cf822417b4b0c4eb27c02": {"L1S105": 98.0, "L1S140": 195.0, "L1S208": 235.0, "L1S257": 126.0, "L1S281": 94.0, "L1S57": 101.0, "L1S76": 52.0, "L1S8": 86.0, "L3S242": 13.0, "L3S378": 34.0}, "4516f28133b919f8d8039ece23d8dd2e": {"L2S382": 18.0, "L4S137": 15.0}, "457c3dbae079470f3cf0bf146c191e1f": {"L4S63": 15.0}, "458462fa1e15c439f12deec2f19af933": {"L2S382": 19.0}, "459244e45f29ce28991de0114a16f9fa": {"L2S382": 10.0, "L4S137": 15.0}, "45c36b8b2965484407b8b213419d4c6c": {"L4S112": 16.0}, "465e9cab9abce306c1e0f7459b325c33": {"L1S57": 85.0, "L2S155": 2.0}, "469e4ff2129066178b74b112829fc03c": {"L2S357": 103.0, "L4S112": 143.0, "L4S63": 240.0}, "4738a05820f1a7840410c66476953498": {"L2S222": 10.0, "L2S309": 4.0, "L4S63": 9.0}, "475741f076c42d2c75d2d63c14fe4d3f": {"L2S382": 55.0, "L4S137": 52.0, "L5S155": 13.0}, "480b52afa972e6deb75357ec39db1998": {"L2S222": 17.0}, "48eda83fda558aea8fdd32b9c8dfff98": {"L1S105": 6.0, "L2S155": 12.0, "L2S175": 3.0, "L2S204": 3.0, "L3S341": 2.0, "L4S112": 6.0, "L4S137": 5.0, "L4S63": 7.0}, "491ef1635067f62c395bdffd58966092": {"L1S57": 15.0, "L1S76": 10.0}, "49232f27012731b0a65805c0919e2bbc": {"L2S240": 4.0, "L6S93": 94.0}, "4980b85712efeef1fc4563a9a949fe2e": {"L2S222": 107.0, "L3S360": 83.0}, "498ae808db957a63e20e836e1bf77f54": {"L2S382": 25.0, "L4S137": 24.0}, "4a5387c4bc61f2d8f3d9d2de983ba556": {"L2S222": 59.0, "L3S360": 31.0}, "4aa8e1c58af1b89f613fe3bf2b81604e": {"L2S204": 8.0, "L4S63": 7.0}, "4ab53e40e06f3a9b0b9b2669d8a52f65": {"L4S137": 54.0}, "4b13979d719e78a50cb0eac34d72dec1": {"L1S257": 20.0, "L1S57": 35.0, "L1S76": 21.0}, "4b5eeb300368260019c1fbc7a3c718fc": {"L1S105": 2222.0, "L1S57": 2829.0, "L1S76": 3327.0, "L1S8": 2613.0, "L2S155": 13.0, "L2S175": 10.0, "L2S204": 23.0, "L2S357": 14.0, "L3S242": 362.0, "L3S313": 6.0, "L3S341": 13.0, "L4S112": 55.0, "L5S104": 10.0}, "4b8228f4d7d3809aa6827e8d9e11a9ae": {"L1S105": 11.0, "L1S140": 16.0, "L1S208": 11.0, "L1S257": 18.0, "L1S281": 17.0, "L1S57": 10.0, "L1S76": 14.0}, "4c4606a3dbb4f5b8bb1ad1db6dfc5617": {"L2S155": 7.0, "L2S175": 31.0, "L2S204": 3.0, "L2S222": 7.0, "L2S309": 31.0, "L2S357": 18.0, "L2S382": 35.0, "L3S294": 7.0, "L3S313": 11.0, "L3S341": 2.0, "L4S112": 87.0, "L4S137": 25.0, "L4S63": 106.0}, "4ce1be9cea00a1eb7f960600e1ff3cfa": {"L2S155": 63.0, "L3S294": 17.0, "L4S63": 15.0}, "4cecaa1cfabe89a905940ae23dd94a64": {"L2S382": 11.0}, "4ea5683e2c2a183c11c45dc8fbd0c67c": {"L2S382": 68.0, "L3S360": 26.0, "L4S112": 70.0, "L4S137": 272.0, "L4S63": 82.0}, "4ea8ed64f727e17c2ecf3616119876eb": {"L4S63": 15.0}, "4fccea69a702bcb90cc0147c0fff2995": {"L2S357": 10.0, "L4S112": 17.0, "L4S137": 28.0, "L6S68": 4.0, "L6S93": 6.0}, "4fdf8dcd9451f5742982d716fa9f0536": {"L2S155": 14.0, "L2S222": 38.0, "L2S357": 16.0, "L2S382": 172.0, "L3S360": 6.0, "L4S112": 43.0, "L4S137": 189.0, "L4S63": 18.0, "L5S203": 6.0, "L6S20": 22.0, "L6S68": 5.0, "L6S93": 3.0}, "500d6b485cef4c52aad211d6d6e6dbc7": {"L2S309": 49.0, "L2S357": 41.0, "L2S382": 63.0, "L4S112": 97.0, "L4S137": 259.0, "L4S63": 192.0}, "5042942b77f5b924b8f8c11de37a3626": {"L2S204": 18.0, "L2S222": 7.0, "L3S294": 9.0, "L3S313": 8.0, "L3S341": 5.0}, "50e96bbd1a8267119529843a1acb43a5": {"L2S155": 10.0, "L2S222": 16.0, "L3S341": 7.0, "L4S112": 7.0, "L4S63": 23.0}, "513de43781dc4c2831eb83b23940d66b": {"L2S155": 21.0, "L2S382": 36.0, "L3S313": 19.0, "L4S137": 50.0}, "51588a76b68ff3041e8b272256df5ae2": {"L2S382": 9.0, "L4S137": 9.0}, "51757b1a0a985640893725af5d87d350": {"L1S281": 29.0}, "51ddb685cfb1775931489ebbd3eef6ca": {"L2S155": 9.0, "L2S175": 11.0, "L2S382": 44.0, "L4S137": 27.0}, "535696cecf56f03d3401d7d6dbe66d7b": {"L1S105": 253.0, "L1S140": 62.0, "L1S208": 260.0, "L1S257": 137.0, "L1S281": 142.0, "L1S57": 103.0, "L1S76": 169.0, "L1S8": 88.0, "L3S242": 13.0}, "53729ba7429e5bd2fe96229b14452bdc": {"L2S240": 6.0, "L4S112": 27.0, "L4S137": 16.0, "L6S68": 4.0, "L6S93": 7.0}, "538c01338d48c71522ac629b17a01c9d": {"L4S112": 13.0}, "53dd9f9a89854c8ebdcfb105b7a26df1": {"L4S63": 21.0}, "5437cb1c86c72638cbbc12896f88d1b1": {"L1S105": 15.0, "L1S208": 24.0, "L1S257": 24.0, "L1S57": 18.0, "L1S76": 23.0, "L1S8": 5.0}, "5454ea14c70f0323a5e836aba10947b8": {"L4S112": 13.0}, "54a5af5112600a1faf06be268f95616e": {"L2S222": 35.0, "L3S360": 22.0}, "54b4964000ad1631e547c46a828ed1a0": {"L1S208": 12.0, "L1S57": 11.0, "L1S76": 16.0}, "54d098d009b89779530eaf43a1bb136a": {"L2S155": 27.0, "L2S204": 40.0, "L2S222": 407.0, "L2S357": 8.0, "L3S360": 69.0, "L4S112": 25.0, "L4S63": 61.0}, "55937e5781c91185e27a91216008e4ca": {"L1S105": 23.0, "L1S8": 33.0, "L3S242": 15.0}, "55ec4b057c122957d25013675512c73d": {"L2S222": 28.0, "L3S360": 11.0}, "5601f094afc823d75ccb34440645a99e": {"L5S104": 20.0, "L5S203": 21.0, "L5S222": 13.0, "L6S20": 92.0, "L6S68": 34.0}, "56c98126dde3abb2d263088db55e12c8": {"L2S175": 7.0, "L2S204": 91.0, "L2S222": 25.0, "L4S112": 18.0, "L4S63": 35.0}, "57b34afdff2e84fb9b0befd219edcb38": {"L1S105": 555.0, "L1S57": 219.0, "L1S76": 137.0}, "58d6cee566e26e231916ccc2093ae053": {"L2S155": 10.0, "L2S175": 8.0, "L2S204": 3.0, "L2S222": 2.0, "L2S309": 3.0, "L4S63": 22.0}, "59fefb91cc66ef6930b0201e4bf24cbb": {"L1S105": 17.0, "L1S57": 96.0}, "5a02c9985adcd7543dff8c846cff62a5": {"L2S155": 12.0, "L2S175": 12.0, "L2S222": 19.0, "L4S63": 19.0}, "5a61388e52a8005b6747280b9332d2de": {"L2S155": 12.0}, "5ada68b9a081358e1a7d5f1d351e656a": {"L2S240": 39.0, "L3S294": 2.0, "L5S104": 8.0, "L5S174": 8.0, "L5S203": 16.0, "L5S222": 25.0, "L5S240": 7.0, "L6S20": 40.0, "L6S68": 50.0, "L6S93": 66.0}, "5b220f66423e4004eb3520bfae1f25d0": {"L4S63": 17.0}, "5c82bad13c4ebd2ed1bd23a8c2e37fc5": {"L2S155": 17.0, "L2S175": 23.0, "L2S222": 17.0, "L2S357": 12.0, "L2S382": 4.0, "L3S294": 8.0, "L4S112": 51.0, "L4S137": 73.0, "L6S68": 5.0, "L6S93": 7.0}, "5decdad9c550489629ce441d32a69a1c": {"L2S222": 19.0, "L4S112": 28.0}, "5df503c1ddf8f3f4ac9e49e983e3d7fd": {"L1S140": 27.0, "L1S208": 11.0, "L1S281": 14.0}, "5e793ed595a0793ab477b17e78421bc5": {"L3S294": 13.0}, "5ec803f68f3c48cd9ce6436ccbd5b1e3": {"L2S309": 5.0, "L3S360": 9.0}, "5ed23cabf504db9af85bce57e9008ea2": {"L3S294": 20.0}, "5fb5ace22c46fefb30969da7bb0dcb74": {"L2S155": 8.0, "L2S204": 7.0, "L2S222": 18.0, "L3S360": 3.0, "L4S63": 8.0}, "626b8ee112be0ec208bb16445611d001": {"L2S204": 71.0, "L2S357": 17.0, "L3S341": 28.0}, "62bf37c50994a06e6c8c93355ad1caa0": {"L2S155": 24.0, "L2S175": 19.0, "L3S294": 25.0, "L3S313": 16.0}, "63145f49e7efc26729094a53d97c0cd1": {"L1S281": 15.0}, "636c27859c1ac0a7994ca8ed145d03fe": {"L2S155": 10.0, "L2S175": 134.0, "L2S222": 22.0, "L2S309": 67.0, "L2S357": 27.0, "L3S313": 34.0, "L4S112": 99.0, "L4S137": 3.0, "L4S63": 229.0}, "6401660183a33dded59f163fc63aab4d": {"L2S204": 4.0, "L2S222": 22.0}, "65fbdc4707be0814fa4faf52571cc2b5": {"L2S382": 13.0}, "66a605fcdaa020dbdd6136f241ea79d9": {"L1S105": 26.0, "L1S57": 27.0}, "66fb1fc4317badb5dfaec2bf8e5055d7": {"L2S222": 22.0, "L2S357": 10.0}, "678424c0e69dd311d2b536cfd69a91a4": {"L2S155": 6.0, "L4S63": 9.0}, "67e23140639733766b7e127f50221289": {"L2S155": 68.0, "L2S175": 106.0, "L2S204": 30.0, "L2S222": 20.0, "L2S309": 29.0, "L2S357": 70.0, "L2S382": 33.0, "L3S294": 13.0, "L3S313": 37.0, "L3S341": 10.0, "L3S360": 10.0, "L4S112": 188.0, "L4S137": 19.0, "L4S63": 135.0}, "67f9c74eeea5a4609bd1d2fab66ad3cc": {"L1S208": 44.0, "L1S281": 20.0, "L1S57": 15.0}, "684721318896ed01048f3502333c214d": {"L2S155": 19.0, "L4S112": 27.0, "L4S63": 168.0}, "684b032107a3a32f6664dea4ef723a42": {"L2S155": 5.0, "L2S222": 7.0, "L3S360": 3.0, "L4S112": 5.0, "L4S63": 3.0}, "685ea779ee012329ec2a171f1823f8a8": {"L2S382": 13.0, "L4S137": 13.0}, "68c05655a58355526692d3a1f0968aff": {"L3S341": 16.0, "L4S63": 21.0}, "699071a4a7ce68918e4cd93a61275ecd": {"L2S175": 44.0, "L2S240": 181.0, "L4S112": 73.0, "L4S137": 102.0, "L4S63": 37.0, "L5S104": 194.0, "L5S155": 165.0, "L5S174": 85.0, "L5S203": 190.0, "L5S222": 151.0, "L5S240": 48.0, "L6S20": 91.0, "L6S68": 185.0, "L6S93": 129.0}, "6a9b2745a31a3e5ae16682a323c28a4d": {"L2S204": 20.0}, "6b82e6cb771d45d6c925405b66299d7f": {"L2S155": 109.0, "L2S175": 49.0, "L3S313": 28.0, "L4S112": 26.0}, "6bd57e46e038faafe4bb747e1d494df7": {"L1S57": 6.0, "L1S76": 5.0}, "6be3ad080a12e28c46c9ca4f94710ac7": {"L2S382": 21.0, "L6S20": 12.0, "L6S93": 19.0}, "6be678de197b54f9a04f6c984b91ef22": {"L4S137": 49.0}, "6de4955c509e8f32f905760cad0beeae": {"L5S174": 5.0, "L6S20": 5.0, "L6S68": 7.0, "L6S93": 13.0}, "6edca9464612efff71d8f97299f01663": {"L5S174": 37.0, "L6S20": 53.0, "L6S68": 62.0, "L6S93": 366.0}, "6f384c926424d43c215fbe9337d55324": {"L4S112": 21.0}, "6fea19332b7fb980e2124d0339c596c2": {"L2S222": 24.0, "L3S313": 5.0, "L3S360": 15.0, "L4S63": 28.0}, "6ffdeb862aed8aedda8a8624fa960c57": {"L2S382": 13.0, "L4S137": 8.0}, "7103ca740aeadee8bdf7cedaefac990b": {"L4S137": 35.0}, "724c43ad3632cb8c5c6230c874551bd2": {"L2S204": 92.0, "L3S341": 17.0}, "726f76e9275bfa07ccb329dda324c58f": {"L2S382": 29.0}, "72cbf125e17c4e14d748543564d3d4ec": {"L2S175": 11.0}, "73291cac0e802b6a1fb25ae7079390ef": {"L1S257": 15.0}, "74106ca246bcf2da5c4f95b82aa6867a": {"L4S63": 23.0}, "7456c5136c45202afcf8000e2a8a01c5": {"L2S240": 12.0}, "74c2326ccd0bc2bd9e0f23f15b79ea16": {"L1S281": 5.0, "L1S57": 11.0, "L1S76": 15.0}, "75258a676bcd7e73c2437d6a2012d490": {"L2S175": 18.0, "L2S382": 94.0, "L4S137": 80.0, "L5S104": 8.0, "L6S93": 20.0}, "752621a2dcf600f86357e9c2fa1fc985": {"L2S175": 9.0, "L4S63": 11.0}, "7595e123b71bdae8a8c1c28b7405a5c0": {"L2S175": 6.0, "L2S222": 13.0, "L4S63": 5.0}, "76174505aef45f134d8068d5ad2c42aa": {"L2S155": 43.0, "L2S175": 14.0, "L2S204": 36.0, "L2S222": 31.0, "L2S309": 18.0, "L3S294": 7.0, "L3S360": 19.0, "L4S112": 16.0, "L4S63": 279.0}, "76e8305b47ef8b35c452b5490589fc95": {"L4S112": 12.0}, "77a517253ff10afeb78a37bc13d649a0": {"L1S208": 37.0, "L1S257": 13.0, "L1S281": 35.0}, "79dcabe7f92f8cf2723b796dcd2f239f": {"L2S382": 123.0, "L4S137": 79.0, "L5S203": 4.0}, "79e9e337b10e2d298bb1b3bde946782d": {"L1S105": 38.0, "L1S140": 60.0, "L1S208": 6.0, "L1S281": 5.0, "L1S76": 190.0, "L1S8": 245.0, "L2S222": 32.0, "L3S242": 41.0, "L3S378": 6.0}, "7a20f7055ca2c7462cfa6a7aef16ec28": {"L2S222": 31.0, "L3S360": 22.0}, "7a5d5e6f85da7ca91daa2d803e8f9279": {"L1S140": 62.0, "L1S208": 74.0, "L1S257": 58.0, "L1S281": 35.0}, "7b9b46a7c3fb8b76b1c68911a9b56da1": {"L2S222": 4.0, "L4S63": 7.0}, "7cd67e7e02db4db794fd67ab72755f8b": {"L4S112": 20.0}, "7cdabbffaaa6cc6d9f478d91f312a8ee": {"L2S382": 87.0}, "7dd981802694dec3ecdb61ee53805956": {"L2S175": 39.0, "L2S204": 11.0, "L3S313": 11.0, "L4S112": 5.0}, "7dd9c9124ec3f118a6cef1f0d422c011": {"L1S208": 224.0, "L1S257": 386.0, "L1S281": 140.0}, "7e4d5b19d3213719048fe55dfad0da3a": {"L1S257": 13.0}, "7e598ad34909a3fb8ff1623f1ede11a6": {"L2S155": 165.0, "L2S175": 293.0, "L2S204": 50.0, "L2S240": 27.0, "L2S309": 84.0, "L2S357": 114.0, "L3S294": 45.0, "L3S313": 66.0, "L3S341": 32.0, "L4S112": 296.0, "L4S137": 76.0, "L4S63": 302.0}, "7ee56e891d069e18c3c8eb866924a26c": {"L2S357": 9.0, "L4S63": 50.0}, "7eedfc5c8d0d6b8852fabb20d52a8c5d": {"L2S204": 73.0, "L2S309": 7.0, "L3S341": 7.0, "L4S112": 16.0, "L4S63": 37.0}, "7f2aa6f3481a4039dcc8d1b8be32beb7": {"L2S175": 10.0, "L2S382": 24.0, "L4S137": 11.0, "L5S174": 5.0}, "7f4909ae8d31a3995fa2c200c690a21f": {"L2S155": 12.0, "L2S175": 19.0, "L2S204": 9.0, "L2S222": 23.0, "L3S313": 6.0}, "7f99061140cbf6c9081a204380efd8e1": {"L2S382": 38.0, "L4S137": 23.0, "L6S93": 4.0}, "7fa8f515ee1ac5cb8b529b13e6a89790": {"L2S222": 18.0}, "7fee9350277038eef98dee70b4190563": {"L1S140": 9.0, "L1S257": 4.0, "L1S281": 7.0, "L1S76": 7.0, "L1S8": 13.0, "L3S242": 5.0, "L3S378": 2.0}, "80b20e907aa4fcf2309796bc303d151d": {"L1S140": 48.0}, "81351ef6b4d49a3a6b2fc24745d70305": {"L2S155": 11.0, "L2S204": 24.0, "L2S222": 107.0, "L3S341": 7.0, "L3S360": 38.0, "L4S112": 27.0, "L4S63": 32.0}, "816b94bcd935ca38afe71fd1e3c5356c": {"L1S105": 22.0, "L1S57": 20.0}, "816e266d71b9a9af9d3d74893dee443e": {"L2S222": 4.0, "L3S360": 3.0, "L4S63": 10.0}, "81fad06bda8cf753d87288f1d080da88": {"L2S382": 13.0}, "823698689031b0b9c2c5152f92ffc70f": {"L1S105": 13.0, "L1S208": 37.0, "L1S257": 19.0}, "82e72255267397b777a1afd44ea22755": {"L2S222": 14.0}, "831514b8b3617bed49e2a4bd9d3d6268": {"L4S63": 21.0}, "839fafb762395fab1ba257442ec29e7f": {"L2S382": 139.0, "L4S137": 75.0}, "846cbaf603b77be035fe0cb61d14a23c": {"L1S105": 29.0, "L1S140": 29.0, "L2S175": 5.0, "L3S313": 6.0, "L4S112": 22.0, "L4S137": 15.0, "L4S63": 37.0}, "84755bc954af6d3b39bb4c369e5992e7": {"L1S208": 55.0, "L1S257": 19.0, "L1S281": 25.0}, "848587c4a03949500c5815bd6edb7b6e": {"L2S155": 14.0, "L2S175": 94.0, "L3S341": 10.0}, "8659c05e82a2d1399cbc3fd26ab938e4": {"L1S140": 7.0, "L2S155": 15.0, "L4S112": 9.0, "L4S137": 9.0}, "867e71db0537674539934bf97db51bc0": {"L2S175": 4.0, "L2S382": 14.0, "L4S137": 2.0, "L6S68": 2.0}, "868528ca947bc57b69ffdf83e6b73bae": {"L1S140": 2276.0, "L1S208": 2156.0, "L1S257": 1205.0, "L1S281": 1772.0, "L2S309": 20.0, "L3S360": 13.0, "L3S378": 369.0, "L5S203": 5.0, "L5S240": 10.0, "L6S93": 9.0}, "868a4fe285b85fa1b8eb40071d5397be": {"L1S208": 30.0, "L1S8": 34.0, "L3S242": 16.0}, "87899779aec8d38dfaf48d895cfe8021": {"L1S208": 58.0, "L1S257": 50.0, "L1S281": 29.0}, "87a04eba5a3dc45f9e899d8ab4c050b4": {"L2S204": 6.0, "L2S222": 17.0}, "880968796af86b3d6270c228fe8e7026": {"L1S140": 89.0, "L1S208": 34.0, "L1S257": 62.0, "L1S281": 40.0, "L3S378": 22.0}, "88b4862756df007aa0c6bc2ba049708b": {"L2S240": 8.0, "L2S309": 3.0, "L4S137": 31.0, "L4S63": 7.0}, "8b111e12f8f73205bac732c7479a97e8": {"L4S112": 56.0}, "8b300bb35321f8c125cdc4c3a242bbc0": {"L4S112": 13.0}, "8bcc747f27b10bb3e1182fe530c7ed24": {"L2S382": 14.0, "L4S137": 7.0}, "8c001c89f020a1b78b26ee21d1d56746": {"L1S140": 7.0, "L2S155": 5.0}, "8c255f9dc0be58d1389877ec645f1a17": {"L2S204": 27.0}, "8c43291754ba53fa1e206f0ac7a18772": {"L2S382": 39.0}, "8c5f2b5fce1b357f54ed4c8c047b6845": {"L4S63": 19.0}, "8cd2a871fab61bdea4ef23a295c371cf": {"L2S357": 9.0, "L3S341": 18.0, "L4S112": 40.0, "L4S137": 35.0, "L4S63": 10.0}, "8da02c7114ba0d9ee40312926e037a8f": {"L2S204": 19.0, "L2S222": 23.0, "L2S382": 12.0, "L3S294": 17.0, "L4S137": 39.0, "L4S63": 31.0}, "8f0a7d866b4e5ebf1e34d0a44eb950a4": {"L1S208": 10.0, "L1S257": 11.0, "L1S281": 8.0}, "8fbf42d21b6c9c4a4e8e260ad1d6a1ab": {"L4S63": 14.0}, "9079bfebcce01d4b5c758067b1208c31": {"L2S155": 13.0, "L2S175": 30.0, "L2S204": 1484.0, "L2S222": 65.0, "L2S309": 22.0, "L2S357": 312.0, "L3S341": 395.0, "L3S360": 201.0, "L4S112": 670.0, "L4S137": 19.0, "L4S63": 145.0}, "909755d7142ea53c7f61c97c3586f26c": {"L2S155": 787.0, "L2S240": 26.0, "L2S382": 4.0, "L3S294": 301.0}, "90d32ffe026535b392c0bad850f213c4": {"L1S105": 616.0, "L1S208": 65.0, "L1S257": 12.0, "L1S281": 237.0, "L1S57": 593.0, "L1S76": 609.0, "L2S309": 18.0}, "9118606a87ac19f8d041da20f16f3236": {"L1S140": 82.0, "L1S208": 171.0, "L1S257": 220.0, "L1S281": 67.0, "L3S378": 18.0}, "919764896275058362e55f0849d2b38b": {"L1S140": 34.0, "L1S8": 42.0}, "91d0b3b7c0329b9a164b6e04a181f1d6": {"L1S281": 54.0, "L1S57": 46.0}, "921966b15e5f1508e8650d053443c385": {"L2S204": 6.0, "L2S222": 23.0, "L4S63": 15.0}, "94ca1389331a3a9230237844cfd545f6": {"L2S155": 14.0}, "9548347b69043c274ff7a1ce599a69ef": {"L4S63": 22.0}, "955280212814a2050dd2f640e10fc25d": {"L6S68": 23.0}, "955d8fcbb35e8bc04c8df0c6aae34d34": {"L3S341": 17.0, "L4S63": 42.0}, "956d0a6f5a8e1d2fbb39df909cc14894": {"L1S208": 44.0}, "9584fe0b6843a9817e1c217bb65caea8": {"L2S309": 10.0, "L4S137": 5.0}, "958bc15b660bce0b894665d13f910f5b": {"L2S155": 31.0, "L2S175": 50.0, "L2S204": 12.0, "L2S309": 14.0, "L2S357": 24.0, "L2S382": 7.0, "L3S294": 16.0, "L3S313": 13.0, "L4S112": 32.0, "L4S137": 27.0, "L4S63": 65.0}, "9590aed21545774c71a124f2b5200691": {"L2S309": 11.0, "L2S382": 5.0, "L4S112": 8.0, "L4S137": 8.0, "L4S63": 75.0}, "959a178855242ad3833af85d38ccff45": {"L4S63": 17.0}, "95f07780b7e9b8b504c2563e63950663": {"L2S382": 18.0, "L5S174": 9.0, "L6S93": 24.0}, "9616cf56be891f816aa7abc6a13c9e8f": {"L2S382": 54.0, "L4S137": 28.0}, "96a7dbb0e2c57e289c05b82e2db880be": {"L4S63": 73.0}, "97e0a84031c426df75af82aeff951f26": {"L2S175": 7.0, "L4S137": 29.0}, "9930e78f4486e70ced513d619dae53fb": {"L2S382": 13.0}, "997056ba80681bbbdd5d09aa591eadc0": {"L1S8": 3.0, "L2S175": 10.0, "L2S240": 632.0, "L2S309": 11.0, "L4S112": 9.0, "L4S137": 28.0, "L4S63": 33.0, "L5S104": 176.0, "L5S155": 44.0, "L5S174": 107.0, "L5S203": 203.0, "L5S222": 515.0, "L5S240": 169.0, "L6S20": 625.0, "L6S68": 895.0, "L6S93": 518.0}, "99e6b8fa779ca2689cdc55d164e593e8": {"L2S155": 7.0, "L2S175": 8.0}, "99f9d85c50cec960adab2a3f0f401371": {"L2S382": 3.0, "L4S137": 9.0}, "9acad60e1ad588fb9250aab68dee645d": {"L2S382": 61.0}, "9af77e369d2ba4b3bb6e0e808ed84d91": {"L2S382": 88.0, "L4S137": 167.0}, "9b0549bb6e63f681bf133d2c7996055d": {"L2S240": 2.0, "L2S382": 9.0, "L4S137": 5.0, "L5S174": 2.0, "L5S222": 3.0, "L6S20": 8.0, "L6S68": 11.0, "L6S93": 26.0}, "9b07cccc73bd232ffb6edb9427194c06": {"L2S222": 12.0}, "9b959f65abdb6cb9adc1d6160a5384ec": {"L2S204": 8.0, "L4S112": 9.0}, "9c6b4f83513e63a49ce33a8aeb1813ad": {"L1S208": 13.0}, "9cd30ed12a411f643a9f6c145e3b59d8": {"L4S63": 14.0}, "9d17e47f8102cca1e9a0a5b0776bb85a": {"L2S382": 6.0, "L4S137": 8.0}, "9d3ec96491b522546acbdfa3b21b6071": {"L2S222": 88.0, "L3S360": 48.0}, "9da7a39de7e82006cc9533681adf765a": {"L2S175": 26.0, "L4S137": 33.0}, "9df911e407318b496425698999a1d81f": {"L2S382": 8.0, "L4S137": 12.0}, "9e1c6b703a4312cce306c7757688a351": {"L1S208": 21.0, "L1S257": 31.0, "L1S281": 21.0}, "9f1913b781d2cde1c8a4c57b7dc2ab83": {"L2S240": 15.0, "L6S20": 25.0, "L6S68": 25.0}, "9f4cdae8a020a8d9c4f54e5abf5a5769": {"L2S155": 5.0, "L2S175": 8.0, "L3S313": 6.0, "L3S341": 2.0}, "9f6a3b261bc6acafa3d4a6d2de87f924": {"L4S63": 12.0}, "9f718b8f66b79c3de80546ca9a54539c": {"L2S240": 146.0, "L2S357": 9.0, "L2S382": 72.0, "L4S112": 34.0, "L4S137": 125.0, "L4S63": 24.0, "L5S104": 64.0, "L5S155": 28.0, "L5S174": 27.0, "L5S203": 44.0, "L5S222": 33.0, "L5S240": 62.0, "L6S20": 179.0, "L6S68": 133.0, "L6S93": 155.0}, "a03aa6a23dc8f296567452ec2242a5fd": {"L2S382": 15.0, "L4S137": 9.0}, "a049763053c277b16c2a318f41eb23b4": {"L2S155": 131.0, "L2S175": 868.0, "L2S204": 22.0, "L2S222": 34.0, "L2S309": 19.0, "L2S357": 58.0, "L2S382": 11.0, "L3S294": 84.0, "L3S313": 242.0, "L3S360": 9.0, "L4S112": 200.0, "L4S137": 33.0, "L4S63": 155.0}, "a0b0961c7ba318abff3e5a93f09f495e": {"L1S208": 27.0, "L1S257": 28.0, "L1S281": 18.0}, "a1b971c01ce0b220275c218adbe717c1": {"L1S140": 18.0, "L1S281": 4.0, "L1S57": 6.0, "L1S76": 9.0, "L1S8": 17.0}, "a3dc97e11838f1bf157aa875f2f6367d": {"L4S112": 20.0}, "a4c08e2c3a34038ea877b16d01736837": {"L1S105": 35.0, "L1S140": 28.0, "L1S57": 51.0, "L1S76": 55.0, "L1S8": 7.0, "L3S378": 14.0}, "a5185df881810390f29afa3ba3ccf522": {"L2S382": 19.0, "L4S137": 20.0}, "a54095a893fd5abc045d162bbe20644a": {"L3S294": 18.0}, "a5551fc60aa8bbaab737487552ea2a75": {"L1S57": 128.0, "L1S8": 63.0}, "a5df9a825c3d8eeb228a6781c3db134c": {"L1S105": 18.0, "L1S140": 8.0, "L1S208": 25.0, "L1S281": 7.0, "L1S57": 53.0, "L1S76": 32.0}, "a5e8aaab366d42b670d589ada160581c": {"L2S204": 9.0, "L4S112": 3.0}, "a621ed0faf5f6d7f3ad8f5e66cd41faf": {"L2S382": 23.0, "L4S137": 7.0}, "a659784c026bd9c8cde94da36aa656d7": {"L5S222": 8.0, "L6S20": 22.0, "L6S68": 11.0, "L6S93": 127.0}, "a6e9c3caf38d8be5744751bea41aa62f": {"L4S63": 14.0}, "a70441600c181b747a763ce5a7414a3f": {"L2S309": 6.0, "L2S382": 5.0, "L4S112": 3.0, "L4S63": 23.0}, "a826883ed572461c97a23561f7ecea3c": {"L2S222": 12.0, "L3S360": 9.0}, "a841dd7e2f38b26bb7bb37179b4141d5": {"L1S257": 15.0}, "a875cba4e2e4da128cec805cd014731f": {"L4S112": 10.0, "L5S203": 2.0, "L5S222": 13.0, "L6S20": 2.0, "L6S68": 4.0}, "a895b66cac813ac67ce1c908259b646f": {"L2S382": 96.0, "L4S112": 32.0, "L4S137": 28.0, "L6S68": 24.0, "L6S93": 30.0}, "aa24dbd408e5d69c6b0d62846145a244": {"L2S175": 9.0, "L3S313": 2.0, "L4S137": 14.0}, "aa668eb01ca9dcc59aeb1454b600c8c8": {"L1S208": 109.0, "L1S257": 3.0}, "aa9f89f9af07d53e077462471423f3ab": {"L2S204": 8.0, "L2S222": 8.0, "L3S341": 2.0, "L4S112": 15.0, "L4S63": 11.0}, "aadef7fba5a0754fb631409c11fb331f": {"L2S357": 20.0, "L4S112": 30.0, "L4S63": 19.0}, "ab4ef4399912b0507d8d1187e874684d": {"L2S175": 19.0, "L2S240": 190.0, "L5S155": 529.0, "L5S174": 84.0, "L5S203": 460.0, "L5S222": 481.0, "L5S240": 74.0, "L6S20": 203.0}, "ab6b063ed43d8cb3008e157a0a305c47": {"L1S105": 4.0, "L1S140": 126.0, "L1S208": 281.0, "L1S257": 295.0, "L1S281": 189.0, "L3S378": 31.0}, "ac809fd715cced98911f73f1dfb1ffb9": {"L2S155": 9.0, "L4S63": 22.0}, "acba6a53153faccd2c02a9c0e8a2d941": {"L2S155": 12.0, "L2S382": 14.0, "L4S137": 22.0}, "acfe4c003905a7074aeaf385b78ad9e0": {"L1S208": 111.0, "L1S257": 62.0, "L1S281": 56.0}, "ad41fe8f8be5b01c96549309937e3b14": {"L2S155": 95.0, "L2S175": 38.0, "L2S204": 31.0, "L2S222": 13.0, "L2S309": 68.0, "L2S357": 61.0, "L2S382": 29.0, "L3S294": 25.0, "L3S313": 22.0, "L3S341": 8.0, "L4S112": 77.0, "L4S137": 66.0, "L4S63": 448.0}, "ae25381e186978a7230f03484baede7c": {"L2S155": 3.0, "L4S63": 10.0}, "ae27459b7f5465815b1f565d792083ce": {"L2S240": 58.0, "L3S313": 2.0, "L5S104": 60.0, "L5S155": 7.0, "L5S174": 6.0, "L5S203": 13.0, "L5S222": 47.0, "L5S240": 25.0, "L6S20": 44.0, "L6S93": 257.0}, "ae4c61e598c093caa5b66b6919f02ba3": {"L2S222": 17.0}, "ae881162d813e498f40bf33b8e42d54a": {"L1S105": 12.0, "L1S208": 17.0, "L1S257": 12.0, "L1S57": 11.0, "L1S76": 11.0, "L1S8": 18.0}, "aee707afe3847427a6d3d34e31437923": {"L1S105": 5.0, "L1S8": 14.0}, "b00d44992702bd3743d7f353638d42f9": {"L1S140": 35.0, "L1S8": 33.0}, "b0ca0d2568c23c26c6704017eae471e1": {"L1S105": 14.0, "L4S137": 2.0, "L4S63": 9.0}, "b0f7e29de400c6b517b39230dc1b4365": {"L2S155": 11.0, "L2S175": 12.0, "L2S240": 12.0, "L2S382": 24.0, "L4S112": 21.0, "L4S137": 35.0, "L4S63": 13.0, "L5S104": 5.0, "L6S20": 8.0, "L6S68": 6.0, "L6S93": 13.0}, "b1141c1ab18997c3339e8229e0b9f41a": {"L2S204": 8.0, "L2S222": 12.0, "L4S63": 13.0}, "b1413b635612c7db2c140bc671789ec7": {"L4S63": 26.0}, "b1e22f094d8c64fb56dbacf680dab8c9": {"L2S240": 27.0, "L4S63": 6.0, "L5S155": 4.0, "L5S222": 5.0, "L5S240": 15.0, "L6S20": 33.0, "L6S68": 28.0, "L6S93": 30.0}, "b1e686a5c5f127a8b92de2863503a9e5": {"L2S222": 14.0, "L4S63": 10.0}, "b2866fdca13681232057e3e85a1978cf": {"L2S155": 57.0, "L2S175": 43.0, "L2S204": 18.0, "L2S222": 20.0, "L2S357": 12.0, "L3S313": 8.0, "L3S341": 25.0, "L3S360": 20.0, "L4S112": 40.0, "L4S137": 50.0, "L4S63": 51.0}, "b2d056fa113334bd2797397b162c6ac9": {"L1S8": 14.0}, "b3406cb10b6d6882837eaacbaec3553e": {"L2S204": 3.0, "L4S63": 10.0}, "b383ade799e9c83c649cec37705a251d": {"L1S140": 35.0, "L1S208": 34.0, "L1S257": 27.0, "L1S281": 53.0, "L3S378": 13.0}, "b3d4d129c955517b446df657236ba5a2": {"L1S105": 38.0, "L1S57": 171.0, "L1S76": 77.0, "L1S8": 55.0, "L3S242": 17.0}, "b428acd97e6af974db1b053a2bc2b5c8": {"L2S155": 41.0, "L2S175": 28.0}, "b44621e5c80607cdfacbf7a81e1cbe41": {"L1S208": 12.0, "L1S257": 2.0, "L1S57": 5.0, "L1S8": 30.0, "L2S155": 27.0, "L2S175": 100.0, "L2S204": 21.0, "L2S222": 15.0, "L2S240": 137.0, "L2S357": 44.0, "L2S382": 17.0, "L3S242": 4.0, "L3S294": 10.0, "L3S313": 57.0, "L4S112": 206.0, "L4S137": 74.0, "L4S63": 24.0, "L5S104": 32.0, "L5S155": 97.0, "L5S174": 52.0, "L5S203": 74.0, "L5S222": 9.0, "L5S240": 40.0, "L6S20": 114.0, "L6S68": 42.0, "L6S93": 95.0}, "b46e36edac9cab660cec7ee6f1a335a3": {"L2S204": 5.0, "L3S341": 4.0, "L3S360": 2.0, "L4S112": 3.0}, "b59d5976acdb148c29f724d6b7990410": {"L2S204": 5.0, "L2S222": 6.0}, "b5bf6383b53e0add0d6589b73949462a": {"L1S105": 46.0, "L1S140": 28.0, "L3S378": 5.0, "L4S63": 15.0}, "b685f8246fb6fad0fd91574c444b8f51": {"L2S155": 361.0, "L2S357": 17.0, "L3S294": 192.0, "L4S112": 33.0, "L4S63": 28.0}, "b815913c61abb4a540babe5c3fae17e7": {"L4S112": 9.0, "L4S63": 7.0}, "b8329e527429f07e08f04ecf93563779": {"L4S137": 31.0}, "b8afb7bb30b7a9170b7c6dcd40251d54": {"L1S208": 108.0, "L1S257": 210.0, "L1S281": 97.0}, "b8b19c4f0719a5d5b965a0f50f05827c": {"L1S208": 75.0}, "b901052d2411ea898be450af4a818744": {"L4S112": 19.0}, "b92e89d105e0a6e09e5984879c4c7809": {"L2S204": 19.0, "L2S222": 12.0, "L2S357": 11.0, "L3S341": 18.0, "L4S112": 78.0, "L4S63": 9.0}, "ba0941f03086680ee946a10dfe90cf12": {"L2S382": 19.0, "L4S137": 29.0}, "bb173654871d294466912ef22f685faa": {"L2S382": 23.0, "L4S137": 24.0}, "bb2704c9052362b112da42bf843e7d9b": {"L4S63": 25.0}, "bb370945a6777f712cfd963c55f2ff54": {"L1S105": 19.0, "L1S208": 21.0, "L1S257": 18.0, "L1S281": 13.0, "L1S57": 22.0, "L1S76": 14.0, "L3S378": 7.0}, "bcb349a220a0c33a6b780dbc29a25f71": {"L2S222": 22.0, "L3S360": 10.0}, "bf6066f701b31c6bba541503797da013": {"L4S112": 2.0, "L4S63": 9.0}, "bfbed36e63b69fec4627424163d20118": {"L1S105": 298.0, "L1S140": 703.0, "L1S208": 372.0, "L1S257": 174.0, "L1S281": 322.0, "L1S57": 107.0, "L1S76": 297.0, "L1S8": 130.0, "L2S175": 7.0, "L2S204": 19.0, "L2S222": 12.0, "L2S357": 10.0, "L3S313": 5.0, "L4S112": 50.0}, "bfbf3b84b315e741c4345ebb43e2b9cc": {"L2S222": 22.0, "L2S309": 6.0, "L4S63": 14.0}, "bfdc8d2e7693336b4f3781920d3fa253": {"L2S204": 48.0, "L2S309": 10.0, "L3S341": 8.0}, "c04b03fdea7f81c8c52fc540c50a24a4": {"L1S105": 15.0, "L1S140": 10.0, "L1S208": 9.0, "L1S57": 24.0}, "c18826df5af5da174f580164c805a38a": {"L2S382": 46.0, "L4S137": 32.0}, "c1dedbc2ee20ed310022b9a1976d56c4": {"L2S204": 30.0}, "c2562f279f2b32428e71ef8e8e1cd3d8": {"L2S222": 28.0}, "c4aad64f84f51ff331b986a67af4ed3d": {"L2S175": 57.0, "L2S204": 19.0, "L2S222": 33.0, "L3S313": 16.0, "L3S341": 12.0, "L3S360": 15.0, "L4S112": 30.0, "L4S137": 10.0, "L4S63": 46.0}, "c4f955168102011d272b685aa772c10a": {"L2S309": 3.0, "L2S357": 62.0, "L4S112": 45.0, "L4S63": 18.0}, "c57b70d65a63c4bf9f12c179c2416839": {"L1S105": 36.0, "L1S57": 16.0}, "c5b61a414bdb4305544bb4f941e0bfc9": {"L2S222": 89.0}, "c5dfb8aa2b481cb89e2602fc20941587": {"L2S204": 20.0, "L4S63": 9.0}, "c66348656c079cbbc916b2c2832f311b": {"L4S63": 15.0}, "c7312d5390945aa1e45badeeba28a998": {"L2S309": 15.0}, "c7ec57695a6d83b461eba523752755ec": {"L1S105": 7.0, "L1S140": 15.0, "L1S8": 11.0}, "c81e310dae79b8767597762a093082c8": {"L2S382": 20.0}, "c961cc0ecd0ac693e2fb7dcf7794c3e5": {"L2S382": 22.0}, "c99439f78b73ffcf55858ae828aac608": {"L2S175": 22.0, "L2S222": 48.0, "L3S360": 30.0}, "c9a1082e87563e01347729352358bbcf": {"L4S63": 43.0}, "c9f68eb27669d95f1e365fc085b51ee6": {"L4S137": 48.0}, "c9ffd432429a7600931358e3a09860f5": {"L4S63": 11.0}, "ca1b627f011b52798bfb8fd2c6b76d20": {"L4S137": 11.0}, "ca96b8fd01aa6c508305bacac37da6c2": {"L2S175": 6.0, "L2S357": 22.0, "L3S341": 14.0, "L4S112": 20.0, "L4S137": 20.0, "L4S63": 4.0, "L6S93": 6.0}, "cb2fe0146e2fbcb101050edb996a0ee2": {"L1S257": 9.0, "L2S155": 82.0, "L2S175": 230.0, "L2S204": 106.0, "L2S222": 49.0, "L2S309": 351.0, "L2S357": 318.0, "L2S382": 105.0, "L3S294": 75.0, "L3S313": 147.0, "L3S341": 65.0, "L3S360": 29.0, "L4S112": 1399.0, "L4S137": 367.0, "L4S63": 1578.0}, "cba5f5b1153235425628bd77a28257c7": {"L1S105": 37.0, "L1S208": 20.0, "L1S257": 6.0, "L1S281": 15.0, "L1S57": 9.0, "L1S76": 17.0}, "cbb7ea319a7633cf0917c6e5cde0e923": {"L1S257": 21.0, "L1S281": 16.0}, "cbc2f795edfaebaf35d10b85062b426d": {"L2S222": 24.0}, "cdd14cce4ec44b3235923652b71e947e": {"L1S140": 305.0, "L1S208": 476.0, "L1S257": 314.0, "L1S281": 404.0, "L3S378": 61.0, "L6S20": 9.0, "L6S68": 5.0}, "ce0a68ef210192a51f60ec3eb8e3e92e": {"L2S309": 5.0, "L2S357": 8.0, "L4S112": 9.0, "L4S63": 23.0}, "ce1d8d111ba2aaec28d68a04e483bf3f": {"L2S382": 17.0, "L4S137": 15.0}, "cee164362eb3296a3d29e33f7b479d2e": {"L2S204": 17.0}, "cf8a25fe1a1b134a027842e7769a285b": {"L2S222": 31.0}, "cfe4948493ea1b183b006512be10924a": {"L2S240": 14.0, "L5S104": 3.0, "L5S174": 43.0}, "d12759fe8dda1d65fe9077cc1ca9cf28": {"L4S63": 27.0}, "d1c7ee5172f16dda522e46aaa4e5fa79": {"L4S112": 22.0}, "d1d750ce3b00503c204516d27ca0d3b0": {"L2S155": 14.0, "L2S175": 49.0, "L2S222": 16.0, "L2S240": 52.0, "L2S357": 30.0, "L2S382": 15.0, "L3S313": 17.0, "L4S112": 114.0, "L4S137": 130.0, "L4S63": 41.0, "L5S104": 29.0, "L5S155": 21.0, "L5S174": 16.0, "L5S203": 14.0, "L5S222": 46.0, "L5S240": 19.0, "L6S20": 14.0, "L6S68": 36.0, "L6S93": 10.0}, "d2613a43f4ed1dda8a673e7fb251ebef": {"L1S208": 37.0, "L1S257": 186.0, "L1S281": 332.0, "L1S57": 170.0, "L1S76": 118.0}, "d29fe3c70564fc0f69f2c03e0d1e5561": {"L2S155": 359.0, "L2S175": 778.0, "L2S204": 95.0, "L2S222": 104.0, "L2S240": 341.0, "L2S309": 230.0, "L2S357": 522.0, "L2S382": 519.0, "L3S294": 46.0, "L3S313": 144.0, "L3S341": 74.0, "L3S360": 39.0, "L3S378": 3.0, "L4S112": 1381.0, "L4S137": 1749.0, "L4S63": 417.0, "L5S104": 216.0, "L5S155": 140.0, "L5S174": 113.0, "L5S203": 215.0, "L5S222": 148.0, "L5S240": 117.0, "L6S20": 215.0, "L6S68": 500.0, "L6S93": 465.0}, "d30b3fb9c1dc7d9f0d4bd6ce8e975238": {"L3S360": 24.0}, "d329ff7ff76454d2282c9f01c2798588": {"L4S63": 41.0}, "d32d15407d86a2044eead0d72cd3f9e7": {"L2S382": 16.0, "L4S137": 8.0}, "d3e265209c342d15d93a910e38ad9be2": {"L1S140": 41.0, "L1S208": 34.0, "L1S257": 15.0, "L1S281": 32.0, "L3S378": 12.0}, "d3f59bdb915bb43f2ecd96ad9296ae92": {"L2S240": 8.0, "L5S240": 2.0, "L6S20": 18.0, "L6S68": 10.0}, "d46bfd723f625e317606ae28580eba3e": {"L2S155": 16.0, "L2S175": 7.0, "L2S204": 29.0, "L2S222": 28.0, "L2S309": 7.0, "L3S294": 4.0, "L3S360": 3.0, "L4S112": 10.0, "L4S63": 31.0}, "d51cd90e95b57acb614698dc580759fb": {"L1S8": 27.0}, "d5ef913e6aee3067001dc610ac8af1d1": {"L2S222": 30.0}, "d781fa7e866ac295ce9a56bd97912983": {"L1S140": 19.0, "L1S208": 84.0, "L1S257": 70.0, "L1S281": 30.0}, "d86ef5d6394f5dbeb945f39aa25e7426": {"L1S105": 147.0, "L1S140": 243.0, "L1S208": 143.0, "L1S257": 95.0, "L1S281": 86.0, "L1S57": 482.0, "L1S76": 153.0, "L1S8": 536.0, "L2S309": 5.0, "L2S357": 3.0, "L3S242": 67.0, "L3S378": 35.0}, "d8db52dac1023a8fa0e56e92670d7ac1": {"L1S208": 11.0, "L1S257": 9.0, "L1S281": 9.0}, "d8e8459398f3f096775f4298666880a7": {"L2S155": 16.0, "L2S175": 102.0, "L2S204": 16.0, "L2S222": 40.0, "L2S309": 7.0, "L2S357": 24.0, "L2S382": 11.0, "L3S294": 6.0, "L3S313": 7.0, "L3S341": 60.0, "L3S360": 9.0, "L4S112": 65.0, "L4S137": 124.0, "L4S63": 15.0, "L5S203": 11.0, "L5S222": 4.0, "L6S20": 3.0, "L6S68": 8.0, "L6S93": 29.0}, "d8f7f446987e67092b6256c10b1ee69e": {"L2S204": 17.0, "L2S222": 15.0, "L3S341": 6.0, "L4S63": 36.0}, "d9095748835ade1b8914c5f57b6acbcf": {"L2S222": 13.0, "L3S360": 8.0}, "d985172bebaa0bbe61ff5f682d372c6e": {"L6S93": 18.0}, "d9efe89c658c7996e7738e1bb777c9f0": {"L4S137": 31.0}, "da247df6fe91b74bf38d3ecc1c05b4b0": {"L2S175": 29.0, "L2S222": 10.0, "L4S63": 13.0}, "dab4d3e6078cfc510502a47c98e82081": {"L2S175": 60.0, "L3S341": 7.0}, "db793caa585e078770021a7979ae8ea2": {"L2S155": 275.0, "L2S175": 139.0, "L2S222": 73.0, "L3S294": 91.0, "L3S313": 64.0, "L4S112": 61.0, "L4S137": 53.0}, "dc7d3610c77e7c118082f25002f26cd4": {"L2S222": 17.0, "L4S63": 16.0}, "dd222108ed685d6a936d2011ea220998": {"L2S222": 14.0, "L4S63": 69.0}, "dd7e1e45831871f719cc3cd68f568e7c": {"L4S63": 92.0}, "de35e106a779f81d63e2e058bf18799c": {"L2S240": 9.0, "L6S20": 4.0}, "de391a8294254c47e8f460325eea85f8": {"L2S222": 21.0, "L3S360": 13.0}, "e03d5567ab978eb82490f359c51912b1": {"L2S155": 5.0, "L4S63": 10.0}, "e0472171de6fa02a1f58e392ad3d000e": {"L2S155": 64.0, "L2S222": 22.0, "L3S294": 62.0, "L4S112": 68.0, "L4S63": 68.0}, "e063d1c3c9daf7390e5475e48d9b01c5": {"L1S57": 165.0, "L1S76": 121.0}, "e0f1938338e6f9b8cf8408e672ee6cd1": {"L2S204": 9.0, "L3S294": 2.0, "L4S112": 19.0}, "e22afe3cb91239d19aeb01ba79015173": {"L2S222": 68.0}, "e2c355360209f0b71b70b85ed0f9532d": {"L1S208": 26.0, "L1S76": 10.0}, "e2cbf79a06f1221cf49d1bef8e5db9cd": {"L2S382": 12.0, "L4S137": 11.0}, "e2f0caba18b002ca9762ed56167c6188": {"L1S208": 19.0, "L1S281": 16.0}, "e31b5affbe5e23b79a8619589f3b6620": {"L2S204": 117.0, "L2S222": 43.0, "L2S240": 7.0, "L2S309": 47.0, "L2S357": 48.0, "L3S341": 39.0, "L3S360": 31.0, "L4S112": 125.0, "L4S63": 81.0, "L5S104": 263.0, "L5S222": 8.0}, "e54bcf1c8ec24811e7c355b8d82fa59e": {"L4S112": 17.0}, "e5c80b4a23b96b2fa35b6da6cac2bf73": {"L2S222": 8.0, "L2S382": 10.0, "L4S137": 546.0}, "e6953e3ef3e20c6b169ef7a759d868df": {"L3S378": 14.0}, "e6df6369108817c93a749fa640528e92": {"L4S112": 17.0, "L4S63": 5.0}, "e6dfd15b38618c3c7ff0a025083f56d4": {"L2S309": 16.0}, "e737a3a864791ec52f1398d83786f4f2": {"L2S155": 25.0, "L2S175": 25.0, "L2S204": 27.0, "L2S222": 34.0, "L2S309": 14.0, "L4S112": 12.0, "L4S63": 98.0}, "e73fc2655e1cca4a2b1c419da3630c72": {"L2S204": 11.0, "L2S222": 11.0, "L4S112": 8.0, "L4S63": 23.0}, "e77bac543df42865af751a32a2942fdb": {"L2S240": 36.0, "L2S382": 8.0, "L4S137": 16.0, "L5S240": 12.0, "L6S20": 49.0, "L6S68": 51.0, "L6S93": 80.0}, "e7a3af060bcc6686986ddfdf5536fac8": {"L2S175": 11.0, "L2S382": 10.0, "L4S112": 18.0, "L4S137": 30.0}, "e7c8b8c8fced8eead4b767bffe6dd544": {"L1S105": 31.0, "L2S155": 31.0, "L2S175": 43.0, "L2S222": 11.0, "L2S382": 338.0, "L3S313": 13.0, "L4S137": 281.0, "L6S93": 87.0}, "e80d9134b601511a2702b54268b57249": {"L1S57": 20.0, "L2S309": 2.0}, "e8e6b7fc969005938de8ac7ffb94f17c": {"L2S155": 14.0, "L2S175": 56.0, "L2S240": 178.0, "L2S309": 12.0, "L2S357": 22.0, "L2S382": 16.0, "L3S313": 14.0, "L4S112": 59.0, "L4S137": 46.0, "L4S63": 48.0, "L5S104": 178.0, "L5S155": 48.0, "L5S174": 45.0, "L5S203": 60.0, "L5S222": 31.0, "L5S240": 106.0, "L6S20": 108.0, "L6S68": 224.0, "L6S93": 38.0}, "e8fb2b3d01d369dbb5d3764548193ae9": {"L2S175": 9.0, "L2S382": 58.0, "L4S137": 56.0, "L5S104": 2.0, "L6S93": 7.0}, "e9849de9c0f7be74e13c457f05177aad": {"L2S175": 11.0}, "e9f0399c43aff643ceb1480929cf89b2": {"L4S137": 16.0}, "ebd1dcd162acede67bb633c42c7b2ac2": {"L1S208": 33.0, "L1S57": 16.0}, "ebe0e9790089ad4f40151cb4a3231a8f": {"L2S155": 10.0, "L2S175": 21.0, "L2S240": 53.0, "L2S382": 11.0, "L3S313": 6.0, "L4S112": 45.0, "L4S137": 45.0, "L4S63": 43.0, "L5S104": 59.0, "L5S155": 27.0, "L5S174": 23.0, "L5S203": 36.0, "L5S222": 29.0, "L5S240": 41.0, "L6S20": 35.0, "L6S68": 132.0, "L6S93": 28.0}, "ecbf086d6ccbe5e8c2a69d0afb144662": {"L4S63": 44.0}, "ecf9eb9fa3970ff27a221e626395c75d": {"L4S63": 70.0}, "ed75725613954c459019eec50b431f9f": {"L2S155": 20.0, "L2S175": 14.0, "L2S222": 19.0, "L4S112": 12.0}, "ed950935b660fb10449d5f229dc13fb9": {"L1S57": 116.0}, "edacf632dcadc21c328669befafe2af6": {"L1S105": 24.0, "L1S57": 12.0}, "ee0fb26fca3afb05e0b288d6fcab899e": {"L1S105": 242.0, "L1S208": 10.0, "L1S257": 14.0, "L1S281": 34.0, "L1S57": 141.0, "L1S76": 195.0, "L1S8": 17.0, "L2S222": 37.0}, "ee7ce85e38500b28d9d79b63c7fbf9a6": {"L1S105": 10.0, "L1S140": 11.0, "L4S63": 19.0}, "eecc4a4317225eb579540e82ab785716": {"L3S242": 13.0, "L3S341": 14.0, "L3S378": 184.0}, "f023384b8f989d014dd2ead7f10db307": {"L1S208": 36.0, "L1S257": 20.0, "L1S281": 34.0, "L2S309": 5.0}, "f094a383692eb30761eb3d5c93240236": {"L2S204": 18.0, "L4S63": 30.0}, "f16a387e898dbae6432b2ed0241120bd": {"L1S140": 13.0, "L1S57": 11.0, "L1S8": 122.0, "L3S242": 21.0}, "f3194c2eb241f821239009ca55dbb30c": {"L2S204": 15.0, "L2S222": 20.0, "L2S309": 12.0, "L4S63": 23.0}, "f32674aec6d3fa6a7aa2323cb35699fc": {"L3S341": 13.0, "L4S112": 17.0, "L4S63": 14.0}, "f351326f9505ffc18da207391818c48e": {"L4S112": 22.0}, "f352c1f1efecf483511c2270aabd0ae6": {"L2S382": 26.0, "L3S360": 9.0, "L4S137": 1100.0}, "f35ce9c514e1398308f5f84ed50b260f": {"L4S112": 11.0, "L4S137": 17.0, "L4S63": 9.0, "L6S20": 12.0, "L6S68": 35.0, "L6S93": 531.0}, "f4eefbd4edf2a372131825289fffcca6": {"L1S105": 9.0, "L1S8": 11.0}, "f59a4d48a03cc224462bf83e4d4ab126": {"L1S105": 33.0, "L1S208": 41.0, "L1S257": 12.0, "L1S281": 8.0, "L1S57": 47.0, "L1S76": 68.0}, "f66effc279917d65747b7c3ef8d62432": {"L1S140": 18.0}, "f8026fa73c97b3f69cf4369cf194fb8b": {"L4S63": 37.0}, "f8753b9f13abb306b57aedce2cf6e7d0": {"L2S155": 9.0, "L4S112": 6.0}, "f8a71161ac98c5ceafcc75e57ace7230": {"L2S155": 83.0, "L2S357": 34.0, "L3S294": 18.0, "L4S112": 60.0, "L5S104": 53.0}, "f8f937eeee7762f446a0e87292f98eb6": {"L1S257": 206.0, "L1S281": 127.0}, "f8fe4ee0ae3da9a1432872f5545a0d42": {"L2S155": 17.0}, "f91c81859bf6eede55eef9c915dd8bab": {"L1S105": 26.0, "L1S208": 36.0, "L1S57": 46.0, "L1S76": 86.0}, "f95cdb71258ef6cc222c673ea4546caf": {"L1S208": 14.0}, "f99678fdc17d27a97c79faac3f2980a4": {"L2S222": 58.0}, "f9bc8716f02b0a22f03b1a686895aae1": {"L4S63": 46.0}, "faf2bd479f04891ef2afba2f407749ac": {"L2S382": 11.0, "L3S294": 4.0, "L4S137": 6.0}, "fb4f7d9d3f91ac2f22a542fbd13019c1": {"L1S140": 48.0, "L1S257": 32.0, "L1S281": 27.0, "L3S378": 22.0}, "fba3d9b3872ff9021d66434323fb9565": {"L2S240": 103.0, "L5S240": 36.0, "L6S20": 116.0, "L6S68": 115.0, "L6S93": 173.0}, "fbf110ef5de76f86121c8504a0cb786e": {"L1S105": 6.0, "L1S257": 3.0, "L1S281": 3.0, "L1S76": 5.0}, "fc15824cd9e9c29e1319d32843452b54": {"L1S105": 79.0, "L1S140": 40.0, "L1S208": 21.0, "L1S257": 27.0, "L1S281": 24.0, "L1S57": 35.0, "L1S76": 29.0, "L1S8": 67.0, "L3S242": 18.0, "L3S378": 9.0}, "fc1f49989e78fa71bc6404ff2a148576": {"L1S140": 34.0, "L1S257": 12.0, "L1S281": 18.0, "L1S76": 14.0}, "fc5b641a0b0408d99ddfb2a5ba64da59": {"L2S175": 8.0, "L4S63": 293.0}, "fcd4f95c05b868060121ff709085bf21": {"L1S140": 11.0, "L2S155": 72.0, "L2S175": 26.0, "L2S204": 14.0, "L2S222": 16.0, "L2S240": 11.0, "L2S309": 43.0, "L2S357": 44.0, "L2S382": 44.0, "L3S294": 17.0, "L3S313": 16.0, "L4S112": 101.0, "L4S137": 99.0, "L4S63": 403.0}, "fd86856409fe6433d719558a30910515": {"L2S155": 16.0, "L2S175": 44.0, "L2S204": 20.0, "L2S222": 21.0, "L2S309": 20.0, "L2S357": 60.0, "L2S382": 43.0, "L3S294": 15.0, "L3S341": 41.0, "L4S112": 185.0, "L4S137": 321.0, "L4S63": 39.0, "L5S203": 14.0, "L5S222": 15.0, "L6S68": 77.0, "L6S93": 186.0}, "fe30ff0f71a38a39cf1717ec2be3a2fc": {"L1S105": 5.0, "L2S204": 24.0, "L2S222": 50.0, "L2S240": 1041.0, "L2S309": 47.0, "L2S357": 123.0, "L2S382": 85.0, "L3S341": 25.0, "L3S360": 22.0, "L4S112": 335.0, "L4S137": 357.0, "L4S63": 164.0, "L5S240": 374.0, "L6S20": 3336.0, "L6S68": 1741.0, "L6S93": 1367.0}, "fe98555e63f547c33b3987391cd34d5d": {"L2S175": 8.0, "L2S382": 2.0, "L4S137": 2.0, "L5S203": 3.0, "L5S240": 2.0, "L6S20": 2.0, "L6S68": 10.0, "L6S93": 12.0}, "fea5c05e9b8245c5ca46f6673f59e0bf": {"L1S105": 17.0, "L1S140": 11.0, "L1S208": 16.0, "L1S257": 22.0, "L1S281": 11.0, "L1S76": 6.0}, "ff3df50eea7490dd794148649c480fd3": {"L1S105": 26.0, "L1S281": 26.0, "L1S57": 64.0, "L1S76": 30.0}, "ff8c7f94f941a0c647120d4e142db316": {"L2S382": 10.0, "L4S137": 8.0}};
        new display.RRVDisplay(
            rankPlotJSON,
            samplePlotJSON,
            countJSON
        ).makePlots();
    }
);
